<?php

require_once("Model/Player.inc");
require_once("Model/ActionLogRecord.inc");
require_once("Model/ActionType.inc");
require_once("Model/Alliance.inc");
require_once("Model/Ship.inc");
require_once("Model/Delivery.inc");

class ActionLogger
{
	const ACTION_DELIVERY_STARTED_ID = 1;
	const ACTION_SHIP_FLOWN_ID = 2;
	const ACTION_SHIP_BOUGHT_ID = 3;
	const ACTION_BASE_BOUGHT_ID = 4;
	const ACTION_DELIVERY_LOADED_ID = 5;
	const ACTION_DELIVERY_UNLOADED_ID = 6;
	const ACTION_LOGGED_IN_ID = 7;
	const ACTION_LOGGED_OUT_ID = 8;
	const ACTION_BASE_COMPLETED_ID = 9;
	const ACTION_SHIP_DOCKED_ID = 10;
	const ACTION_FLIGHT_PAYED_ID = 11;
	const ACTION_LICENCE_BOUGHT_ID = 12;
	const ACTION_SHIP_UPGRADED_ID = 13;
	const ACTION_PIRATES_ATTACK_WON_ID = 14;
	const ACTION_PIRATES_ATTACK_LOST_ID = 15;
	const ACTION_PIRATES_CARGO_LOST_ID = 16;
	const ACTION_PIRATES_RELATIONS_DECREASED_ID = 17;
	const ACTION_EMBASSY_LEVEL_BOUGHT_ID = 18;
	const ACTION_ALLIANCE_CREATED_ID = 19;
	const ACTION_ALLIANCE_ABANDONED_ID = 20;
	const ACTION_ALLIANCE_JOINED_ID = 21;
	const ACTION_ALLIANCE_KICKED_ID = 22;
	const ACTION_DONATE_MONEY_SENT_ID = 23;
	const ACTION_DONATE_MONEY_RECIEVED_ID = 24;
	const ACTION_DONATE_GUARDS_SENT_ID = 25;
	const ACTION_DONATE_GUARDS_RECIEVED_ID = 26;
	const ACTION_SHIP_FLOWN_TO_WORMHOLE_ID = 27;
	const ACTION_SHIP_FLOWN_THROUGH_WORMHOLE_ID = 28;
	
	private $player;
	
	public function __construct(Player $player)
	{
		if ($player == NULL)
		{
			throw new Exception("Player must be provided.");
		}
		
		$this->player = $player;
	}
	
	public function LogDeliveryStarted(Ship $ship, Planet $planet, Delivery $delivery)
	{
		$args = sprintf("%s;%s;%d;%s", $ship->GetName(), $planet->GetName(), $delivery->GetAmount(), $delivery->GetGoodType()->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DELIVERY_STARTED_ID, $args);
		return $record != NULL;
	}
	
	public function LogShipFlown(Ship $ship, Planet $target)
	{
		$args = sprintf("%s;%s", $ship->GetName(), $target->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_SHIP_FLOWN_ID, $args);
		return $record != NULL;
	}
	
	public function LogShipFlownToWormHole(Ship $ship, $otherSystemName)
	{
		$args = sprintf("%s;%s", $ship->GetName(), $otherSystemName);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_SHIP_FLOWN_TO_WORMHOLE_ID, $args);
		return $record != NULL;
	}
	
	public function LogShipFlownThroughWormHole(Ship $ship, $otherSystemName, $taxes)
	{
		$args = sprintf("%s;%s;%d", $ship->GetName(), $otherSystemName, $taxes);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_SHIP_FLOWN_THROUGH_WORMHOLE_ID, $args);
		return $record != NULL;
	}
	
	public function LogShipBought(Ship $ship)
	{
		$args = sprintf("%s;%s;%d", $ship->GetName(), $ship->GetModel()->GetName(), $ship->GetModel()->GetPrice());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_SHIP_BOUGHT_ID, $args);
		return $record != NULL;
	}
	
	public function LogBaseBought(Planet $planet, $price)
	{
		$args = sprintf("%s;%d", $planet->GetName(), $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_BASE_BOUGHT_ID, $args);
		return $record != NULL;
	}
	
	public function LogDeliveryLoaded(Ship $ship, Planet $planet, Delivery $delivery)
	{
		$args = sprintf("%s;%s;%d;%s", $ship->GetName(), $planet->GetName(), $delivery->GetAmount(), $delivery->GetGoodType()->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DELIVERY_LOADED_ID, $args);
		return $record != NULL;
	}
	
	public function LogDeliveryUnloaded(Ship $ship, Planet $planet, Delivery $delivery)
	{
		$args = sprintf("%s;%s;%s;%d", $ship->GetName(), $planet->GetName(), $delivery->GetGoodType()->GetName(), $delivery->GetPrice());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DELIVERY_UNLOADED_ID, $args);
		return $record != NULL;
	}
	
	public function LogLoggedIn()
	{
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_LOGGED_IN_ID, $_SERVER['REMOTE_ADDR']);
		return $record != NULL;
	}
	
	public function LogLoggedOut()
	{
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_LOGGED_OUT_ID, $_SERVER['REMOTE_ADDR']);
		return $record != NULL;
	}
	
	public function LogBaseCompleted(Planet $planet, $price, $time)
	{
		$args = sprintf("%s;%d", $planet->GetName(), $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_BASE_COMPLETED_ID, $args, $time);
		return $record != NULL;
	}
	
	public function LogShipDocked(Ship $ship, Planet $planet, $price)
	{
		$args = sprintf("%s;%s;%d", $ship->GetName(), $planet->GetName(), $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_SHIP_DOCKED_ID, $args);
		return $record != NULL;
	}
	
	public function LogShipFlightPayed(Ship $ship, $price)
	{
		$args = sprintf("%s;%d", $ship->GetName(), $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_FLIGHT_PAYED_ID, $args);
		return $record != NULL;
	}
	
	public function LogLicenceBought($count, $price)
	{
		$args = sprintf("%d;%d", $count, $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_LICENCE_BOUGHT_ID, $args);
		return $record != NULL;
	}
	
	public function LogEmabassyLevelBought($count, $price)
	{
		$args = sprintf("%d;%d", $count, $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_EMBASSY_LEVEL_BOUGHT_ID, $args);
		return $record != NULL;
	}
	
	public function LogShipUpgraded(Ship $ship, $price)
	{
		$args = sprintf("%s;%d;%d", $ship->GetName(), $ship->GetLevel(), $price);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_SHIP_UPGRADED_ID, $args);
		return $record != NULL;
	}
	
	public function LogPiratesAttackWon(Ship $cargoShip, $ourLoss, $pirateLoss)
	{
		$args = sprintf("%s;%d;%d", $cargoShip->GetName(), $ourLoss, $pirateLoss);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_PIRATES_ATTACK_WON_ID, $args);
		return $record != NULL;
	}
	
	public function LogPiratesAttackLost(Ship $cargoShip, $ourLoss, $pirateLoss, $levelLoss)
	{
		$args = sprintf("%s;%d;%d;%d", $cargoShip->GetName(), $ourLoss, $pirateLoss, $levelLoss);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_PIRATES_ATTACK_LOST_ID, $args);
		return $record != NULL;
	}
	
	public function LogPiratesCargoLost(Ship $cargoShip)
	{
		$args = sprintf("%s", $ship->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_PIRATES_CARGO_LOST_ID, $args);
		return $record != NULL;
	}
	
	public function LogPiratesRelationsDecreased()
	{
		$args = sprintf("");
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_PIRATES_RELATIONS_DECREASED_ID, $args);
		return $record != NULL;
	}
	
	public function LogAllianceCreated(Alliance $alliance)
	{
		$args = sprintf("%s", $alliance->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_ALLIANCE_CREATED_ID, $args);
		return $record != NULL;
	}
	
	public function LogAllianceAbandoned(Alliance $alliance)
	{
		$args = sprintf("%s", $alliance->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_ALLIANCE_ABANDONED_ID, $args);
		return $record != NULL;
	}
	
	public function LogAllianceJoined(Alliance $alliance)
	{
		$args = sprintf("%s", $alliance->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_ALLIANCE_JOINED_ID, $args);
		return $record != NULL;
	}
	
	public function LogAllianceKickedMe(Alliance $alliance, Player $kicker, $reason)
	{
		$args = sprintf("%s;%s;%s", $alliance->GetName(), $kicker->GetStringIdentifier(), $reason);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_ALLIANCE_KICKED_ID, $args);
		return $record != NULL;
	}
	
	public function LogMoneyDonateSent(Player $reciever, $amount)
	{
		$args = sprintf("%d;%s", $amount, $reciever->GetStringIdentifier());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DONATE_MONEY_SENT_ID, $args);
		return $record != NULL;
	}
	
	public function LogMoneyDonateRecieved(Player $sender, $amount)
	{
		$args = sprintf("%s;%d", $sender->GetStringIdentifier(), $amount);
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DONATE_MONEY_RECIEVED_ID, $args);
		return $record != NULL;
	}
	
	public function LogGuardsDonateSent(Player $reciever, Ship $guard)
	{
		$args = sprintf("%s;%s;%s", $guard->GetName(), $guard->GetModel()->GetName(), $reciever->GetStringIdentifier());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DONATE_GUARDS_SENT_ID, $args);
		return $record != NULL;
	}
	
	public function LogGuardsDonateRecieved(Player $sender, Ship $guard)
	{
		$args = sprintf("%s;%s;%s", $sender->GetStringIdentifier(), $guard->GetName(), $guard->GetModel()->GetName());
		$record = ActionLogRecord::CreateNewRecord($this->player->GetId(), self::ACTION_DONATE_GUARDS_RECIEVED_ID, $args);
		return $record != NULL;
	}
	
	/* sdfsfdfdf*/
	
	public function GetLatestRecords($topCount = 50)
	{
		return $this->player->LoadLatestLogRecordsFromDB($topCount);
	}
	
	public function ClearLogForPlayer()
	{
		return ActionLogRecord::RemoveFromDBAllForPlayer($this->player->GetId());
	}	
	
	public function BuildTextString(ActionLogRecord $record)
	{
		if ($record == NULL)
		{
			return "";
		}	
		
		$dictionary = Dictionary::GetInstance();
		
		$actionType = ActionType::LoadFromDB($record->GetTypeId());
		$format = $dictionary->Translate($actionType->GetNameString());
		
		$args = split(";", $record->GetArgs());
		
		$command = '$res = sprintf($format, ';
		
		for ($i = 0; $i < count($args); $i++)
		{
			$command .= '$args['.$i.']';
			
			if ($i != count($args) - 1)
			{
				$command .= ", ";
			}
		}
		
		$command .= ");";
		
		$res = "";
		eval($command);
		
		return $res;
	}
}

?>