<?php

/**
 * Static class for ingame virtual time measurement.
 */
class GameTimer
{
	/**
	 * Real time in seconds when game started.
	 */
	const GAME_START_TIME = 0;
	
	/**
	 * Length of day on Earth in game in seconds of real life.
	 */
	const EARTH_DAY_LENGTH_SEC = 12;
	
	const SECONDS_IN_DAY = 86400;
	
	private static $elapsedSeconds = -1;
	
	/**
	 * Number of ingame Earth days elapsed or -1 if not measured yet.
	 */
	private static $elapsedDays = -1;
	
	/**
	 * Ratio within current day in range <0; 1).
	 */
	private static $currentDayRatio = -1;
	
	/**
	 * Hidden constructor.
	 */
	private function __construct()
	{
		
	}	
	
	/**
	 * Gets/counts number of ingame Earth days elapsed since game start.
	 * Rounds down. Use GetSecondsElapsed() or GetCurrentDayRatio() to get more
	 * precision. Or just use $float = true.
	 */
	public static function GetDaysElapsed($float = false)
	{
		if (self::$elapsedDays < 0)
		{
			$elapsedTime = microtime(true) - GameTimer::GAME_START_TIME;		
			self::$elapsedSeconds = $elapsedTime;
			self::$elapsedDays = floor($elapsedTime / GameTimer::EARTH_DAY_LENGTH_SEC);
			self::$currentDayRatio = $elapsedTime / GameTimer::EARTH_DAY_LENGTH_SEC - self::$elapsedDays;
		}
		
		if (!$float)
		{
			return self::$elapsedDays;	
		}	
		else
		{
			return self::$elapsedDays + $currentDayRatio;
		}
	}
		
	public static function GetSecondsElapsed()
	{
		if (self::$elapsedDays < 0)
		{
			GameTimes::GetDaysElapsed();
		}
		
		return self::$elapsedSeconds;	
	}
	
	
	/**
	 * Gets/counts ratio within current day in range <0; 1).
	 */
	public static function GetCurrentDayRatio()
	{
		if (self::$elapsedDays < 0)
		{
			GameTimes::GetDaysElapsed();
		}
		
		return self::$currentDayRatio;	
	}
	
	/**
	 * Converts time period in real time seconds to ingame Earth days.
	 * @param $timeInSec value in seconds to convert
	 * @return ig-game time in Earth days 
	 */
	public static function RealTimeToEarthDays($timeInSec)
	{
		return  $timeInSec / floatval(GameTimer::EARTH_DAY_LENGTH_SEC);
	}
	
	/**
	 * Converts time period in ingame Earth days to real seconds.
	 * @param $timeInSec time in Earth days
	 * @return ig-game time in real seconds
	 */
	public static function EarthDaysToRealTime($earthDays)
	{
		return  $earthDays * GameTimer::EARTH_DAY_LENGTH_SEC;
	}
}