<?php

require_once('Model/Player.inc');
require_once('Model/SolarSystem.inc');
require_once('Model/Planet.inc');

class Globals
{
	const LANG_CS_CZ = 0;
	const LANG_EN_UK = 1;
	const LANG_COUNT = 2;
	
	const DEFAULT_SYSTEM_ID = 1;
	
	private function __construct() {}
	
	public static function SetLanguage($languageCode)
	{
		if (!is_array($_SESSION))
		{
			return;
		}
		
		if ($languageCode >= LANG_COUNT)
		{
			throw new Exception("Invalid language code.");
		}		
		
		$_SESSION["app_lang"] = $languageCode;
	} 	
	
	public static function GetLanguage()
	{ 
		if (is_array($_SESSION) && array_key_exists("app_lang", $_SESSION))
		{
			return $_SESSION["app_lang"];
		}
		else
		{
			return Globals::LANG_CS_CZ;
		} 
	}
	
	private static $playerCache = NULL;
	
	public static function SetActivePlayer(Player $player = NULL)
	{
		if (!is_array($_SESSION))
		{
			return;
		}
		
		$playerId = $player == NULL ? -1 : $player->GetId();
		
		$_SESSION["active_player"] = $playerId;
		self::$playerCache = $player;
	}
	
	public static function GetActivePlayer()
	{ 
		if (!is_array($_SESSION))
		{
			return NULL;
		}
		
		$playerId = -1;
		
		if (array_key_exists("active_player", $_SESSION))
		{
			$playerId = $_SESSION["active_player"];
		}
		
		if ($playerId < 0)
		{
			return NULL;
		}
		
		if (self::$playerCache == NULL || self::$playerCache->GetId() == $playerId)
		{
			self::$playerCache = Player::LoadFromDB($playerId);	
		}
		
		return self::$playerCache;		
	}	
	
	
	
	
	private static $solarSystemCache = NULL;
	
	public static function SetActiveSolarSystem(SolarSystem $system = NULL)
	{
		if (!is_array($_SESSION))
		{
			return;
		}
		
		$systemId = $system == NULL ? -1 : $system->GetId();
		
		$_SESSION["active_solar_system"] = $systemId;
		self::$solarSystemCache = $system;
	}
	
	public static function GetActiveSolarSystem()
	{ 
		if (!is_array($_SESSION))
		{
			return NULL;
		}
		
		$systemId = -1;
		
		if (array_key_exists("active_solar_system", $_SESSION))
		{
			$systemId = $_SESSION["active_solar_system"];
		}
		
		if ($systemId < 0)
		{
			$player = Globals::GetActivePlayer();
			if ($player == NULL)
			{
				$systemId = self::DEFAULT_SYSTEM_ID;
			}
			else 
			{
				$planet = Planet::LoadFromDB($player->GetHomePlanetId());
				$systemId = $planet->GetSolarSystemId();
			}
			
			$_SESSION["active_solar_system"] = $systemId;
		}
		
		if (self::$solarSystemCache == NULL || self::$solarSystemCache->GetId() == $systemId)
		{
			self::$solarSystemCache = SolarSystem::LoadFromDB($systemId, true);	
		}
		
		return self::$solarSystemCache;		
	}	
	
	public static function GetGamePlanSize()
	{
		if (!is_array($_SESSION))
		{
			return 600;
		}
		
		if (!array_key_exists("gameplan_size", $_SESSION))
		{
			$_SESSION["gameplan_size"] = "469;464";
		}
		
		return split(";", $_SESSION["gameplan_size"]);
	}
	
	public static function SetGamePlanSize(array $size)
	{
		if (!is_array($_SESSION))
		{
			return;
		}
		
		$_SESSION["gameplan_size"] = $size[0] . ";" . $size[1];
	}
}

?>