<?php

require_once("Model/SolarSystem.inc");
require_once("Model/Player.inc");
require_once("Model/Delivery.inc");
require_once("Model/Message.inc");
require_once("Model/Alliance.inc");
require_once("Model/AllianceInvitation.inc");
require_once("Control/DBManager.inc");
require_once("Control/GameTimer.inc");
require_once("Control/GameConstants.inc");
require_once("Control/Dictionary.inc");
require_once("Control/GameUpdater.inc");
require_once("Control/Globals.inc");
require_once("Control/ActionLogger.inc");
require_once("Control/ShipActionController.inc");
require_once("View/GamePlan.inc");
require_once("View/LoginPanel.inc");
require_once("View/PlanetGraphic.inc");
require_once("View/ShipGraphic.inc");
require_once("View/PlanetInfoPanel.inc");
require_once("View/DesignConstants.inc");
require_once("View/MenuPanel.inc");
require_once("View/DeliveryPanel.inc");
require_once("View/PlanetHomePlayersPanel.inc");
require_once("View/ShipSelectionPanel.inc");
require_once("View/ShipShopPanel.inc");
require_once("View/HighScorePanel.inc");
require_once("View/MessagePanel.inc");
require_once("View/LogViewPanel.inc");
require_once("View/GuardAssignmentPanel.inc");
require_once('View/EmbassyPanel.inc');
require_once("View/AllianceTransferPanel.inc");
require_once("View/GalaxyMap.inc");

class Responder
{
	public static function ApplyGuardAssignments($assignments)
	{
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$response = 1;
		$lines = split("%", $assignments);
		
		foreach ($lines as $line)
		{
			$words = split(";", $line);
			
			if (count($words) < 3)
			{
				continue;
			}
					
			$guardId = split("_", $words[0]);
			if (count($guardId) < 2)
			{
				continue;
			}
			$guardId = $guardId[1];
			$cargoId = $words[1];
			
			$guard = Ship::LoadFromDB($guardId);
			
			if ($guard == NULL)
			{
				continue;
			}
			
			if ($guard->GetPlayerID() != $player->GetId())
			{
				continue;
			}
			
			if ($guard->GetModel()->GetShipType()->GetId() != GameConstants::GUARD_SHIP_TYPE_ID)
			{
				continue;
			}
			
			
	
			// give to pirates
			if ($words[2] == "1")
			{
				$pirates = Player::LoadPiratesFromDB();
				$guard->SetPlayerId($pirates->GetId());
				
				$shipAC = new ShipActionController($pirates, $guard);
				$shipAC->AssignGuardTask(NULL);
				
				$player->SetPirateRelations($player->GetPirateRelations() + 1);
				
				$response = 2;
			}
			else if ($cargoId > 0)
			{
				$shipAC = new ShipActionController($player, $guard);			
				$cargo = Ship::LoadFromDB($cargoId);
				
				if ($cargo == NULL)
				{
					continue;
				}
				
				if ($cargo->GetPlayerID() != $player->GetId())
				{
					continue;
				}
				
				if ($cargo->GetModel()->GetShipType()->GetId() != GameConstants::CARGO_SHIP_TYPE_ID)
				{
					continue;
				}
				
				$res = $shipAC->AssignGuardTask($cargo);
			}
			else
			{
				$shipAC = new ShipActionController($player, $guard);
				$shipAC->AssignGuardTask(NULL);
			}		
		}
		
		return $response;
	}
	
	public static function GoToSystem($systemId = -1)
	{
		if ($systemId < 0)
		{
			Globals::SetActiveSolarSystem(NULL);
			return;
		}
		
		$system = SolarSystem::LoadFromDB($systemId, true);
		Globals::SetActiveSolarSystem($system);
		return;
	}
	
	public static function DeleteMessage($messageId)
	{
		if ($messageId == NULL)
		{
			Responder::GetMessagePanel(0, 'list');
			return;
		}
		
		$message = Message::loadFromDB($messageId);
		
		if ($message != NULL)
		{
			$message->RemoveFromDB();
		}
		
		Responder::GetMessagePanel(0, 'list');
	}
	
	public static function SendNewMessage($reciever, $subject, $textBody)
	{
		if ($reciever == NULL || $subject == NULL || $textBody == NULL || strlen(trim($subject)) == 0)
		{
			echo 0;
			return;
		}
		
		$recieverPlayer = Player::LoadFromDBByLogin(trim($reciever));
		
		if ($recieverPlayer == NULL)
		{
			echo 2;
			return;
		}
		
		$sender = Globals::GetActivePlayer();
		
		if ($sender == NULL)
		{
			echo 0;
			return;
		}
		
		$subject = trim($subject);
		
		$message = Message::CreateNewMessage($sender->GetId(), $recieverPlayer->GetId(), $subject, $textBody);
		
		if ($message == NULL)
		{
			echo 0;
			return;
		}
		
		$dictionary = Dictionary::GetInstance();
		echo "<p>".$dictionary->Translate("MESSAGE_HAS_BEEN_SENT")."</p>\n";
		
		Responder::GetMessagePanel(0, "list");
	}
	
	public static function GetMessagePanel($messageId, $mode = "list", $sortKey = "points", $sortOrder = "desc", $reciever = "")
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		$panel = new MessagePanel($gamePlan);
		$panel->SetSortKey($sortKey);
		$panel->SetSortOrder($sortOrder);
		
		if (!strcasecmp($mode, "read"))
		{
			$message = Message::LoadFromDB($messageId);
			$panel->SetMessage($message);
		}
		
		if (!strcasecmp($mode, "new") && strlen($reciever) > 0)
		{
			$reciever = Player::LoadFromDB($reciever);
			$panel->SetDefaultReciever($reciever);
		}
		
		$panel->SetMode($mode);	
	
		$panel->RenderContent();
	}
	
	public static function BuyLicence(Player $player = NULL)
	{
		$dictionary = Dictionary::GetInstance();
		
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
		}
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$licencePrice = GameConstants::GetLicencePrice($player);
		$hasMoney = ($licencePrice <= $player->GetMoney());
		
		if (!$hasMoney)
		{
			return sprintf($dictionary->Translate("LICENCE_BUY_NO_MONEY"), $licencePrice, $player->GetMoney());
		}
		
		$res = $player->SetLicenceCount($player->GetLicenceCount() + 1);
		
		if (!$res)
		{
			return $dictionary->Translate("LICENCE_BUY_FAILED");
		}
		
		$player->WriteNewMoney($player->GetMoney() - $licencePrice);
		$logger = new ActionLogger($player);
		$logger->LogLicenceBought($player->GetLicenceCount(), $licencePrice);
		
		return 1;
	}
	
	public static function BuyEmbassyLevel(Player $player = NULL)
	{
		$dictionary = Dictionary::GetInstance();
		
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
		}
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$levelPrice = GameConstants::GetEmbassyLevelPrice($player);
		$hasMoney = ($levelPrice <= $player->GetMoney());
		
		if (!$hasMoney)
		{
			return sprintf($dictionary->Translate("EMBASSY_LEVEL_BUY_NO_MONEY"), $levelPrice, $player->GetMoney());
		}
		
		$res = $player->SetEmbassyLevel($player->GetEmbassyLevel() + 1);
		
		if (!$res)
		{
			return $dictionary->Translate("EMBASSY_LEVEL_BUY_FAILED");
		}
		
		$player->WriteNewMoney($player->GetMoney() - $levelPrice);
		$logger = new ActionLogger($player);
		$logger->LogEmabassyLevelBought($player->GetEmbassyLevel(), $levelPrice);
		
		return 1;
	}	
	
	public static function BuyShipLevel($shipId, Player $player = NULL)
	{
		$dictionary = Dictionary::GetInstance();
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
		}
		$ship = Ship::LoadFromDB($shipId);
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if ($ship == NULL)
		{
			return $dictionary->Translate("SHIP_NOT_FOUND");
		}
		
		if (!GameConstants::IsShipLevelable($ship))
		{
			return $dictionary->Translate("SHIP_NOT_LEVELABLE");
		}
		
		if (!($ship->GetLevel() < GameConstants::CARGO_SHIP_TYPE_MAX_LEVEL))
		{
			return sprintf($dictionary->Translate("MENU_SHIP_MAX_LEVEL_REACHED"), $ship->GetLevel());
		}
		
		$guardCount = count(Utils::GetAssignedGuardians($ship, $player));
		$guardable = $guardCount >= $ship->GetLevel() + 1;
		if (!$guardable)
		{
			return sprintf($dictionary->Translate("MENU_SHIP_LEVEL_NOT_GUARDED"), $guardCount, $ship->GetLevel() + 1);
		}
		
		$levelPrice = GameConstants::GetShipLevelPrice($ship);
		
		if (!($levelPrice <= $player->GetMoney()))
		{
			return sprintf($dictionary->Translate("MENU_SHIP_LEVEL_TOO_EXPENSIVE"), $levelPrice);
		}
		
		$res = $ship->SetLevel($ship->GetLevel() + 1);
		
		if (!$res)
		{
			return $dictionary->Translate("SHIP_UPGRADE_FAILED");
		}
		
		$player->WriteNewMoney($player->GetMoney() - $levelPrice);	
		
		$logger = new ActionLogger($player);
		$logger->LogShipUpgraded($ship, $levelPrice);
		
		return 1;
	}
	
	public static function BuildBase($planetId)
	{
		if ($planetId == NULL)
		{
			return 0;
		}
		
		$planet = Planet::LoadFromDB($planetId);
		
		$player = Globals::GetActivePlayer();
		
		if ($planet == NULL || $player == NULL)
		{
			return 0;
		}
		
		$price = GameConstants::BASE_PRICE;
		
		if ($player->GetMoney() < $price)
		{
			return 0;
		}
		
		$bases = (array)$player->GetBasesForced();
		
		foreach ($bases as $base)
		{
			if ($base->GetPlanetId() == $planet->GetId())
			{
				return 0;
			}
		}
		
		$builtTime = time() + GameTimer::EarthDaysToRealTime(GameConstants::BASE_BUILT_TIME);
		$base = Base::CreateNewBase($player->GetId(), $planet->GetId(), $builtTime);
		
		if ($base == NULL)
		{
			return 0;
		}
		
		$player->WriteNewMoney($player->GetMoney() - $price);
		
		$logger = new ActionLogger($player);
		$logger->LogBaseBought($planet, $price);
		$logger->LogBaseCompleted($planet, $price, $base->GetBuiltTime());
		
		return 1;
	}
	
	public static function BuyShip($modelId, $shipName, Player $player = NULL, SolarSystem $solarSystem = NULL)
	{
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
		}
		
		$model = ShipModel::LoadFromDB($modelId);
		
		if ($player == NULL || $shipName == NULL)
		{
			return NULL;
		}
		
		if ($player->GetMoney() < $model->GetPrice())
		{
			return NULL;
		}
		
		if ($shipName == NULL || strlen($shipName) < 1)
		{
			return NULL;
		}
		
		$licenceUsedCount = Utils::CalculatePlayerUsedLicences($player);
		$hasFreeLicence = ($licenceUsedCount < $player->GetLicenceCount());
		$licenceble = (!$model->GetShipType()->IsLicenceRequired()) || $hasFreeLicence;
		
		if (!$licenceble)
		{
			return NULL;
		}
		
		if ($solarSystem ==NULL)
		{
			$solarSystem = Globals::GetActiveSolarSystem();
		}
		
		$ship = Ship::CreateNewShip($player->GetId(), $model->GetId(), $shipName, $solarSystem->GetId());
		
		if ($ship == NULL)
		{
			return NULL;
		}
		
		$player->WriteNewMoney($player->GetMoney() - $model->GetPrice());	
			
		$planets = (array)$solarSystem->GetPlanets();
		$shipAC = new ShipActionController($player, $ship, $solarSystem);
		$shipAC->DockToPlanet($planets[$player->GetHomePlanetId()]);
		
		$logger = new ActionLogger($player);
		$logger->LogShipBought($ship);
		
		return $ship;
	}
	
	public static function CreateAlliance($allianceName)
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$allianceName = trim($allianceName);
		if ($allianceName == NULL || strlen($allianceName) <= 0)
		{
			return $dictionary->Translate("INVALID_ALLIANCE_NAME");
		}
		
		$alliance = Alliance::CreateNewAlliance($allianceName, $player->GetId());
		
		if ($alliance == NULL)
		{
			return $dictionary->Translate("ALLIANCE_CREATE_FAILED"); 
		}
		
		$player->SetAllianceId($alliance->GetId());
		
		$logger = new ActionLogger($player);
		$logger->LogAllianceCreated($alliance);
		
		return 1;
	}
		
	public static function InvitePlayerToAlliance($invitedLogin)
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$alliance = Alliance::LoadFromDB($player->GetAllianceId());
		if ($player->GetAllianceId() == NULL || ($alliance->GetAdminId() != $player->GetId()))
		{
			return $dictionary->Translate("PLAYER_NOT_IN_ALLIANCE");
		}
		
		if ($invitedLogin == NULL || strlen($invitedLogin = trim($invitedLogin)) <= 0 || ($invited = Player::LoadFromDBByLogin($invitedLogin)) == NULL)
		{
			return $dictionary->Translate("EMBASSY_LOGIN_NOT_FOUND");
		}
		
		if ($invited->GetId() == $player->GetId())
		{
			return $dictionary->Translate("EMBASSY_CANT_INVITE_MYSELF");
		}
		
		if ($invited->GetAllianceId() == $alliance->GetId())
		{
			return $dictionary->Translate("EMBASSY_INVITED_ALREADY_MEMBER");
		}
		
		if (AllianceInvitation::LoadFromDBForInvitedAndAlliance($invited->GetId(), $alliance->GetId()) != NULL)
		{
			return $dictionary->Translate("EMBASSY_MULTIPLE_INVITATION");
		}
		
		$invitation = AllianceInvitation::CreateNew($player->GetAllianceId(), $player->GetId(), $invited->GetId());
		
		if ($invitation == NULL)
		{
			return $dictionary->Translate("EMBASSY_INVITATION_FAILED");
		}
		
		return 1;
	}
	
	public static function LeaveAlliance()
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if ($player->GetAllianceId() == NULL)
		{
			return $dictionary->Translate("EMBASSY_LEAVE_NOT_IN_ALLIANCE");
		}
		
		$alliance = Alliance::LoadFromDB($player->GetAllianceId());
		
		if ($alliance == NULL)
		{
			$player->SetAllianceId(NULL);
			return 1;
		}
		
		$player->SetAllianceId(NULL);
		$logger = new ActionLogger($player);
		$logger->LogAllianceAbandoned($alliance);
		
		if ($alliance->GetAdminId() == $player->GetId())
		{
			$alliance->LoadMembersFromDB();
			$members = (array)$alliance->GetMembersForced();
			
			if (count($members) > 0)
			{
				$alliance->SetAdminId(array_pop($members)->GetId());	
			}
			else
			{
				$alliance->RemoveFromDB();
			}			
		}	
		
		return 1;
	}
	
	public static function KickAllianceMember($memberId, $reason)
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if ($player->GetAllianceId() == NULL || ($alliance = Alliance::LoadFromDB($player->GetAllianceId())) == NULL)
		{
			return $dictionary->Translate("EMBASSY_LEAVE_NOT_IN_ALLIANCE");
		}
		
		if ($player->GetId() != $alliance->GetAdminId())
		{
			return $dictionary->Translate("EMBASSY_YOU_ARE_NOT_ADMIN");
		}
		
		$member = Player::LoadFromDB($memberId);
		if ($member == NULL || $member->GetAllianceId() != $alliance->GetId())
		{
			return $dictionary->Translate("EMBASSY_KICKED_NOT_IN_ALLIANCE");
		}
		
		$member->SetAllianceId(NULL);
		$logger = new ActionLogger($member);
		$logger->LogAllianceKickedMe($alliance, $player, $reason);
		
		return 1;
	}
	
	public static function AllianceDonateMoney($amount, $recieverLogin)
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if ($player->GetAllianceId() == NULL || ($alliance = Alliance::LoadFromDB($player->GetAllianceId())) == NULL)
		{
			return $dictionary->Translate("EMBASSY_LEAVE_NOT_IN_ALLIANCE");
		}
		
		$reciever = Player::LoadFromDBByLogin($recieverLogin);
		if ($reciever == NULL || $reciever->GetAllianceId() != $alliance->GetId())
		{
			return $dictionary->Translate("EMBASSY_KICKED_NOT_IN_ALLIANCE");
		}
		
		if (!is_numeric($amount) || ($amount = intval($amount)) > GameConstants::ALLIANCE_MONEY_DONATE_MAX)
		{
			return $dictionary->Translate("ALLIANCE_MONEY_TOO_HIGH") . GameConstants::ALLIANCE_MONEY_DONATE_MAX;
		}
		
		if ($amount > $player->GetMoney())
		{
			return $dictionary->Translate("ALLIANCE_MONEY_NOT_ENOUGH_MONEY", $amount, $player->GetMoney());
		}
		
		$player->WriteNewMoney($player->GetMoney() - $amount);
		$logger = new ActionLogger($player);
		$logger->LogMoneyDonateSent($reciever, $amount);
		
		$reciever->WriteNewMoney($reciever->GetMoney() + $amount);
		$logger = new ActionLogger($reciever);
		$logger->LogMoneyDonateRecieved($player, $amount);
		
		return 1;
	}
	
	public static function AllianceDonateGuards($donates)
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if ($player->GetAllianceId() == NULL || ($alliance = Alliance::LoadFromDB($player->GetAllianceId())) == NULL)
		{
			return $dictionary->Translate("EMBASSY_LEAVE_NOT_IN_ALLIANCE");
		}
		
		$lines = split("%", $donates);
		
		$successCount = 0;
		
		foreach ($lines as $line)
		{
			$line = trim($line);
			if (strlen($line) <= 0)
			{
				continue;
			}
			
			$args = split(";", $line);
			
			if (count($args) < 2)
			{
				continue;
			}
			
			$guardId = $args[0];
			$recieverLogin = $args[1];
			
			try
			{
				if (($guard = Ship::LoadFromDB($guardId)) == NULL 
					|| $guard->GetModel()->GetShipType()->GetId() != GameConstants::GUARD_SHIP_TYPE_ID
					|| $guard->GetPlayerID() != $player->GetId())	
				{
					continue;
				}
				
				if (($reciever = Player::LoadFromDBByLogin($recieverLogin)) == NULL
					|| $reciever->GetAllianceId() != $alliance->GetId())
				{
					continue;	
				}
			}
			catch (Exception $e)
			{
				continue;
			}
			
			$shipAC = new ShipActionController($player, $guard);
			$shipAC->AssignGuardTask(NULL);
			
			$guard->SetPlayerId($reciever->GetId());
			
			$logger = new ActionLogger($player);
			$logger->LogGuardsDonateSent($reciever, $guard);
			
			$logger = new ActionLogger($reciever);
			$logger->LogGuardsDonateRecieved($player, $guard);
			
			$successCount++;
		}
		
		if ($successCount == 0)
		{
			return $dictionary->Translate("ALLIANCE_DONATE_GUARD_FAILED");
		}
		
		return $successCount;
	}
	
	public static function AnswerAllianceInvitations($invitationId, $accept)
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$invitation = AllianceInvitation::LoadFromDB($invitationId);
		
		if ($invitation == NULL || $invitation->GetInvitedId() != $player->GetId() || ($alliance = Alliance::LoadFromDB($invitation->GetAllianceId())) == NULL)
		{
			if ($alliance == NULL)
			{
				$invitation->RemoveFromDB();
			}
			
			return $dictionary->Translate("EMBASSY_INVITATION_INVALID");
		}
		
		if ($player->GetAllianceId() != NULL)
		{
			return $dictionary->Translate("EMBASSY_PLAYER_ALREADY_IN_ALLIANCE");
		}
		
		if ($accept)
		{
			if (Utils::GetAllianceTotalCapacity($alliance) + $player->GetEmbassyLevel() <= count($alliance->GetMembersForced()))
			{
				return $dictionary->Translate("EMBASSY_ALLIANCE_CAPACITY_FULL");
			}			
			
			$player->SetAllianceId($invitation->GetAllianceId());
			$logger = new ActionLogger($player);
			$logger->LogAllianceJoined($alliance);
		}
		
		$invitation->RemoveFromDB();
		
		return 1;
	}
	
	public static function FlyShipToTarget($targetType, $shipId, $targetId)
	{
		$dictionary = Dictionary::GetInstance();
		$solarSystem = Globals::GetActiveSolarSystem();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if (!strcasecmp($targetType, "planet"))
		{
			$planets = (array)$solarSystem->GetPlanets();
			$target = $planets[$targetId];
		}
		else if (!strcasecmp($targetType, "wormhole"))
		{
			$wormholes = (array)$solarSystem->GetWormHolesForced();
			$target = $wormholes[$targetId];
		}		
			
		if ($target == NULL)
		{
			return $dictionary->Translate("FLY_TARGET_NOT_FOUND");
		}
		
		$playerShips = (array)$player->GetShipsForced();
		$found = false;
		
		foreach ($playerShips as $ship)
		{
			if ($ship->GetId() == $shipId)
			{
				$found = true;
				break;
			}
		}
		
		if (!$found)
		{
			return $dictionary->Translate("SHIP_NOT_FOUND");
		}
			
		$shipAC = new ShipActionController($player, $ship, $solarSystem);
		
		if(!$shipAC->IsWaiting())
		{	
			$res = $dictionary->Translate("SHIP_IN_NOT_WAITING");
			if ($shipAC->IsGuarding())
			{
				$res .= " " . $dictionary->Translate("SHIP_IS GUARDING");
			}
			
			return $res;
		}
			
		if (!strcasecmp($targetType, "planet"))
		{
			$res = $shipAC->EnqueFlyToPlanet($target);
			$logger = new ActionLogger($player);
			$logger->LogShipFlown($ship, $target);
		}
		else if (!strcasecmp($targetType, "wormhole"))
		{
			$otherSystem = SolarSystem::LoadFromDB($target->GetOtherSystemId($ship->GetSolarSystemId()));
			$res = $shipAC->EnqueFlyToWormhole($target);
			$res &= $shipAC->EnqueTravelThroughWormhole($target);		
			$logger = new ActionLogger($player);
			$logger->LogShipFlownToWormHole($ship, $otherSystem->GetName());	
		}	
		
		return $res ? 1 : 0;
	}
	
	public static function NavigateShip($shipId, $pathA)
	{
		$dictionary = Dictionary::GetInstance();
		$solarSystem = Globals::GetActiveSolarSystem();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$ship = Ship::LoadFromDB($shipId);
		
		if ($ship->GetPlayerID() != $player->GetId())
		{
			return $dictionary->Translate("SHIP_NOT_FOUND");
		}
		
		$currentSystem = SolarSystem::LoadFromDB($ship->GetSolarSystemId());
		
		$shipAC = new ShipActionController($player, $ship, $currentSystem);
		
		if(!$shipAC->IsWaiting())
		{	
			$res = $dictionary->Translate("SHIP_IN_NOT_WAITING");
			if ($shipAC->IsGuarding())
			{
				$res .= " " . $dictionary->Translate("SHIP_IS GUARDING");
			}
			
			return $res;
		}
		
		$wormHoles = array();
		$systems = array();
		
		$systemIds = split(";", $pathA);
		foreach ($systemIds as $systemId)
		{
			$systemId = trim($systemId);
			if (strlen($systemId) <= 0)
			{
				continue;
			}
			
			$nextSystem = SolarSystem::LoadFromDB($systemId);
			
			$wormHole = Utils::FindSystemConnectionWormHole($currentSystem, $nextSystem);
			
			if ($wormHole == NULL)
			{
				return $dictionary->Translate("NAVIGATE_PATH_INVALID");
			}
			
			array_push($wormHoles, $wormHole);
			array_push($systems, $nextSystem);
			$currentSystem = $nextSystem;
		}
		
		$res = true;
		
		$logger = new ActionLogger($player);
		
		for ($i = 0; $i < count($wormHoles); $i++)
		{
			$res &= $shipAC->EnqueFlyToWormhole($wormHoles[$i]);
			$res &= $shipAC->EnqueTravelThroughWormhole($wormHoles[$i]);	
			
			if ($i == (count($wormHoles) - 1))
			{	
				$logger->LogShipFlownToWormHole($ship, $systems[$i]->GetName());
			}
		}
		
		return $res ? 1 : 0;
	}
	
	public static function DeliverDelivery($shipId, $deliveryId, $ignoreShipBusy = false)
	{
		$dictionary = Dictionary::GetInstance();
		$solarSystem = Globals::GetActiveSolarSystem();
		$player = Globals::GetActivePlayer();
		$delivery = Delivery::LoadFromDB($deliveryId);
		
		$sourcePlanetId = $delivery->GetLocationID();
	
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		if ($delivery == NULL)
		{
			return $dictionary->Translate("DELIVERY_NOT_FOUND_IN_DB");	
		}
		
		if ($delivery->IsHidden())
		{
			return $dictionary->Translate("DELIVERY_HIDDEN");
		}
		
		$ship = NULL;
		$ships = (array)$player->GetShipsForced();
		
		if (!array_key_exists($shipId, $ships))
		{
			return $dictionary->Translate("SHIP_NOT_PLAYERS");
		}
		
		$ship = $ships[$shipId];
		
		$shipAction = new ShipActionController($player, $ship, $solarSystem);
		if (!$shipAction->CanBeDelivered($delivery))
		{
			return $dictionary->Translate("DELIVERY_CANNOT_BE_DELIVERED_BY_SHIP");
		}
		
		if (!$shipAction->IsWaiting() && !$ignoreShipBusy)
		{
			return $dictionary->Translate("DELIVERY_SHIP_BUSY");
		}
		
		try
		{
			if (!$shipAction->EnqueDeliverDelivery($delivery))
			{
				return $dictionary->Translate("DELIVERY_FAIL");
			}
			
			$planets = (array)$solarSystem->GetPlanets();
			$planet = $planets[$sourcePlanetId];
			$logger = new ActionLogger($player);
			$logger->LogDeliveryStarted($ship, $planet, $delivery);
		}
		catch (Exception $e)
		{
			return $dictionary->Translate("DELIVERY_FAIL");
		}
			
		$deliveries = (array)$planet->GetDeliveriesForced();
		
		if (count($deliveries) < GameConstants::LIMIT_FOR_DELIVERY_REFILL)
		{
			$gameUpdater = new GameUpdater($solarSystem);
		
			$gameUpdater->PlayPCPlayer();
			$gameUpdater->CheckDeliveriesOnPlanet($planet);
		}
		
		return 1;
	}
	
	public static function FinishDeliveries($shipId)
	{
		$dictionary = Dictionary::GetInstance();
		$solarSystem = Globals::GetActiveSolarSystem();
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return $dictionary->Translate("PLAYER_NOT_LOGGED");
		}
		
		$ship = NULL;
		$ships = (array)$player->GetShipsForced();
		
		if (!array_key_exists($shipId, $ships))
		{
			return $dictionary->Translate("SHIP_NOT_PLAYERS");
		}
		
		$ship = $ships[$shipId];
		
		if ($ship->GetModel()->GetShipType()->GetId() != GameConstants::CARGO_SHIP_TYPE_ID)
		{
			return $dictionary->Translate("SHIP_NOT_CARGO");
		}
		
		$shipAC = new ShipActionController($player, $ship);
		
		try
		{			
			$deliveries = $ship->GetDeliveriesForced();
			$first = true;
			if (count($deliveries) < 1)
			{
				return $dictionary->Translate("SHIP_HAS_NO_DELIVERIES");
			}
					
			foreach ($deliveries as $delivery)
			{
				if ($first)
				{
					$targetPlanet =  Planet::LoadFromDB($delivery->GetTargetPlanetID());
					$shipAC->EnqueFlyToPlanet($targetPlanet);
					$logger = new ActionLogger($player);
					$logger->LogShipFlown($ship,$targetPlanet);
					$first = false;
				}	
				
				$shipAC->EnqueUnload($delivery);
			}
		}
		catch (Excetion $e)
		{
			return $dictionary->Translate("DELIVERY_FAIL");
		}
		
		return 1;
	}
	
	public static function GetLogViewPanel($rowCount = 50)
	{
		$player = Globals::GetActivePlayer();
	
		$panel = new LogViewPanel($player);
		$panel->SetRowCount($rowCount);
	
		$panel->RenderContent();
	}
	
	public static function GetPlanetGraphic($planetId, $planetGraphicId)
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
		$planets = (array) $solarSystem->GetPlanets();
		$planet = $planets[$planetId];
		
		if ($planet == NULL)
		{
			echo 0;
			return;
		}
	
		$planetGraphic = new PlanetGraphic($planet, $gamePlan);
		$planetGraphic->SetHtmlId($planetGraphicId);
	
		$planetGraphic->RenderContent();
	}
	
	public static function GetShipGraphic($shipId)
	{
		$ship = Ship::LoadFromDB($shipId);
		
		$gamePlan = new GamePlan(SolarSystem::LoadFromDB($ship->GetSolarSystemId()));
		$gamePlan->SetWidth(Globals::GetGamePlanSize());
		$gamePlan->SetHeight(Globals::GetGamePlanSize());
		
		$graphic = new ShipGraphic($ship, $gamePlan);
		$graphic->Render();
	}
	
	public static function GetPlanetInfoPanel($planetId)
	{
		$planet = Planet::LoadFromDB($planetId);
		
		if ($planet == NULL)
		{
			echo 0;
			return;
		}
		
		$solarSystem = SolarSystem::LoadFromDB($planet->GetSolarSystemId());
		$gamePlan = new GamePlan($solarSystem);
		
		$planetInfo = new PlanetInfoPanel(new PlanetGraphic($planet, $gamePlan), $gamePlan);	
		$planetInfo->RenderContent();
	}
	
	public static function GetHighScorePanel($sortKey = "points", $sortOrder = "desc")
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		$panel = new HighScorePanel($gamePlan);
		$panel->SetSortKey($sortKey);
		$panel->SetSortOrder($sortOrder);
	
		$panel->RenderContent();
	}
	
	public static function GetShipShopPanel()
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		$panel = new ShipShopPanel($gamePlan);
	
		$panel->RenderContent();
	}
	
	public static function GetGuardAssignmentPanel()
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		$panel = new GuardAssignmentPanel($gamePlan);
	
		$panel->RenderContent();
	}
	
	public static function GetPlanetHomePlayersPanel($planetId)
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		$planets = (array)$solarSystem->GetPlanets();
		$panel = new PlanetHomePlayersPanel($gamePlan, $planets[$planetId]);
	
		$panel->RenderContent();
	}
	
	public static function GetShipSelectionPanel($deliveryId)
	{
		$solarSystem = Globals::GetActiveSolarSystem();
	
		$player = Globals::GetActivePlayer();
		if ($player != NULL)
		{
			$ships = (array)$player->GetShipsForced();
			foreach ($ships as $ship)
			{
				$shipAC = new ShipActionController($player, $ship, $solarSystem);
				$shipAC->UpdateState();
			}
		}
	
		$gamePlan = new GamePlan($solarSystem);
	
		$delivery = Delivery::LoadFromDB($deliveryId);
		$panel = new ShipSelectionPanel($gamePlan, $delivery);
	
		$panel->RenderContent();
	}
	
	public static function GetEmbassyPanel()
	{
		$player = Globals::GetActivePlayer();
		$panel = new EmbassyPanel(NULL, $player);
		$panel->RenderContent();
	}
	
	public static function GetAllianceTransferPanel()
	{
		$player = Globals::GetActivePlayer();
		$panel = new AllianceTransferPanel(NULL, $player);
		$panel->RenderContent();
	}	
	
	public static function GetGalaxyMap($gamePlanSize, $shipId = NULL, $deliveryId = NULL, $targetSystemId = NULL)
	{		
		$ship = $shipId ? Ship::LoadFromDB($shipId) : NULL;
		$delivery = $deliveryId ? Delivery::LoadFromDB($deliveryId) : NULL;
		$targetSystem = $targetSystemId ? SolarSystem::LoadFromDB($targetSystemId) : NULL;
		
		$galaxyMap = new GalaxyMap(NULL, $ship, $delivery, $targetSystem);
		$galaxyMap->SetWidth($gamePlanSize[0]);
		$galaxyMap->SetHeight($gamePlanSize[1]);
		$galaxyMap->RenderContent();		
	}
	
	public static function GetDeliveryPanel($planetId, $sortKey = "points", $sortOrder = "desc")
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		$planets = (array)$solarSystem->GetPlanets();
		$panel = new DeliveryPanel($gamePlan, $planets[$planetId]);
		$panel->SetSortKey($sortKey);
		$panel->SetSortOrder($sortOrder);
	
		$panel->RenderContent();
	}
	
	public static function GetMenu($itemId, $selectionType)
	{
		$solarSystem = Globals::GetActiveSolarSystem();
		$gamePlan = new GamePlan($solarSystem);
	
		if ($selectionType == "planet")
		{
			$planets = (array)$solarSystem->GetPlanets();
			$menu = new MenuPanel($gamePlan, $planets[$itemId]);
		}
		else if ($selectionType == "ship")
		{
			$ship = Ship::LoadFromDB($itemId);
			$shipAC = new ShipActionController(Globals::GetActivePlayer(), $ship, $solarSystem);
			$shipAC->UpdateState();
			$menu = new MenuPanel($gamePlan);
			$menu->SetShip($ship);
		}
		else if ($selectionType == "sun")
		{
			$menu = new MenuPanel($gamePlan);
			$menu->SetSunMode(true);
		}
		else
		{
			$menu = new MenuPanel($gamePlan);
		}
	
		$menu->SetWidth(DesignConstants::RIGHT_PANEL_WIDTH);
		$menu->RenderContent();
	}
	
	// responds planet id;oldX;oldY;newX;newY;ratio within day$ for each planet;visible;stateCode
	public static function GetPlanetPositions($gamePlanSize)
	{
		$solarSystem = Globals::GetActiveSolarSystem();
	
		$gamePlan = new GamePlan($solarSystem);
		$gamePlan->SetWidth($gamePlanSize[0]);
		$gamePlan->SetHeight($gamePlanSize[1]);
	
		$planets = (array)$solarSystem->GetPlanets();
	
		foreach ($planets as $planet)
		{
			$finalCoordinates = $gamePlan->WorldToScreenCoords($planet->GetWorldX(), $planet->GetWorldY());
			echo $planet->GetId() . ";" . $finalCoordinates[0] . ";" .$finalCoordinates[1];
	
			$nextCoords = (array)$planet->GetNextPositionFromDB();
			$finalCoordinates = $gamePlan->WorldToScreenCoords($nextCoords[0], $nextCoords[1]);
			echo ";" . $finalCoordinates[0] . ";" .$finalCoordinates[1];
			echo ";" . GameTimer::GetCurrentDayRatio();
			echo ";true";
			echo ";" . Utils::GetPlanetStateCode($planet, NULL, $solarSystem);
			echo "$";
		}
	}
	
	// responds ship id;oldX;oldY;newX;newY;ratio within day$ for each planet;visible;stateCode
	public static function GetShipPositions($gamePlanSize)
	{
		$startDay = GameTimer::GetDaysElapsed();
		$elapsedTime = GameTimer::SECONDS_IN_DAY;
		
		$solarSystem = Globals::GetActiveSolarSystem();
	
		$gamePlan = new GamePlan($solarSystem);
		$gamePlan->SetWidth($gamePlanSize[0]);
		$gamePlan->SetHeight($gamePlanSize[1]);
	
		$player = Globals::GetActivePlayer();
		if ($player == NULL)
		{
			return;
		}
	
		$ships = (array)$player->GetShipsForced();
		foreach ($ships as $ship)
		{		
			$shipAC = new ShipActionController($player, $ship, $solarSystem);
			$shipAC->UpdateState();
			
			if ($ship->GetSolarSystemId() != $solarSystem->GetId())
			{
				continue;
			}
					
			$finalCoordinates = $gamePlan->WorldToScreenCoords($ship->GetX(), $ship->GetY());
			echo $ship->GetId() . ";" . $finalCoordinates[0] . ";" .$finalCoordinates[1];
	
			$target = $shipAC->GetTargetObject();
			$flighter = new FlightController($shipAC);		
			
			if ($target != NULL)
			{ 
				$flyRes = $flighter->FlyToTarget($target, $startDay, $elapsedTime);
				$path = (array)$flyRes[1];
				$nextCoords = (array)array_pop($path);
				$finalCoordinates = $gamePlan->WorldToScreenCoords($nextCoords[0], $nextCoords[1]);
			}
			
			echo ";" . $finalCoordinates[0] . ";" .$finalCoordinates[1];
			echo ";" . GameTimer::GetCurrentDayRatio();
			
			
			if ($ship->GetModel()->GetShipType()->GetId() == GameConstants::GUARD_SHIP_TYPE_ID)
			{
				$visible = false;
			}
			else if ($shipAC->GetDockedPlanet() == null)
			{
				$visible = true;
			}
			else
			{
				$visible = false;
			}
			
			echo ";" . ($visible ? "true" : "false");
			echo "$";
		}
	}
	
	public static function Login($login, $password, $panelWidth, $panelId)
	{
		if ($login == NULL || $password == NULL)
		{
			return;
		}
			
		$dictionary = Dictionary::GetInstance();
	
		$player = Player::LoadFromDBByLogin($login);
		$loginPanel = new LoginPanel($player);
		$loginPanel->SetWidth($panelWidth);
		$loginPanel->SetHtmlId($panelId);
	
		if ($player == NULL || (strcmp($player->GetPasswordHash(), $password) != 0))
		{
			$loginPanel->SetErrorMessage($dictionary->Translate("WRONG_PSSWD"));
			$loginPanel->SetPlayer(NULL);
			echo 0;
			$loginPanel->RenderContentOnly();
			return;		
		}
		
		if ($player->HasFlag("delete"))
		{
			$timeOfDeath = $player->GetFlagValues("delete");
			$timeOfDeath = $timeOfDeath[1];
			if (intval($timeOfDeath) < time())
			{
				$player->RemoveFromDB();
				
				$loginPanel->SetErrorMessage($dictionary->Translate("WRONG_PSSWD"));
				$loginPanel->SetPlayer(NULL);
				echo 0;
				$loginPanel->RenderContentOnly();
				return;
			} 
			else
			{
				$player->SetFlag("delete", false);
			}
		}
		
		if (!$player->IsActive())
		{
			$loginPanel->SetErrorMessage($dictionary->Translate("PLAYER_NOT_ACTIVATED"));
			$loginPanel->SetPlayer(NULL);
			echo 0;
			$loginPanel->RenderContentOnly();
			return;
		}
	
		$player->NoticeLoginTime();
		Globals::SetActivePlayer($player);
		Globals::SetLanguage($player->GetLanguage());
		echo 1;
		$loginPanel->RenderContentOnly();
		
		$logger = new ActionLogger($player);
		$logger->LogLoggedIn();
	}
	
	public static function SetLanguage($languageCode)
	{
		Globals::SetLanguage($languageCode);
	
		$player = Globals::GetActivePlayer();
		if ($player != NULL)
		{
			$player->SetLanguage(Globals::GetLanguage());
		}
	}
	
	public static function TranslateTerm($termName)
	{
		$dictionary = Dictionary::GetInstance();
		echo $dictionary->Translate($termName);
	}
	
	public static function Logout()
	{
		$player = Globals::GetActivePlayer();
		
		if ($player == NULL)
		{
			return;
		}
		
		Globals::SetActivePlayer(NULL);
		
		$logger = new ActionLogger($player);
		$logger->LogLoggedOut();
	}
	
	public static function UpdateGame()
	{
		srand(time());
	
		$solarSystem = Globals::GetActiveSolarSystem();
		$gameUpdater = new GameUpdater($solarSystem);
		
		$gameUpdater->PlayPCPlayer();
		$gameUpdater->CheckDeliveries();
	}
	
	
}
?>
