<?php 

require_once("Control/Dictionary.inc");
require_once("Control/Globals.inc");
require_once("Control/GameConstants.inc");
require_once("Control/ShipActionController.inc");
require_once("Model/Player.inc");
require_once("Model/Ship.inc");
require_once("Model/Delivery.inc");
require_once("Model/Alliance.inc");

class Utils
{
	private function __construct()
	{
		
	}
	
	public static function GenerateRandomString($length = 10) 
	{
	    $characters = '0123456789abcdefghijklmnopqrstuvwxyz';
	    $string = "";    	
	
	    for ($p = 0; $p < $length; $p++) 
	    {
	        $string .= $characters[mt_rand(0, strlen($characters))];
	    }

    	return $string;
	}
	
	public static function GetVector2Length(array $vector)
	{
		return sqrt(Utils::GetDotProduct2D($vector, $vector));
	}
	
	public static function Cross3($a, $b)
	{
		$res = array();
		$res[0] = -$a[2] * $b[1] + $a[1] * $b[2];
		$res[1] = $a[2] * $b[0] - $a[0] * $b[2];
		$res[2] = -$a[1] * $b[0] + $a[0] * $b[1];
		return $res;
	}
	
	public static function GetDotProduct2D(array $v1, array $v2)
	{
		return $v1[0] * $v2[0] + $v1[1] * $v2[1];
	}
	
	public static function AddVertices2(array $v1, array $v2)
	{
		$res = array();
		$res[0] = $v1[0] + $v2[0];
		$res[1] = $v1[1] + $v2[1];
		return $res;
	}
	
	public static function SubtractVertices2(array $v1, array $v2)
	{
		$res = array();
		$res[0] = $v1[0] - $v2[0];
		$res[1] = $v1[1] - $v2[1];
		return $res;
	}
	
	public static function MultiplyVertex2(array $v, $factor)
	{
		$res = array();
		$res[0] = $v[0] * $factor;
		$res[1] = $v[1] * $factor;
		return $res;
	}
	
	public static function GetLineParams(array $startPoint, array $endPoint)
	{
		$dir = Utils::SubtractVertices2($endPoint, $startPoint);
		
		$temp = $dir[0];
		$dir[0] = $dir[1];
		$dir[1] = -$temp;
		
		$dir[2] = -Utils::GetDotProduct2D($dir, $startPoint);
		return $dir;
	}
	
	public static function GetPointDistanceFromLine2D(array $point, array $lineStart, array $lineEnd)
	{
		$dir = Utils::SubtractVertices2($lineEnd, $lineStart);
		
		$normal = array();
		$normal[0] = $dir[1];
		$normal[1] = -$dir[0];
		
		$c = -Utils::GetDotProduct2D($normal, $lineStart);		
		$normSize = Utils::GetVector2Length($normal);
		
		$distFromLine = (Utils::GetDotProduct2D($normal, $point) + $c) / $normSize;
		// TODO finish		
	}	
	
	public static function GetNearestDistanceBetweenLines2D(array $startA, array $endA, array $startB, array $endB)	
	{
		/*$lineA = Utils::GetLineParams($startA, $endA);
		$lineB = Utils::GetLineParams($startB, $endB);
		
		$intersection = Utils::Cross3($lineA, $lineB);
		$intersection = Utils::MultiplyVertex2($intersection, 1 / $intersection[2]);*/
		
		//TODO complete
		
		return 9e99;
	}
	
	public static function GetDateTimeString($time)
	{
		$dictionary = Dictionary::GetInstance();
		$dateFormat = $dictionary->TRANSLATE("DATETIME_FORMAT");
		return date($dateFormat, $time);		
	}
	
	public static function GetFibbonaci($arg)
	{
		if ($arg <= 0)
		{
			return NULL;
		}
		
		$numbers = array(1 => 1, 2 => 1);
		
		for ($i = 3; $i <= $arg; $i++)
		{
			$numbers[$i] = $numbers[$i - 2] + $numbers[$i - 1];
		}
		
		return $numbers[$arg];
	}
	
	public static function GetAssignedGuardians(Ship $cargoShip, Player $player = NULL)
	{
		if ($player == NULL)
		{
			$player = Player::LoadFromDB($cargoShip->GetPlayerID());
		}
		
		if ($cargoShip->GetModel()->GetShipType()->GetId() != GameConstants::CARGO_SHIP_TYPE_ID)
		{
			return 0;
		}
		
		$ships = (array)$player->GetShipsForced();
		$guards = array();
		
		foreach ($ships as $guard)
		{
			if ($guard->GetModel()->GetShipType()->GetId() != GameConstants::GUARD_SHIP_TYPE_ID)
			{
				continue;
			}
			
			$shipAC = new ShipActionController($player, $guard, Globals::GetActiveSolarSystem());
			if ($shipAC->GetGuardedShipId() == $cargoShip->GetId())
			{
				$guards[$guard->GetId()] = $guard;
			}
		}
		
		return $guards;
	}
	
	
	public static function CalculatePlayerUsedLicences(Player $player)
	{
		$sum = 0;
		$ships = (array)$player->GetShipsForced();
		foreach ($ships as $ship)
		{
			$type = $ship->GetModel()->GetShipType();
			if ($type->IsLicenceRequired())
			{
				$sum ++;
			}
		}	
		
		return $sum;
	}
	
	public static function CountPlayerPoints(Player $player)
	{
		$points = 0;
		
		$ships = (array) $player->GetShipsForced();
		foreach ($ships as $ship)
		{
			$points += GameConstants::GetShipPointValue($ship);
		}
		
		$bases = (array)$player->GetBasesForced();
		$buildingCount = count($bases);
		$points += $buildingCount * GameConstants::POINTS_FOR_BASE;
		
		return $points;
	}
	
	public static function GetPlayerRank(Player $player)
	{
		$players = Player::LoadAllFromDB();
		
		$order = array();
		
		foreach ($players as $playerTemp)
		{
			$order[sprintf("%10d", Utils::CountPlayerPoints($playerTemp)) . "_" . $playerTemp->GetLogin()] = $playerTemp;
		}
		
		krsort($order);
		
		$i = 0;
		
		foreach ($order as $playerTemp)
		{
			if ($playerTemp->GetId() == $player->GetId())
			{
				return $i + 1;	
			}
			
			$i++;
		}
		
		return count($order);		
	}
	
	public static function CountPlayerDeliveries(Player $player)
	{
		$count = 0;
		$ships = (array) $player->GetShipsForced();
		foreach ($ships as $ship)
		{
			$count += $ship->GetDeliveryDoneCount();
		}
		
		return $count;
	}
	
	public static function GetRandomProbability($seed = false)
	{
		if ($seed)
		{
			srand(time());
			mt_srand(time() + rand(0, getrandmax()));
		}
		
		return mt_rand(0, mt_getrandmax()) / floatval(mt_getrandmax());
	}
	
	public static function GetAllianceTotalCapacity(Alliance $alliance)
	{
		$members = (array)$alliance->GetMembersForced();
		
		$totalEmbassyLevel = 0;
		
		foreach ($members as $member)
		{
			$totalEmbassyLevel += $member->GetEmbassyLevel();
		}
		
		return $totalEmbassyLevel;
	}
	
	public static function HasPlayersAllianceDockOnPlanet(Player $player, Planet $planet)
	{
		if ($player->GetAllianceId() != NULL)
		{
			$members = (array)Alliance::LoadFromDB($player->GetAllianceId())->GetMembersForced();	
		}
		else
		{
			$members = array(0 => $player);
		}
		
		foreach ($members as $member)
		{
			$bases = (array)$member->GetBasesForced();
			foreach ($bases as $base)
			{
				if ($base->GetPlanetId() == $planet->GetId())
				{
					return true;
				}
			}
		}
		
		return false;
	}
	
	public static function GetPlayersAlliancePirateRelations(Player $player)
	{
		if ($player->GetAllianceId() != NULL)
		{
			$members = (array)Alliance::LoadFromDB($player->GetAllianceId())->GetMembersForced();	
		}
		else
		{
			$members = array(0 => $player);
		}
		
		$totalRel = 0;
		
		foreach ($members as $member)
		{
			$totalRel += $member->GetPirateRelations();
		}
		
		return $totalRel;
	}
	
	public static function CountShipDeliveriesPrice(Ship $ship)
	{
		$deliveries = (array) $ship->GetDeliveriesForced();
		
		$sum = 0;
		
		foreach ($deliveries as $delivery)
		{
			$sum += $delivery->GetPrice();
		}
		
		return $sum;
	}
	
	public static function FindSystemConnectionWormHole(SolarSystem $systemA, SolarSystem $systemB)
	{
		$wormHolesA = $systemA->GetWormHolesForced();
		
		foreach ($wormHolesA as $wormHole)
		{
			if ($wormHole->GetOtherSystemId($systemA->GetId()) == $systemB->GetId())
			{
				return $wormHole;
			}
		}
		
		return NULL;
	}
	
	public static function GetPlanetStateCode(Planet $planet, Player $player = NULL, $solarSystem = NULL)
	{
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
			
			if ($player == NULL)
			{
				return -1;
			}	
		}
		
		$dlzState = 0;		
		
		if ($player->GetHomePlanetId() == $planet->GetId())
		{
			$dlzState |= 32;
		}
	
		$found = false;
		$bases = (array)$player->GetBasesForced();
		foreach ($bases as $base)
		{
			if ($base->GetPlanetId() == $planet->GetId())
			{
				$found = true;
				break;
			}
		}
					
		if ($found)
		{
			if ($base->GetBuiltTime() > time())
			{
				$dlzState |= 1;
			}
			else 
			{
				$dlzState |= 2;
			}
		}
		
		$ships = (array)$player->GetShipsForced();
		foreach ($ships as $ship)
		{
			if ($ship->GetModel()->GetShipType()->GetId() == GameConstants::GUARD_SHIP_TYPE_ID)
			{
				continue;
			}
				
			$shipAC = new ShipActionController($player, $ship, $solarSystem);
			$dockedPlanet = $shipAC->GetDockedPlanet();
			if ($dockedPlanet != NULL && $dockedPlanet->GetId() == $planet->GetId())
			{
				$dlzState |= 8;
				break;
			}
		}
		
		return $dlzState;
		
	}
}
?>