<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");

/**
 * 
 * Image of DB entity "hraci_online".
 */
class ActivationRecord
{
	private $id;	
	
	public function GetId()
	{
		return $this->id;		
	}
	
	/**
	 * Name of good.
	 */
	private $playerID;
	
	private $controlHash;
	
	public function GetControlHash()
	{
		return $this->controlHash;		
	}
	
	private $createTime;
	
	public function GetCreateTime()
	{
		return $this->createTime;		
	}
	
	/**
	 * Creates new instance with specified ID.
	 * @param id ID of new instance
	 */
	private function __construct($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$this->id = $id;
	}
	
	/**
	 * Loads from DB using ID.
	 * @param id ID of good in DB
	 */
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE id=%d", DBConstants::ACTIVATION_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		return ActivationRecord::ParseDBRow($data);
	}
	
	public static function LoadActivationForPlayer(Player $player)
	{
		if ($player == NULL)
		{
			throw new Exception("Player must be valid instance.");
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE player_id=%d", DBConstants::ACTIVATION_TABLE_NAME, $player->GetId());
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		return ActivationRecord::ParseDBRow($data);
	}
	
	private static function ParseDBRow($row)
	{
		$record = new ActivationRecord($row["ID"]);
		
		$record->playerID = $row["player_id"];
		$record->controlHash = $row["control_hash"];
		$record->createTime = $row["create_time"];
		
		return $record;
	}
	
	public static function CreateActivation(Player $player)
	{
		if ($player == NULL)
		{
			throw new Exception("Player must be valid instance.");
		}
		
		if (ActivationRecord::LoadActivationForPlayer($player) != NULL)
		{
			throw new Exception("Activation for player has already been created.");
		}
		
		$dbManager = DBManager::GetInstance();
		
		mt_srand(time());
		$hash = md5("".rand(0, mt_getrandmax()));

		$query = sprintf("INSERT INTO `%s` (player_id, control_hash, create_time) VALUES (%d, '%s', %d)", 
			DBConstants::ACTIVATION_TABLE_NAME, $player->GetId(), $hash, time());
		$data = $dbManager->PerformQuery($query);
		
		$id = $dbManager->GetLastId();
		return ActivationRecord::LoadFromDB($id);
	}
	
	/**
	 * Removes this record from DB.
	 * @return true on success
	 */
	public function RemoveFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("DELETE FROM `%s` WHERE ID=%d", DBConstants::ACTIVATION_TABLE_NAME, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		return 1;
	}
	
	public static function RemoveExpired($expirationLength)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("DELETE FROM `%s` WHERE create_time <= %d", DBConstants::ACTIVATION_TABLE_NAME, time() - $expirationLength);
		$data = $dbManager->PerformQuery($query);
		
		return true;
	}
}

?>