<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Model/Player.inc");

class Alliance
{
	/**
	 * ID of good type in DB.
	 */
	private $id;
	
	/**
	 * Gets ID of good type in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
		
	private $name;
	
	public function GetName()
	{
		return $this->name;
	}
	
	private $creatorId;
	
	public function GetCreatorId()
	{
		return $this->creatorId;
	}
	
	private $adminId;
	
	public function GetAdminId()
	{
		return $this->adminId;
	}
	
	public function SetAdminId($id)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET admin_id='%d' WHERE ID=%d", DBConstants::ALLIANCE_TABLE_NAME, $id, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->adminId = $id;
		
		return true;
	}
	
	private $time;
	
	public function GetTime()
	{
		return $this->time;
	}
		
	private $members;
	
	/**
	 * Gets array of player's messages with their IDs as keys.
	 * May return null if not loaded yet - it is loaded separately
	 * to save performance when no ships are needed - i.e. when just
	 * retrieving account state.
	 */
	public function GetMembers()
	{
		return $this->members;
	}
	
	/**
	 * Gets messages for player.
	 * Reads from DB if necessary.
	 * @return bases for player
	 */
	public function GetMembersForced()
	{
		if ($this->members == NULL)
		{
			$this->LoadMembersFromDB();
		}
		
		return $this->members;
	}
	
	private $invitations;
	
	/**
	 * Gets array of player's messages with their IDs as keys.
	 * May return null if not loaded yet - it is loaded separately
	 * to save performance when no ships are needed - i.e. when just
	 * retrieving account state.
	 */
	public function GetInvitations()
	{
		return $this->invitations;
	}
	
	/**
	 * Gets messages for player.
	 * Reads from DB if necessary.
	 * @return bases for player
	 */
	public function GetInvitationsForced()
	{
		if ($this->invitations == NULL)
		{
			$this->LoadInvitationsFromDB();
		}
		
		return $this->invitations;
	}
			
	/**
	 * Creates new instance with specified ID.
	 * @param id ID of new instance
	 */
	private function __construct($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$this->id = $id;
	}
	
	/**
	 * Loads from DB using ID.
	 * @param id ID of good in DB
	 */
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE id=%d", DBConstants::ALLIANCE_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		$alliance = new Alliance($data["id"]);
		$alliance->name = $data["name"];
		$alliance->creatorId = $data["creator_id"];
		$alliance->adminId = $data["admin_id"];
		$alliance->time = $data["time"];
		
		return $alliance;
	}
	
	public static function CreateNewAlliance($name, $creatorId)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("INSERT INTO `%s` (name, creator_id, admin_id, time) ", DBConstants::ALLIANCE_TABLE_NAME);
		$query .= sprintf("VALUES ('%s', %d, %d, %d)", $name, $creatorId, $creatorId, time());
		
		$dbManager->PerformQuery($query);
		
		$id = mysql_insert_id();
		
		if ($id <= 0)
		{
			return NULL;
		}
		
		return Alliance::LoadFromDB($id);
	}
	
	public function LoadMembersFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT id FROM `%s` WHERE alliance_id=%d", DBConstants::PLAYER_TABLE_NAME, $this->id);
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->members = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			$member = Player::LoadFromDB($row["id"]);
			$this->members[$member->GetId()] = $member;
		}
	}
	
	public function LoadInvitationsFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT id FROM `%s` WHERE alliance_id=%d", DBConstants::ALLIANCE_INVITATION_TABLE_NAME, $this->id);
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->invitations = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			$invitation = AllianceInvitation::LoadFromDB($row["id"]);
			$this->invitations[$invitation->GetId()] = $invitation;
		}
	}
	
	public function RemoveFromDB()
	{
		$this->LoadMembersFromDB();
		$members = $this->GetMembersForced();
		
		foreach ($members as $member)
		{
			$member->SetAllianceId(NULL);
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("DELETE FROM `%s` WHERE id=%d", DBConstants::ALLIANCE_TABLE_NAME, $this->id);
		$dbManager->PerformQuery($query);
		
		return 1;
	}
}

?>