<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Model/GoodType.inc");
require_once("Model/Planet.inc");

/**
 * Delivery task located on planet.
 * Image of DB entity "zasilky".
 */
class Delivery
{
	/**
	 * ID of task as in DB.
	 */
	private $id;
	
	/**
	 * Gets ID of task as in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
	
	/**
	 * ID of start planet or ship depending on location.
	 */
	private $locationID;
	
	/**
	 * Gets location ID. Positive
	 * values for planets, negative for ships.
	 */
	public function GetLocationID()
	{
		return $this->locationID;
	}
	
	/**
	 * Writes new location ID to DB. Positive
	 * values for planets, negative for ships.
	 * @param $locationId new id or pseudoid (negated id)
	 * @return unknown_type true on success
	 */
	public function WriteNewLocationID($locationId)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET planeta=%d WHERE ID=%d", DBConstants::DELIVERY_TABLE_NAME, $locationId, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->locationID = $locationId;
		
		return true;
	}
	
	/**
	 * ID of target planet.
	 */
	private $targetPlanetID;
	
	/**
	 * Gets ID of target planet.
	 */
	public function GetTargetPlanetID()
	{
		return $this->targetPlanetID;
	}
	
	/**
	 * Time of creation in seconds of real time.
	 */
	private $creationTime;
	
	/**
	 * GoodType instance for specification of cargo type.
	 */
	private $goodType;
	
	/**
	 * Returns type of good.
	 */
	public function GetGoodType()
	{
		return $this->goodType;
	}
	
	/*
	 * Total price of delivery.
	 */
	private $price;
	
	/*
	 * Gets total price of delivery.
	 */
	public function GetPrice()
	{
		return $this->price;
	}
	
	/*
	 * Amount of delivery stuff (tons usualy).
	 */
	private $amount;
	
	/*
	 * Gets amount of delivery stuff (tons usualy).
	 */
	public function GetAmount()
	{
		return $this->amount;
	}
	
	private $hidden;
	
	public function IsHidden()
	{
		return $this->hidden;	
	}
	
	public function SetHidden($hidden)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET hidden=%d WHERE ID=%d", DBConstants::DELIVERY_TABLE_NAME, $hidden, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->hidden = $hidden;
		
		return true;
	}
	
	/**
	 * Creates new Delivery with specified DB ID.
	 * @param id DB ID
	 */
	private function __construct($id) 
	{ 		
		$this->id = $id;
	}
	
	/**
	 * Loads from DB delivery task with specified ID.
	 * @param id DB ID
	 * @return loaded delivery or NULL
	 */ 
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Id must be positive integer.");
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE ID=%d", DBConstants::DELIVERY_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		$delivery = new Delivery($data["ID"]);
		$delivery->locationID = $data["planeta"];
		$delivery->targetPlanetID = $data["cil"];
		$delivery->creationTime = $data["cas_vytvoreni"];
		$delivery->goodType = GoodType::LoadFromDB((int)$data["typ"]);
		$delivery->price = $data["cena"];
		$delivery->amount = $data["mnozstvi"];
		$delivery->hidden = $data["hidden"];
		
		return $delivery;
	}	
	
	/**
	 * Creates new Delivery, inserts it to DB and returns its instance.
	 * @param startPlanet instance of start planet, location of delivery
	 * @param targetPlanet instance of target planet
	 * @param goodType instance of GoodType, specifies goods
	 * @param amount amount of stuff (tons,...)
	 * @param price money offered for delivery
	 */
	public static function CreateNewDelivery(Planet $startPlanet, Planet $targetPlanet, GoodType $goodType, $amount, $price)
	{
		$delivery = new Delivery(-1);
		$delivery->locationID = $startPlanet->GetID();
		$delivery->targetPlanetID = $targetPlanet->GetId();
		$delivery->creationTime = time();
		$delivery->goodType = $goodType;
		$delivery->price = $price;
		$delivery->amount = $amount;
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("INSERT INTO `%s` (planeta, cil, cas_vytvoreni, typ, cena, mnozstvi) ", DBConstants::DELIVERY_TABLE_NAME);
		$query .= sprintf("VALUES (%d, %d, %d, %d, %d, %d)", $delivery->locationID, $delivery->targetPlanetID, 
					$delivery->creationTime, $goodType->GetId(), $delivery->price, $delivery->amount);
		
		$dbManager->PerformQuery($query);
		
		$id = mysql_insert_id();
		
		if ($id <= 0)
		{
			return NULL;
		}
		
		$delivery->id = $id;
		return $delivery;
	}
	
	/**
	 * Removes this delivery from DB.
	 * @return true on success
	 */
	public function RemoveFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("DELETE FROM `%s` WHERE ID=%d", DBConstants::DELIVERY_TABLE_NAME, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		//echo "mazu ". $this->GetId() ."<br/>";
		
		return 1;
	}
}