<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Model/ShipType.inc");

class GoodClass
{
	/**
	 * ID of good type in DB.
	 */
	private $id;
	
	/**
	 * Gets ID of good type in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
	
	/**
	 * Name of good.
	 */
	private $name;
	
	/**
	 * Gets name of good type.
	 */
	public function GetName()
	{
		return $this->name;
	}
	
	private $compatibleShipTypes;
	
	/**
	 * Gets array of player's bases with their IDs as keys.
	 * May return null if not loaded yet - it is loaded separately
	 * to save performance when no ships are needed - i.e. when just
	 * retrieving account state.
	 */
	public function GetCompatibleShipTypes()
	{
		return $this->compatibleShipTypes;
	}
	
	/**
	 * Gets bases for player.
	 * Reads from DB if necessary.
	 * @return bases for player
	 */
	public function GetCompatibleShipTypesForced()
	{
		if ($this->compatibleShipTypes == NULL)
		{
			$this->LoadCompatibleShipTypesFromDB();
		}
		
		return $this->compatibleShipTypes;
	}
	
	/**
	 * Creates new instance with specified ID.
	 * @param id ID of new instance
	 */
	private function __construct($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$this->id = $id;
	}
	
	/**
	 * Loads from DB using ID.
	 * @param id ID of good in DB
	 */
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE Id=%d", DBConstants::GOOD_CLASS_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		$goodClass = new GoodClass($data["Id"]);
		
		$goodClass->name = $data["Name"];
		
		return $goodClass;
	}
	
	/**
	 * Loads all good types from DB and returns them
	 * as array with IDs as keys.
	 * @return array of goods with IDs as keys
	 */
	public static function LoadAllFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT ID FROM `%s`", DBConstants::GOOD_CLASS_TABLE_NAME);
		$rows = $dbManager->PerformQuery($query);
		
		if (!$rows)
		{
			return NULL;
		}
		
		$goodClasses = array();
		
		while ($row = mysql_fetch_assoc($rows))
		{
			$goodClass = GoodClass::LoadFromDB($row["Id"]);	
			$goodClasses[$goodClass->GetId()] = $goodClass;
		}
		
		return $goodClasses;
	}
	
	public function LoadCompatibleShipTypesFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT ship_type FROM `%s` WHERE good_class=%d", DBConstants::CARGO_COMPATIBILITY_TABLE_NAME, $this->id);
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->compatibleShipTypes = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			$shipType = ShipType::LoadFromDB($row["ship_type"]);
			$this->compatibleShipTypes[$shipType->GetId()] = $shipType;
		}
	}
}

?>