<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Model/ShipModel.inc");

/**
 * Class represents player's ship.
 * Image of database entity "lode_hrace".
 */
class Ship
{
/**
	 * ID of ship as in DB.
	 */
	private $id;
	 
	/**
	 * Gets ID ship as in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
	
	private $name;
	
	public function GetName()
	{
		return $this->name;
	}
	
	private $playerID;
	
	public function GetPlayerID()
	{
		return $this->playerID;
	}
	
	public function SetPlayerId($playerId)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET majitel=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $playerId, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->playerID = $playerId;
		
		return true;
	}
	
	private $shipModel;
	
	public function GetModel()
	{
		return $this->shipModel;
	}
	
	private $solarSystemId;

	/**
	 * Gets ID of planet as in DB.
	 */
	public function GetSolarSystemId()
	{
		return $this->solarSystemId;
	}
	
	public function SetSolarSystemId($id)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET solar_system_id=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $id, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->solarSystemId = $id;
		
		return true;
	}	
	
	private $level;
	
	public function GetLevel()
	{
		return $this->level;
	}
	
	public function SetLevel($level)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET level=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $level, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->level = $level;
		
		return true;
	}
	
	public function GetFinalCapacity()
	{
		return $this->GetModel()->GetCapacity() * $this->GetLevel();
	}
	
	private $positionX;
	
	public function GetX()
	{
		return $this->positionX;
	}
	
	private $positionY;
	
	public function GetY()
	{
		return $this->positionY;
	}
	
	public function WriteNewPosition($x, $y)
	{
		$x = round($x);
		$y = round($y);
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET x=%d, y=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $x, $y, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->positionX = $x;
		$this->positionY = $y;
		
		return true;
	}
	
	private $pendingAction;
	
	public function GetPendingAction()
	{
		return $this->pendingAction;
	}
	
	public function PerformNewAction($action)
	{
		$dbManager = DBManager::GetInstance();

		$now = time();
		$query = sprintf("UPDATE `%s` SET akce='%s', prep_pozice=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $action, $now, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->pendingAction = $action;
		$this->lastUpdateTime = $now;
		
		return true;
	}
	
	private $lastUpdateTime;
	
	public function GetLastUpdateTime()
	{
		return $this->lastUpdateTime;
	}
	
	public function NotifyUpdate()
	{
		$dbManager = DBManager::GetInstance();

		$now = time();
		$query = sprintf("UPDATE `%s` SET prep_pozice=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $now, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->lastUpdateTime = $now;
		
		return true;
	}
	
	private $dockedPlanetID;
	
	public function GetDockedPlanetId()
	{
		return $this->dockedPlanetID;
	}
	
	public function WriteNewDockedPlanetId($planetID)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET planeta=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $planetID, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->dockedPlanetID = $planetID;
		
		return true;
	}
	
	public function WriteNewUpdateTime($newTime)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET prep_pozice=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $newTime, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->lastUpdateTime = $newTime;
		
		return true;
	}
	
/**
	 * Array of ship deliveries with IDs as keys.
	 * May be null if not loaded yet - it is loaded separately
	 * to save performance when no deliveries are needed.
	 */
	private $deliveries;

	/**
	 * Gets array of ship deliveries with IDs as keys.
	 * May return null if not loaded yet - it is loaded separately
	 * to save performance when no deliveries are needed.
	 */
	public function GetDeliveries()
	{
		return $this->deliveries;
	}
	
	/**
	 * Marks deliveries as out of date.
	 */
	public function InvalidateDeliveries()
	{
		$this->deliveries = NULL;
	}
	
	/**
	 * Gets deliveries for ship.
	 * Reads from DB if necessary.
	 * @return deliveries for ship
	 */
	public function GetDeliveriesForced()
	{
		if ($this->deliveries == NULL)
		{
			$this->LoadDeliveriesFromDB();
		}
		
		return $this->deliveries;
	}
	
	private $deliveryDoneCount;
	
	public function GetDeliveryDoneCount()
	{
		return $this->deliveryDoneCount;
	}
	
	public function WriteDeliveryDoneCount($value)
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET delivery_count=%d WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $value, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->deliveryDoneCount = $value;
		
		return true;
	}
	
	protected function __construct($id) 
	{ 
		$this->id = $id;
		$this->ships = array();	
	}
	
	/**
	 * Loads ship from DB.
	 * @param $id id of player in DB
	 * @return void
	 */
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Id must be positive integer.");
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}	

		$ship = new Ship($data["ID"]);
		$ship->name = $data["nazev"];
		$ship->playerID = $data["majitel"];
		$ship->positionX = $data["x"];
		$ship->positionY = $data["y"];
		$ship->pendingAction = $data["akce"];
		$ship->lastUpdateTime = $data["prep_pozice"];
		$ship->dockedPlanetID = $data["planeta"];
		$ship->deliveryDoneCount = $data["delivery_count"];
		$ship->solarSystemId = $data["solar_system_id"];
		$ship->level = $data["level"];
		
		$ship->shipModel = ShipModel::LoadFromDB($data["trida"]);
		
		return $ship;		
	}
	
	/**
	 * Loads deliveries for this ship from DB.
	 * Does not return anything, use GetDeliveries() to access result.
	 */
	public function LoadDeliveriesFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT ID FROM `%s` WHERE planeta=%d", DBConstants::DELIVERY_TABLE_NAME, -($this->id));
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->deliveries = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			$delivery = Delivery::LoadFromDB($row["ID"]);
			$this->deliveries[$delivery->GetId()] = $delivery;
			//echo "nacitam ". $row["ID"] ."<br/>";
		}
	}
	
	public static function CreateNewShip($playerId, $modelId, $name, $solarSystemId)
	{
		$dbManager = DBManager::GetInstance();
		
		$query = sprintf("INSERT INTO `%s` (majitel, trida, nazev, solar_system_id) VALUES (%d, %d, '%s', %d)", 
			DBConstants::SHIP_TABLE_NAME, $playerId, $modelId, $name, $solarSystemId);
		$data = $dbManager->PerformQuery($query);
		
		return Ship::LoadFromDB($dbManager->GetLastId());
	}
	
	public function RemoveFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("DELETE FROM `%s` WHERE ID=%d", DBConstants::SHIP_TABLE_NAME, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		//echo "mazu ". $this->GetId() ."<br/>";
		
		return 1;
	}
}

?>