<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Model/GoodClass.inc");

class ShipType
{
	/**
	 * ID of good type in DB.
	 */
	private $id;
	
	/**
	 * Gets ID of good type in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
	
	/**
	 * Name of good.
	 */
	private $nameString;
	
	/**
	 * Gets name of good type.
	 */
	public function GetNameString()
	{
		return $this->nameString;
	}
	
	private $requiresLicence;
	
	/**
	 * Gets name of good type.
	 */
	public function IsLicenceRequired()
	{
		return $this->requiresLicence;
	}
	
	private $pointValue;
	
	public function GetPointValue()
	{
		return $this->pointValue;
	}
	
	private $iconUrl;
	
	public function GetIconURL()
	{
		return $this->iconUrl;
	}
	
	private $compatibleGoodClassses;
	
	/**
	 * Gets array of player's bases with their IDs as keys.
	 * May return null if not loaded yet - it is loaded separately
	 * to save performance when no ships are needed - i.e. when just
	 * retrieving account state.
	 */
	public function GetCompatibleGoodClasses()
	{
		return $this->compatibleGoodClassses;
	}
	
	/**
	 * Gets bases for player.
	 * Reads from DB if necessary.
	 * @return bases for player
	 */
	public function GetCompatibleGoodClassesForced()
	{
		if ($this->compatibleGoodClassses == NULL)
		{
			$this->LoadCompatibleGoodClassesFromDB();
		}
		
		return $this->compatibleGoodClassses;
	}	
	
	/**
	 * Creates new instance with specified ID.
	 * @param id ID of new instance
	 */
	private function __construct($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$this->id = $id;
	}
	
	/**
	 * Loads from DB using ID.
	 * @param id ID of good in DB
	 */
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE id=%d", DBConstants::SHIP_TYPE_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		$shipType = new ShipType($data["id"]);		
		$shipType->nameString = $data["name_string"];
		$shipType->requiresLicence = $data["requires_licence"];
		$shipType->pointValue = $data["point_value"];
		$shipType->iconUrl = $data["icon_url"];
		
		return $shipType;
	}
	
	/**
	 * Loads all good types from DB and returns them
	 * as array with IDs as keys.
	 * @return array of goods with IDs as keys
	 */
	public static function LoadAllFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT id FROM `%s`", DBConstants::SHIP_TYPE_TABLE_NAME);
		$rows = $dbManager->PerformQuery($query);
		
		if (!$rows)
		{
			return NULL;
		}
		
		$shipTypes = array();
		
		while ($row = mysql_fetch_assoc($rows))
		{
			$shipType = ShipType::LoadFromDB($row["id"]);	
			$shipTypes[$shipType->GetId()] = $shipType;
		}
		
		return $shipTypes;
	}
		
	public function LoadCompatibleGoodClassesFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT good_class FROM `%s` WHERE ship_type=%d", DBConstants::CARGO_COMPATIBILITY_TABLE_NAME, $this->id);
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->compatibleGoodClassses = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			
			$goodClass = GoodClass::LoadFromDB($row["good_class"]);
			$this->compatibleGoodClassses[$goodClass->GetId()] = $goodClass;
		}
	}
}

?>