<?php

require_once("Model/Planet.inc");
require_once("Model/WormHole.inc");
require_once("Control/DBConstants.inc");
require_once("Control/DBManager.inc");

/**
 * Represents solar system with planets.
 */
class SolarSystem
{
	/**
	 * Size of solar system border.
	 * It is ratio of space beyond last planet that is to be counted
	 * as part of system and therefore for example rendered.
	 */
	const SIZE_BORDER_COEF = 1.2;
	
	private $id;
	
	/**
	 * Gets ID of good type in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
	
	private $name;
	
	/**
	 * Gets name of good type.
	 */
	public function GetName()
	{
		return $this->name;
	}
	
	private $x;
	
	/**
	 * Gets name of good type.
	 */
	public function GetX()
	{
		return $this->x;
	}
	
	private $y;
	
	/**
	 * Gets name of good type.
	 */
	public function GetY()
	{
		return $this->y;
	}
	
	private $sunImageUrl;
	
	public function GetSunImageUrl()
	{
		return $this->sunImageUrl;
	}
	
	/*public function Randomize()
	{
		$x = mt_rand(0, mt_getrandmax()) / floatval(mt_getrandmax()) * 0.8 + 0.1;
		$y = mt_rand(0, mt_getrandmax()) / floatval(mt_getrandmax()) * 0.8 + 0.1;
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("UPDATE `%s` SET x=%f, y=%f WHERE id=%d", DBConstants::SOLAR_SYSTEM_TABLE_NAME, $x, $y, $this->id);
		$data = $dbManager->PerformQuery($query);
		
		$this->x = $x;
		$this->y = $y;
		
		return true;
	}*/
	
	/**
	 * Array of planets with IDs as keys.
	 */
	private $planets;	
	
	/**
	 * Gets array of planets with IDs as keys.
	 */
	public function GetPlanets()
	{
		if ($this->planets == NULL)
		{
			$this->LoadPlanetsFromDB();
		}
		
		return $this->planets;
	}
	
	private $wormHoles;
	
	/**
	 * Gets array of player's bases with their IDs as keys.
	 * May return null if not loaded yet - it is loaded separately
	 * to save performance when no ships are needed - i.e. when just
	 * retrieving account state.
	 */
	public function GetWormHoles()
	{
		return $this->wormHoles;
	}
	
	/**
	 * Gets bases for player.
	 * Reads from DB if necessary.
	 * @return bases for player
	 */
	public function GetWormHolesForced()
	{
		if ($this->wormHoles == NULL)
		{
			$this->LoadWormHolesFromDB();
		}
		
		return $this->wormHoles;
	}
	
	/**
	 * Width of system in ingame units as defined by most outter planet
	 * and SIZE_BORDER_COEF.
	 */
	private $systemWidth;
	
	/**
	 * Gets width of system in ingame units as defined by most outter planet
	 * and SIZE_BORDER_COEF.
	 */
	public function GetSystemWidth()
	{
		return $this->systemWidth;
	}
	
	/**
	 * Height of system in ingame units as defined by most outter planet
	 * and SIZE_BORDER_COEF.
	 */
	private $systemHeight;
	
	/**
	 * Gets height of system in ingame units as defined by most outter planet
	 * and SIZE_BORDER_COEF.
	 */
	public function GetSystemHeight()
	{
		return $this->systemHeight;
	}
	
	/**
	 * Creates new instance but doesn't load data from DB.
	 */
	private function __construct($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$this->id = $id;
		$this->planets = NULL;
	}
	
	public static function LoadFromDB($id = 1, $loadContent = false)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE Id=%d", DBConstants::SOLAR_SYSTEM_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
		
		$system = new SolarSystem($data["id"]);
		$system->name = $data["name"];
		$system->x = $data["x"];
		$system->y = $data["y"];
		$system->sunImageUrl = $data["sun_image_url"];
		
		if ($loadContent)
		{
			$system->LoadPlanetsFromDB();		
			$system->MeasureSystemDimensions();
		}
		
		return $system;
	}
	
	public static function LoadAllFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT id FROM `%s`", DBConstants::SOLAR_SYSTEM_TABLE_NAME);
		$rows = $dbManager->PerformQuery($query);
		
		if (!$rows)
		{
			return NULL;
		}
		
		$systems = array();
		
		while ($row = mysql_fetch_assoc($rows))
		{
			$system = SolarSystem::LoadFromDB($row["id"]);	
			$systems[$system->GetId()] = $system;
		}
		
		return $systems;
	}
	
	public function LoadPlanetsFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT ID FROM `%s` WHERE solar_system_id=%d", DBConstants::PLANET_TABLE_NAME, $this->id);
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->planets = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			$planet = Planet::LoadFromDB($row["ID"]);
			$this->planets[$planet->GetId()] = $planet;
		}
	}
	
	private function MeasureSystemDimensions()
	{
		$dbManager = DBManager::GetInstance();
		
		$query = sprintf(
			"SELECT ABS(x) as width FROM `%s`, `%s`, `%s` " .
			"WHERE `%s`.solar_system_id = %d " .
			"AND `%s`.id = `%s`.trajectory_id " .
			"AND `%s`.planet_trajectory_id = `%s`.id " .
			"ORDER BY ABS(x) DESC LIMIT 1", 
			DBConstants::PLANET_TABLE_NAME, DBConstants::PLANET_TRAJECTORY_TABLE_NAME, DBConstants::COORD_TABLE_NAME,
			DBConstants::PLANET_TABLE_NAME, $this->id, 
			DBConstants::PLANET_TRAJECTORY_TABLE_NAME, DBConstants::PLANET_TABLE_NAME, 
			DBConstants::COORD_TABLE_NAME, DBConstants::PLANET_TRAJECTORY_TABLE_NAME
			);
		$result = $dbManager->PerformQueryAssoc($query);
		$this->systemWidth = 2 * (int) $result["width"] * SolarSystem::SIZE_BORDER_COEF;
		
		$query = sprintf(
			"SELECT ABS(y) as height FROM `%s`, `%s`, `%s` " .
			"WHERE `%s`.solar_system_id = %d " .
			"AND `%s`.id = `%s`.trajectory_id " .
			"AND `%s`.planet_trajectory_id = `%s`.id " .
			"ORDER BY ABS(y) DESC LIMIT 1", 
			DBConstants::PLANET_TABLE_NAME, DBConstants::PLANET_TRAJECTORY_TABLE_NAME, DBConstants::COORD_TABLE_NAME,
			DBConstants::PLANET_TABLE_NAME, $this->id, 
			DBConstants::PLANET_TRAJECTORY_TABLE_NAME, DBConstants::PLANET_TABLE_NAME, 
			DBConstants::COORD_TABLE_NAME, DBConstants::PLANET_TRAJECTORY_TABLE_NAME
			);
		$result = $dbManager->PerformQueryAssoc($query);
		$this->systemHeight = 2 * (int) $result["height"] * SolarSystem::SIZE_BORDER_COEF;
		
		$this->systemWidth = max($this->systemWidth, 500000000000);
		$this->systemHeight = max($this->systemHeight, 500000000000);
	}
	
	public function LoadWormHolesFromDB()
	{
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT id FROM `%s` WHERE system_a_id=%d OR system_b_id=%d", 
			DBConstants::WORM_HOLE_TABLE_NAME, $this->id, $this->id);
		$rows = $dbManager->PerformQuery($query);

		if (!$rows)
		{
			return NULL;
		}

		$this->wormHoles = array();

		while ($row = mysql_fetch_assoc($rows))
		{
			$wormHole = WormHole::LoadFromDB($row["id"]);
			$this->wormHoles[$wormHole->GetId()] = $wormHole;
		}
	}
}

?>