<?php

require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Control/INavigable.inc");

class WormHole implements INavigable
{
	/**
	 * ID of good type in DB.
	 */
	private $id;
	
	/**
	 * Gets ID of good type in DB.
	 */
	public function GetId()
	{
		return $this->id;		
	}
		
	private $systemIds;
	
	public function GetSystemIds()
	{
		return $this->systemIds;
	}
	
	public function GetOtherSystemId($systemId)
	{
		if ($systemId == $this->systemIds[0])
		{
			return $this->systemIds[1];
		}
		else if ($systemId == $this->systemIds[1])
		{
			return $this->systemIds[0];
		}
		
		return NULL; 
	}
	
	private $imageUrl;
	
	public function GetImageURL()
	{
		return $this->imageUrl;
	}
	
	private $positions;
	
	public function GetPositions()
	{
		return $this->positions;
	}
	
	public function GetCurrentPosition($solarSystemId = NULL)
	{
		if ($this->systemIds[0] == $solarSystemId)
		{
			return $this->positions[0];
		}
		
		if ($this->systemIds[1] == $solarSystemId)
		{
			return $this->positions[1];
		}
		return NULL;
	}
	
	public function GetPositionForGameDay($gameDay, $solarSystemId = NULL)
	{
		return $this->GetCurrentPosition($solarSystemId);
	}
		
	/**
	 * Creates new instance with specified ID.
	 * @param id ID of new instance
	 */
	private function __construct($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$this->id = $id;
	}
	
	/**
	 * Loads from DB using ID.
	 * @param id ID of good in DB
	 */
	public static function LoadFromDB($id)
	{
		if ($id <= 0)
		{
			throw new Exception("Ivalid ID value.");			
		}
		
		$dbManager = DBManager::GetInstance();

		$query = sprintf("SELECT * FROM `%s` WHERE id=%d", DBConstants::WORM_HOLE_TABLE_NAME, $id);
		$data = $dbManager->PerformQueryAssoc($query);
		
		if (!$data)
		{
			return NULL;
		}
				
		$wormhole = new WormHole($data["id"]);
		$wormhole->imageUrl = $data["image_url"];
		
		$wormhole->systemIds = array();
		$wormhole->systemIds[0] = $data["system_a_id"];
		$wormhole->systemIds[1] = $data["system_b_id"];		
		
		$wormhole->positions = array();
		$wormhole->positions[0] = array();
		$wormhole->positions[0][0] = $data["x_coord_in_a"];
		$wormhole->positions[0][1] = $data["y_coord_in_a"];
		$wormhole->positions[1] = array();
		$wormhole->positions[1][0] = $data["x_coord_in_b"];
		$wormhole->positions[1][1] = $data["y_coord_in_b"];
		
		return $wormhole;		
	}
}

?>