<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once("Control/Utils.inc");
require_once("Model/Player.inc");
require_once("Model/Alliance.inc");

class AllianceTransferPanel extends Control
{
	private $player;
	
	private $parentControl;
	
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		
		$this->htmlId = $newId;
	}
		
	const CLASS_NAME = "AllianceTransferPanel";
		
	public function __construct(Control $parentControl = NULL, Player $player = NULL)
	{
		$this->htmlId = self::CLASS_NAME;
		
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
		}
		
		$this->player = $player;
		$this->parentControl = $parentControl;		
	}	
		
	public function Render()
	{	
		$this->UpdateSize();
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/universal.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(this, event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 6, 38, 455, 394);
		echo '<div style="'.$divStyle.'">';
		
		echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
		echo $dictionary->Translate("ALLIANCE_TRANSFER_HEADLINE");
		echo "</div>\n";
		
		if ($this->player == NULL)
		{
			echo $dictionary->Translate("PLAYER_NOT_LOGGED") . "<br/>";
		} 
		else if ($this->player->GetAllianceId() == NULL || ($alliance = Alliance::LoadFromDB($this->player->GetAllianceId())) == NULL)
		{
			echo $dictionary->Translate("ALLIANCE_TRANSFER_NOT_IN_ALLIANCE") . "<br/>";
			
			if ($this->player->GetAllianceId() != NULL) 
			{
				$this->player->SetAllianceId(NULL);
			}
		}
		else
		{
			$this->PrintMoneyDonate($alliance);
			$this->PrintShipDonate($alliance);			
		}
		
		echo "<form method=\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_namePromptText\" name=\"namePromptText\" type=\"hidden\" value=\"".$dictionary->Translate('ENTER_ALLIANCE_NAME')."\"/>";
		echo "</form>\n";
		
		echo "</div>\n";
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
	}
	
	private function PrintShipDonate(Alliance $alliance)
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<h3>".$dictionary->Translate("ALLIANCE_DONATE_BATTLESHIP")."</h3>\n";
		
		echo "<p>\n";
		echo "<form method=\"post\" action=\"\">\n";
		echo "<div id=\"".self::CLASS_NAME."_donateGuardList\">\n";
		
		$this->PrintShipDonateItem($alliance, "", "");
		
		echo "</div>\n";
		
		echo "<br/>";
		echo "<input id=\"".$this->GetHtmlId()."_donateGuardSendBtn\" name=\"_donateGuardSendBtn\" type=\"button\" ";
		echo "value=\"".$dictionary->Translate("ALLIANCE_DONATE_GUARDS_SEND")."\" ";
		echo "onclick=\"".self::CLASS_NAME."_DonateGuards('".$dictionary->Translate("ALLIANCE_DONATE_GUARDS_QUESTION")."')\"/>\n";		
		
		echo "<span id=\"".self::CLASS_NAME."_donateGuardsResultLbl\"></span>\n";
		
		echo "<input id=\"".$this->GetHtmlId()."_donateGuardsSuccessText\" name=\"donateGuardsSuccessText\" type=\"hidden\" ";
		echo "value=\"".$dictionary->Translate("ALLIANCE_DONATE_GUARDS_SUCCESS")."\"/>\n";
		
		echo "<input id=\"".$this->GetHtmlId()."_donateGuardsPartialResText\" name=\"donateGuardsPartialResText\" type=\"hidden\" ";
		echo "value=\"".$dictionary->Translate("ALLIANCE_DONATE_GUARDS_PARTIAL")."\"/>\n";
		
		echo "</form>\n";
		echo "<br/>";
		echo "</p>\n";
	}
	
	public function PrintShipDonateItem(Alliance $alliance = NULL, $id, $name = NULL)
	{
		if ($alliance == NULL)
		{
			$alliance = Alliance::LoadFromDB($this->player->GetAllianceId());
		}
		
		if ($name = NULL)
		{
			$name = $id;
		}
		
		$dictionary = Dictionary::GetInstance();
		
		echo "<div id=\"".$id."\" name=\"".$name."\">\n";
		
		echo $dictionary->Translate("ALLIANCE_DONATE_GUARD_GUARD") . "&nbsp;";
		$this->PrintGuardsDdl($this->player, "", "", true);
		
		echo $dictionary->Translate("ALLIANCE_DONATE_GUARD_TO") . "&nbsp;";
		$onChangeCallBack = self::CLASS_NAME."_DonateGuard_RecieverChange(this)";
		$this->PrintMembersDdl($alliance, "", "", true, $onChangeCallBack);
		
		echo "</div>\n";
	}
	
	private function PrintMoneyDonate(Alliance $alliance)
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<h3>".$dictionary->Translate("ALLIANCE_DONATE_MONEY")."</h3>\n";
		
		echo "<p>";
		
		echo "<form method=\"post\" action=\"\">";
		
		echo $dictionary->Translate("ALLIANCE_DONATE_MONEY_AMOUNT") . "&nbsp;";
		echo "<input id=\"".$this->GetHtmlId()."_donateMoneyAmount\" name=\"donateMoneyAmount\" size=\"10\" type=\"text\" value=\"\$0\"/>\n";
		
		echo $dictionary->Translate("ALLIANCE_DONATE_MONEY_TO") . "&nbsp;";
		$this->PrintMembersDdl($alliance, self::CLASS_NAME . "_donateMoneyReciever", "donateMoneyReciever");
		
		echo "<input id=\"".$this->GetHtmlId()."_donateMoneySendBtn\" name=\"donateMoneySendBtn\" type=\"button\" ";
		echo "value=\"".$dictionary->Translate("ALLIANCE_DONATE_MONEY_SEND")."\" ";
		echo "onclick=\"".self::CLASS_NAME."_DonateMoney('".$dictionary->Translate("ALLIANCE_DONATE_MONEY_QUESTION")."')\"/>\n";		
		
		echo "<span id=\"".self::CLASS_NAME."_donateMoneyResultLbl\"></span>\n";
		
		echo "<input id=\"".$this->GetHtmlId()."_donateMoneySuccessText\" name=\"donateMoneySuccessText\" type=\"hidden\" ";
		echo "value=\"".$dictionary->Translate("ALLIANCE_DONATE_MONEY_SUCCESS")."\"/>\n";		
		echo "</form>\n";		
				
		echo "</p>\n";
	}
	
	private function PrintGuardsDdl(Player $player, $id, $name = NULL, $disabled = false)
	{
		if ($name == NULL)
		{
			$name = $id;
		}
		
		$dictionary = Dictionary::GetInstance();
		
		echo "<select name=\"".$name."\" id=\"".$id."\"";
		
		if ($disabled)
		{
			echo " disabled=\"disabled\"";
			echo " style=\"color: gray;\"";
		}
		echo ">\n";
		
		$guards = (array)$player->GetShipsForced();	
		$guardsSorted = array();
		
		foreach ($guards as $guard)
		{
			$guardsSorted[$guard->GetName() . "_" . $guard->GetId()] = $guard;
		}		
		
		ksort($guardsSorted);
						
		foreach ($guardsSorted as $guard)
		{
			if ($guard->GetModel()->GetShipType()->GetId() != GameConstants::GUARD_SHIP_TYPE_ID)
			{
				continue;
			}
			
			echo "<option value=\"".$guard->GetId()."\">";
			echo $guard->GetName();
			echo "</option>\n";
		}
		
		echo "</select>\n";
	}
	
	private function PrintMembersDdl(Alliance $alliance, $id, $name = NULL, $printEmpty = false, $onchangeCallBack = NULL)
	{
		if ($name == NULL)
		{
			$name = $id;
		}
		
		$dictionary = Dictionary::GetInstance();
		
		echo "<select name=\"".$name."\" id=\"".$id."\"";
		if ($onchangeCallBack)
		{
			echo " onchange=\"".$onchangeCallBack."\"";
		}
		echo ">\n";
		
		if ($printEmpty)
		{
			echo "<option selected=\"selected\" value=\"-1\">";
			echo $dictionary->Translate("ALLIANCE_MEMBER_NONE");
			echo "</option>\n";
		}
		
		$members = (array)$alliance->GetMembersForced();	
		$membersSorted = array();
		
		foreach ($members as $member)
		{
			$membersSorted[$member->GetStringIdentifier() . "_" . $member->GetId()] = $member;
		} 
		
		krsort($membersSorted);		
						
		foreach ($membersSorted as $member)
		{
			if ($member->GetId() == $this->player->GetId())
			{
				continue;
			}
			
			echo "<option value=\"".$member->GetLogin()."\">";
			echo $member->GetStringIdentifier();
			echo "</option>\n";
		}
		
		echo "</select>\n";
	}
	
	public function UpdateSize()
	{
		if ($this->parentControl == NULL)
		{
			return;
		}
		
		$this->SetWidth($this->parentControl->GetWidth());
		$this->SetHeight($this->parentControl->GetHeight());
	}
}
?>