<?php

require_once("Control/IRenderable.inc");

/**
 * Parent class for most of web controls of View layer.
 */
abstract class Control implements IRenderable
{
	/**
	 * Generates unique ID for control for HTML.
	 */
	public abstract function GetHtmlId();
	
	/**
	 * In page X coordinate in px.
	 */
	protected $x = 0;
	
	/**
	 * Gets in page X coordinate in px.
	 */
	public function GetX()
	{
		return $this->x;
	}
	
	/**
	 * Sets in page X coordinate in px.
	 */
	public function SetX($value)
	{
		$this->x = $value;
	}
	
	/**
	 * In page Y coordinate in px.
	 */
	protected $y = 0;
	
	/**
	 * Gets in page Y coordinate in px.
	 */
	public function GetY()
	{
		return $this->y;
	}
	
	/**
	 * Sets in page Y coordinate in px.
	 */
	public function SetY($value)
	{
		$this->y = $value;
	}
	
	/**
	 * In page width in px.
	 */
	protected $width = 0;
	
	/**
	 * Gets in page width in px.
	 */
	public function GetWidth()
	{
		return $this->width;
	}
	
	/**
	 * Sets in page width in px.
	 */
	public function SetWidth($value)
	{
		if ($value < 0)
		{
			throw new Exception("Width must be 0 or higher.");
		}
		
		$this->width = $value;
	}
	
	/**
	 * In page height in px.
	 */
	protected $height = 0;
	
	/**
	 * Gets in page height in px.
	 */
	public function GetHeight()
	{
		return $this->height;
	}
	
	/**
	 * Sets in page height in px.
	 */
	public function SetHeight($value)
	{
		if ($value < 0)
		{
			throw new Exception("Height must be 0 or higher.");
		}
		
		$this->height = $value;
	}
	
	/**
	 * Flag of visibility.
	 * Invisible control is rendered but not displayed.
	 * Default value is true.
	 * @var unknown_type
	 */
	protected $visible = true;
	
	/**
	 * Gets flag whetter the control is visible.
	 * Invisible control is rendered but not displayed.
	 * @return flag of visibility
	 */
	public function IsVisible()
	{
		return $this->visible;
	}
	
	/**
	 * Sets visibility of control.
	 * Invisible control is rendered but not displayed.
	 * @param $value visibility
	 */
	public function SetVisible($value)
	{
		$this->visible = ($value == true);
	}
	
	/**
	 * Background color of control.
	 * Default value is white.
	 * @var unknown_type
	 */
	protected $backgroundColor = "#FFFFFF";
	
	/**
	 * Gets background color of control.
	 * Default value is white.
	 * @return background color
	 */
	public function GetBackgroundColor()
	{
		return $this->backgroundColor;
	}
	
	/**
	 * Sets background color of control.
	 * Default value is white.
	 * @param $value new background color
	 */
	public function SetBackgroundColor($value)
	{
		$this->backgroundColor = $value;
	}
	
	private $positionMode = "absolute";
	
	public function GetPositionMode()
	{
		return $this->positionMode;
	}
	
	public function SetPoistionMode($value)
	{
		$this->positionMode = $value;
	}
	
	protected $autoSize = false;
	
	public function IsAutoSize()
	{
		return $this->autoSize;
	}
	
	public function SetAutoSize($enabled)
	{
		$this->autoSize = $enabled;
	}
	
	protected function GenerateStyleString()
	{
		$string = "left: ".$this->GetX()."px;";
		$string .= "top: ".$this->GetY()."px;";
		
		if (!$this->IsAutoSize())
		{
			$string .= "width: ".$this->GetWidth()."px;";
			$string .= "height: ".$this->GetHeight()."px;";
		}
		
		$string .= "background-color: ".$this->GetBackgroundColor().";";
		$visible = $this->IsVisible() ? "inherit" : "none";
		$string .= "display: ".$visible.";";
		$string .= "position: ".$this->GetPositionMode().";";

		return $string;
	}
}

?>
