<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once('Model/Planet.inc');
require_once('Control/Dictionary.inc');

class DeliveryPanel extends Control
{
	private $gamePlan;
	
	public function GetGamePlan()
	{
		return $this->gamePlan;
	}
	
	private $planet;
	
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	private $sortKey;
	
	public function SetSortKey($key)
	{
		$this->sortKey = $key; 
	}
	
	private $sortOrder;
	
	public function SetSortOrder($order)
	{
		$this->sortOrder = $order; 
	}
	
	const CLASS_NAME = "DeliveryPanel";
		
	public function __construct(GamePlan $gamePlan, Planet $planet = NULL)
	{
		$this->gamePlan = $gamePlan;
		$this->planet = $planet;
		$this->htmlId = DeliveryPanel::CLASS_NAME;
		$this->sortKey = "reward";
		$this->sortOrder = "desc";
	}	
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
		
	public function Render()
	{
		//$this->SetX($this->gamePlan->GetX());
		//$this->SetY($this->gamePlan->GetY());
		$this->UpdateSize();
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/universal.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="DeliveryPanel_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 18, 35, 433, 353);
		echo '<div style="'.$divStyle.'">';
		
		if ($this->planet != NULL)
		{
			echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
			echo $this->planet->GetName()."</div>\n";
			
			$this->PrintDeliveryTable();			
		}
		
		echo "</div>\n";
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
	}
	
	private function PrintDeliveryTable()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<table style=\"width: 100%\">\n";
		
		$this->PrintHeader();
		
		$rows = $this->GenerateRows();
				
		$i = 0;
		foreach ($rows as $rowArray)
		{
			foreach ($rowArray as $row)
			{
				echo "<tr>\n";
				echo "<td>".$row["good"]."</td>\n";
				echo "<td style=\"text-align: center;\">".$row["amount"]."</td>\n";
				echo '<td>$'.$row["reward"]."</td>\n";
				echo "<td>".$row["target"]."</td>\n";
				echo "<td>".$row["system"]."</td>\n";
				echo "<td style=\"text-align: center;\">".$row["action"]."</td>\n";
				echo "</tr>\n";
				$i++;
			}
		}
		
		echo "</table>\n";
	}
	
	private function PrintHeader()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
			
		$this->PrintSortableHeaderCell('GOODS', "good", "asc");
		$this->PrintSortableHeaderCell('TONS', "amount", "desc");	
		$this->PrintSortableHeaderCell('REWARD', "reward", "desc");	
		$this->PrintSortableHeaderCell('TARGET_PLANET', "target", "asc");
		$this->PrintSortableHeaderCell('DELIVERY_SYSTEM', "system", "asc");
		$this->PrintHeaderCell('DELIVERY_CHOOSE', "", "");
				
		echo "</tr>\n";
	}
	
	private function PrintSortableHeaderCell($dictNameKey, $sortKey, $defaultOrder)
	{
		$sortOrder = $defaultOrder;
		$style = "text-decoration: underline; cursor: pointer;";
		
		if (!strcasecmp($this->sortKey, $sortKey))
		{
			$style .= " font-weight: bold;";
			
			if (!strcasecmp($this->sortOrder, $sortOrder))
			{
				if (!strcasecmp($sortOrder, "desc"))
			    {
			    	$sortOrder  = "asc";
			    }
			    else
			    {
			    	$sortOrder = "desc";	
			    }				
			}
		}		
		
		$action = self::CLASS_NAME . "_Show(".$this->planet->GetId().", '".$sortKey."', '".$sortOrder."')";
		$this->PrintHeaderCell($dictNameKey, $style, $action);	
	}
	
	private function PrintHeaderCell($nameKey, $style = "", $action = "")
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<td";
		
		if (strlen($style) > 0)
		{
			echo " style=\"".$style."\"";
		}
		
		if (strlen($action) > 0)
		{
			echo " onclick=\"".$action."\"";
		}
		
		echo ">";
		echo $dictionary->Translate($nameKey);
		echo "</td>\n";
	}
	
	private function GenerateRows()
	{
		$dictionary = Dictionary::GetInstance();
		
		$rows = array();
		$deliveries = (array)$this->planet->GetDeliveriesForced();
		
		foreach ($deliveries as $delivery)
		{	
			if ($delivery->IsHidden())
			{
				continue;
			}
			
			$targetPlanet =  Planet::LoadFromDB($delivery->GetTargetPlanetId());
			
			$good = $delivery->GetGoodType()->GetName();
			$amount = $delivery->GetAmount();
			$reward = $delivery->GetPrice();
			$target = $targetPlanet->GetName();
			$system = ($targetPlanet->GetSolarSystemId() == $this->planet->GetSolarSystemId()) ? $dictionary->Translate("DELIVERY_LOCAL") : $dictionary->Translate("DELIVERY_ABROAD");
			$action = "<span class=\"LoginPanel_link\" onclick=\"ShipSelectionPanel_Show(".$delivery->GetId().")\">";
			$action .= $dictionary->Translate("DELIVERY_DELIVER").'</span>'."\n";
			
			$row = array("good" => $good, "amount" => $amount, "reward" => $reward, 
						"target" => $target, "system" => $system, "action" => $action);
			
			if (!strcasecmp($this->sortKey, "good"))
			{
				$key = strtolower($good);
			}
			else if (!strcasecmp($this->sortKey, "amount"))
			{
				$key = $amount;
			}
			else if (!strcasecmp($this->sortKey, "reward"))
			{
				$key = $reward;
			}
			else if (!strcasecmp($this->sortKey, "system"))
			{
				$key = $system;
			}
			else if (!strcasecmp($this->sortKey, "target"))
			{
				$key = strtolower($target);
			}
			else
			{
				$key = $reward;
			}	
			
			if (!array_key_exists($key, $rows))
			{
				$rows[$key] = array();
			}
			
			array_push($rows[$key], $row);
		}
		
		if (!strcasecmp($this->sortOrder, "asc"))
		{
			ksort($rows);
		}
		else
		{
			krsort($rows);
		}
		
		return $rows;
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}

?>