<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once("Control/Utils.inc");
require_once("Model/Player.inc");
require_once("Model/Alliance.inc");
require_once("Model/AllianceInvitation.inc");

class EmbassyPanel extends Control
{
	private $player;
	
	private $gamePlan;
	
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		
		$this->htmlId = $newId;
	}
		
	const CLASS_NAME = "EmbassyPanel";
		
	public function __construct(GamePlan $gamePlan = NULL, Player $player = NULL)
	{
		$this->htmlId = self::CLASS_NAME;
		
		if ($player == NULL)
		{
			$player = Globals::GetActivePlayer();
		}
		
		$this->player = $player;
		$this->gamePlan = $gamePlan;
	}	
		
	public function Render()
	{	
		$this->UpdateSize();
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/universal.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(this, event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 18, 35, 433, 353);
		echo '<div style="'.$divStyle.'">';
		
		echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%; position: relative; top: 10px;">';
		echo $dictionary->Translate("EMBASSY_PANEL_HEADLINE");
		echo "</div>\n";
		
		$divStyle = sprintf("position: relative; top: %fpx;", 10);
		echo '<div style="'.$divStyle.'">';
		
		if ($this->player == NULL)
		{
			echo $dictionary->Translate("PLAYER_NOT_LOGGED") . "<br/>";
		} 
		else if ($this->player->GetAllianceId() != NULL)
		{
			$alliance = Alliance::LoadFromDB($this->player->GetAllianceId());
						
			echo "<p>";
			
			echo "<b>".$dictionary->Translate("EMBASSY_CURRENT_ALLIANCE_NAME")."</b>" . $alliance->GetName();
			echo " " . sprintf($dictionary->Translate("EMBASSY_CURRENT_ALLIANCE_SIZE"), count($alliance->GetMembersForced()));
			echo " - " . sprintf($dictionary->Translate("EMBASSY_CURRENT_ALLIANCE_LEADER"), Player::LoadFromDB($alliance->GetAdminId())->GetStringIdentifier());
			echo  "<br/>\n";
			
			echo "<b>".$dictionary->Translate("EMBASSY_CURRENT_ALLIANCE_FOUNDED")."</b>" . Utils::GetDateTimeString($alliance->GetTime());
			echo " " . sprintf($dictionary->Translate("EMBASSY_CURRENT_ALLIANCE_CREATOR"), Player::LoadFromDB($alliance->GetCreatorId())->GetStringIdentifier());
			echo "<br/>\n";
						
			echo "<span class=\"LoginPanel_link\" onclick=\"".AllianceTransferPanel::CLASS_NAME."_Show()\">";
			echo $dictionary->Translate("EMBASSY_SHOW_ALLIANCE_TRANSFERS").'</span>'."\n";
						
			echo "<span style=\"position: relative; left: 20px;\" class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_LeaveAlliance('".sprintf($dictionary->Translate("EMBASSY_LEAVE_ALLIANCE_QUESTION"), $alliance->GetName())."')\">";
			echo $dictionary->Translate("EMBASSY_LEAVE_ALLIANCE").'</span>'."\n";
						
			echo "</p>\n";
			
			echo "<p>";
			echo "<h3>".$dictionary->Translate("EMBASSY_MEMBERS")."</h3>";
			$this->PrintAllianceMemberTable($alliance);
			
			if ($this->player->GetId() == $alliance->GetAdminId())
			{
				$this->PrintInvitationSender($alliance);
			}
			$this->PrintInvitationAcceptor();
			
			echo "</p>\n";
		}
		else
		{
			echo "<p>";
			
			echo "<b>".$dictionary->Translate("EMBASSY_CURRENT_ALLIANCE_NAME")."</b>";
			echo $dictionary->Translate("NOT_IN_ALLIANCE");
			
			if ($this->player->GetEmbassyLevel() > 0)
			{
				echo " => ";
				echo "<span class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_CreateAlliance()\">";
				echo $dictionary->Translate("EMBASSY_CREATE_ALLIANCE").'</span><br/>'."\n";
			} 
			
			else
			{
				echo "<br/>";
				echo $dictionary->Translate("YOU_HAVE_NO_EMBASSY") . "<br/>";		
			}
			
			$this->PrintInvitationAcceptor();
			
			echo "</p>";
		}
		
		echo '</div>'."\n";
		echo "</div>\n";
				
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
		
		echo "<form method=\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_namePromptText\" name=\"namePromptText\" type=\"hidden\" value=\"".$dictionary->Translate('ENTER_ALLIANCE_NAME')."\"/>";
		echo "</form>\n";
	}
	
	private function PrintInvitationSender(Alliance $alliance)
	{
		$dictionary = Dictionary::GetInstance();
		echo "<h3>".$dictionary->Translate("EMBASSY_INVITOR_HEADLINE")."</h3>";
		
		echo "<form method=\"post\" action=\"\">";
		echo $dictionary->Translate("EMBASSY_ENTER_LOGIN"). ": ";
		echo "<input id=\"".$this->GetHtmlId()."_invitedLogin\" name=\"invitedLogin\" type=\"text\" value=\"\"/>";
		echo "<input name=\"inviteBtn\" type=\"button\" value=\"".$dictionary->Translate("EMBASSY_INVITE_BTN")."\"";
		echo "onclick=\"".self::CLASS_NAME."_InvitePlayer()\" />";
		echo "<span style=\"color: red;\" id=\"".$this->GetHtmlId()."_invitationResult\"\></span>";
		echo "<input id=\"".$this->GetHtmlId()."_inviteSuccessText\" name=\"inviteSuccessText\" type=\"hidden\" value=\"".$dictionary->Translate('EMBASSY_INVITE_SUCCESS')."\"/>";
		echo "</form>\n";
	} 
	
	private function PrintInvitationAcceptor()
	{
		$dictionary = Dictionary::GetInstance();
		echo "<h3>".$dictionary->Translate("EMBASSY_ACCEPT_HEADLINE")."</h3>";
		
		echo "<table style=\"width: 100%\">\n";
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
		echo "<td>".$dictionary->Translate('EMBASSY_INVITATION_INDEX')."</td>\n";
		echo "<td>".$dictionary->Translate('EMBASSY_INVITATION_ALLIANCE_NAME')."</td>\n";
		echo "<td>".$dictionary->Translate('EMBASSY_INVITATION_SENDER_NAME')."</td>\n";
		echo "<td>".$dictionary->Translate('EMBASSY_INVITATION_ACTION_HEADER')."</td>\n";
		echo "</tr>\n";
		
		$invitations = (array) $this->player->GetAllianceInvitationsForced();
		$invitationsSorted = array();
		foreach ($invitations as $invitation) 
		{
			if ($invitation->GetTime() + GameConstants::ALLIANCE_INVITATION_EXPIRATION < time())
			{
				$invitation->RemoveFromDB();
				continue;
			}
			
			$invitationsSorted[$invitation->GetTime()] = $invitation;	
		}
		
		krsort($invitationsSorted);
		
		$i = 0;
		foreach ($invitationsSorted as $invitation) 
		{
			echo "<tr>\n";
			echo "<td style=\"text-align: center;\">".($i + 1)."</td>\n";
			$alliance = Alliance::LoadFromDB($invitation->GetAllianceId());
			echo "<td>".$alliance->GetName()."</td>\n";
			echo "<td>".Player::LoadFromDB($invitation->GetSenderId())->GetStringIdentifier()."</td>\n";
			
			echo "<td style=\"text-align: center;\">";
			
			if ($this->player->GetAllianceId() == NULL)
			{
				echo "<span class=\"LoginPanel_link\" ";
				echo "onclick=\"".self::CLASS_NAME."_AnswerInvitation(".$invitation->GetId().", true, '".sprintf($dictionary->Translate("EMBASSY_INVITATION_ACCEPT_QUESTION"), $alliance->GetName())."')\">\n";
				echo $dictionary->Translate('EMBASSY_ACCEPT_INVITATION_ACTION').'</span>';
				
				echo "&nbsp;";
				
				echo "<span class=\"LoginPanel_link\" ";
				echo "onclick=\"".self::CLASS_NAME."_AnswerInvitation(".$invitation->GetId().", false, '".sprintf($dictionary->Translate("EMBASSY_INVITATION_REJECT_QUESTION"), $alliance->GetName())."')\">\n";
				echo $dictionary->Translate('EMBASSY_REJECT_INVITATION_ACTION').'</span>';
			}	
			else
			{
				echo "<i>".$dictionary->TRANSLATE("EMBASSY_LEAVE_OLD_ALLIANCE_FIRST")."</i>";
			}		
			echo "</td>";
							
			echo "</tr>\n";
			
			$i++;		
		}
		
		echo "</table>\n";
	}
	
	private function PrintAllianceMemberTable(Alliance $alliance)
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<table style=\"width: 100%\">\n";
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
		echo "<td>".$dictionary->Translate('EMBASSY_MEMBER_INDEX')."</td>\n";
		echo "<td>".$dictionary->Translate('EMBASSY_MEMBER_NAME')."</td>\n";
		echo "<td>".$dictionary->Translate('EMBASSY_MEMBER_SCORE')."</td>\n";
		if ($this->player->GetId() == $alliance->GetAdminId())
		{
			echo "<td>".$dictionary->Translate('EMBASSY_MEMBER_KICK_ACTION_HEADER')."</td>\n";
		}
		echo "</tr>\n";
		
		$members = (array) $alliance->GetMembersForced();
		$membersSorted = array();
		foreach ($members as $member)
		{
			$membersSorted[$member->GetStringIdentifier()] = $member;
		}				
		ksort($membersSorted);
		
		$i = 0;
		foreach ($membersSorted as $member)
		{
			echo "<tr>\n";
			echo "<td style=\"text-align: center;\">".($i + 1)."</td>\n";
			echo "<td>".$member->GetStringIdentifier()."</td>\n";
			echo "<td style=\"text-align: right;\">".Utils::CountPlayerPoints($member)."</td>\n";
						
			if ($this->player->GetId() == $alliance->GetAdminId())
			{
				echo "<td style=\"text-align: center;\">";
				if ($member->GetId() != $this->player->GetId())
				{
					echo "<span class=\"LoginPanel_link\" ";
					echo "onclick=\"".self::CLASS_NAME."_KickMember(" .
							"".$member->GetId().", " .
							"'".sprintf($dictionary->Translate("EMBASSY_MEMBER_KICK_QUESTION"), $member->GetStringIdentifier())."', " .
							"'".$dictionary->Translate("EMBASSY_KICK_ENTER_REASON")."')\">\n";
					echo $dictionary->Translate('EMBASSY_MEMBER_KICK_ACTION').'</span>';
				}
				else
				{
					echo "-";
				}
				echo "</td>\n";
			}
			
			echo "</tr>\n";
			
			$i++;
		}
		
		echo "</table>\n";
	}
	
	public function UpdateSize()
	{
		if ($this->gamePlan == NULL)
		{
			return;
		}
		
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}
?>