<?php

require_once('View/Control.inc');
require_once('View/DesignConstants.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once("Control/Utils.inc");
require_once("Model/SolarSystem.inc");
require_once("Model/WormHole.inc");

class GalaxyMap extends Control
{
	private $ship;
	
	private $delivery;
	
	private $targetSystem;
	
	private $parentControl;
	
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		
		$this->htmlId = $newId;
	}
		
	const CLASS_NAME = "GalaxyMap";
		
	public function __construct(Control $parentControl = NULL, Ship $ship = NULL, Delivery $delivery = NULL, SolarSystem $targetSystem = NULL)
	{
		$this->htmlId = self::CLASS_NAME;
		
		$this->ship = $ship;
		$this->delivery = $delivery;
		$this->parentControl = $parentControl;		
		
		if ($this->delivery == NULL)
		{
			$this->targetSystem = $targetSystem;
		}
		else
		{
			$targetPlanet = Planet::LoadFromDB($this->delivery->GetLocationID());
			if ($targetSystem != NULL && $targetSystem->GetId() == $targetPlanet->GetSolarSystemId())
			{
				$this->targetSystem = $targetSystem;
			}
			else
			{
				$this->targetSystem = SolarSystem::LoadFromDB($targetPlanet->GetSolarSystemId());
			}
		}
	}	
		
	public function Render()
	{	
		$this->UpdateSize();
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$this->GenerateStyleString().'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(this, event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
				
		echo "<img style=\"position: absolute; left: 0x; top: 0px;\" src=\"Images/galaxy_map.png\" " .
				"width=\"100%\" height=\"100%\" alt=\"GalaxyMap\" />";
		/*
		echo '<div class="GamePlan_SolarSystemName">';
		echo $dictionary->Translate("GALAXY_MAP_HEADLINE");
		echo "</div>\n";*/	
		
		$closeBtnX0 = 0.90965092402 * $this->GetWidth();
		$closeBtnY0 = 0.03901437 * $this->GetHeight();
		$closeBtnX1 = 0.94455852156 * $this->GetWidth();
		$closeBtnY1 = 0.07802874 * $this->GetHeight();
	
		echo "<div name=\"".self::CLASS_NAME."_btnClose\" ";
		echo "style=\"cursor: pointer; position: absolute; " . 
			sprintf("left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 
			$closeBtnX0, $closeBtnY0, $closeBtnX1 - $closeBtnX0, $closeBtnY1 - $closeBtnY0).".\" ";
			//0, 0, 200,200).".\" ";
		echo "title=\"".$dictionary->Translate("CLOSE")."\" ";
		echo "onclick=\"".self::CLASS_NAME."_Hide()\" >\n";
		echo "</div>\n";
				
		echo "<div id=\"".self::CLASS_NAME."_lineDiv\"></div>\n";
		
		$this->PrintSolarSystems();
		
		echo "<div id=\"".self::CLASS_NAME."_actionBtn\" style=\"display: none; position: absolute; bottom: 10px; right: 10px;\">";
		
		if ($this->ship == NULL)
		{
			$btnActionLbl = $dictionary->Translate("GALAXY_BTN_GOTO");
		}
		else if ($this->delivery == NULL)
		{
			$btnActionLbl = $dictionary->Translate("GALAXY_BTN_FLY_SHIP");
		}
		else
		{
			$btnActionLbl = $dictionary->Translate("GALAXY_BTN_DELIVER");
		}
				
		echo "<span class=\"LoginPanel_link\" style=\"font-size: 16pt; \" ";
		echo "onclick=\"".$action = self::CLASS_NAME . "_ActionBtnOnClick(this, event)\">";
		echo $btnActionLbl.'</span>'."\n";
		
		echo "</div>\n";		
	}
	
	private function PrintSolarSystems()
	{
		//if ($this->targetSystem) echo $this->targetSystem->GetName();
		$dictionary = Dictionary::GetInstance();
		
		/*
		echo '<svg width="100%" height="100%" version="1.1" xmlns="http://www.w3.org/2000/svg">'."\n";
		foreach ($solarSystems as $solarSystem)
		{
			echo "<circle ";
			echo "cx=\"".$solarSystem->GetX() * $this->GetWidth()."\" ";
			echo "cy=\"".$solarSystem->GetY() * $this->GetHeight()."\" ";
			echo "r=\"".$systemSize."\" ";
			echo "stroke=\"yellow\" ";
			echo "stroke-width=\"2\" ";
			echo "fill=\"white\" ";
			echo "/>\n";
		}
		echo "</svg>\n";*/
				
		$solarSystems = (array)SolarSystem::LoadAllFromDB();
		$systemSize = DesignConstants::SOLAR_SYSTEM_TO_GALAXY_REL_SIZE * min($this->GetWidth(), $this->GetHeight());
		$systemConnections = array();
		
		echo "<form method=\"post\" action=\"\">";
		foreach ($solarSystems as $solarSystem)
		{
			$style = "position: absolute;";
			$style .= sprintf("left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 
				$solarSystem->GetX() * $this->GetWidth() - $systemSize / 2,
				$solarSystem->GetY() * $this->GetHeight() - $systemSize / 2,
				$systemSize, $systemSize);
			$style .= "border: 0px solid white;";
			$style .= "cursor: pointer;";
			
			$id = self::CLASS_NAME."_SolarSystem_".$solarSystem->GetId();
			
			echo "<div ";
			echo "id=\"".$id."\" ";
			echo "name=\"".self::CLASS_NAME."_SolarSystem\" ";
			echo "style=\"".$style."\" ";
			echo "onclick=\"".self::CLASS_NAME."_SystemOnClick(this, event)\" ";
			echo "ondblclick=\"".self::CLASS_NAME."_SystemOnDoubleClick(this, event)\" ";
			echo "onmouseover=\"".self::CLASS_NAME."_SystemOnMouseOver(this, event)\" ";
			echo "onmouseout=\"".self::CLASS_NAME."_SystemOnMouseOut(this, event)\" ";
			echo "tag =\"".$solarSystem->GetName()."\" ";
			echo "title =\"".$solarSystem->GetName()."\" ";
			echo "></div>\n";
			
			$wormHoles = $solarSystem->GetWormHolesForced();
			$connectionString = "";
			foreach ($wormHoles as $wormHole)
			{
				$connectionString .= $wormHole->GetOtherSystemId($solarSystem->GetId()) . ";";
			}
			
			echo "<input id=\"".$id."_connectedSystems\" name=\"connectedSystems\" type=\"hidden\" value=\"".$connectionString."\"/>";
			echo "<input id=\"".$id."_id\" name=\"id\" type=\"hidden\" value=\"".$solarSystem->GetId()."\"/>";
			
			if ($this->ship != NULL && $this->ship->GetSolarSystemId() == $solarSystem->GetId())
			{
				$initSystem = $id;
			}
			
			if ($this->targetSystem != NULL && $this->targetSystem->GetId() == $solarSystem->GetId())
			{
				$finalSystem = $id;
			}
				//$finalSystem = $initSystem;
				//$initSystem = $id;
		}
		echo "</form>\n";
		
		echo "<form method=\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_initSystem\" name=\"initSystem\" type=\"hidden\" value=\"".$initSystem."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_finalSystem\" name=\"finalSystem\" type=\"hidden\" value=\"".$finalSystem."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_shipId\" name=\"shipId\" type=\"hidden\" value=\"".($this->ship != NULL ? $this->ship->GetId() : "")."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_deliveryId\" name=\"deliveryId\" type=\"hidden\" value=\"".($this->delivery != NULL ? $this->delivery->GetId() : "")."\"/>";
		echo "</form>\n";
	}
	
	public function UpdateSize()
	{
		if ($this->parentControl == NULL)
		{
			return;
		}
		
		$this->SetWidth($this->parentControl->GetWidth());
		$this->SetHeight($this->parentControl->GetHeight());
	}
}
?>