<?php   

require_once("Model/SolarSystem.inc");
require_once("Model/Planet.inc");
require_once("Control/GameTimer.inc"); 
require_once("View/DesignConstants.inc");
require_once("View/PlanetGraphic.inc");
require_once("View/WormHoleGraphic.inc");
require_once("View/DeliveryPanel.inc");
require_once("View/Control.inc");
require_once("View/PlanetInfoPanel.inc");
require_once('View/ShipSelectionPanel.inc');
require_once('View/PlanetHomePlayersPanel.inc');
require_once('View/ShipGraphic.inc');
require_once('View/ShipShopPanel.inc');
require_once('View/HighScorePanel.inc');
require_once('View/MessagePanel.inc');
require_once('View/GuardAssignmentPanel.inc');
require_once('View/Graphics.inc');
require_once('View/EmbassyPanel.inc');
require_once("View/AllianceTransferPanel.inc");
require_once("View/GalaxyMap.inc");

/**
 * Control of game plan. Shows planets, space, ships, cargo...
 */
class GamePlan extends Control
{	
	const CLASS_NAME = "GamePlan";
	
	/**
	 * Displayed solar system.
	 */	
	private $solarSystem;
		
	/**
	 * Gets displayed solar system.
	 */
	public function GetSolarSystem()
	{
		return $this->solarSystem;
	}
	
	private $deliveryPanel;
		
	/**
	 * Gets displayed solar system.
	 */
	public function GetDeliveryPanel()
	{
		return $this->deliveryPanel;
	}
	
	private $controls;
	
	public function AddControl(Control $control)
	{
		array_push($this->controls, $control);
	}
	
	private $ships;
	
	public function AddShip(ShipGraphic $ship)
	{
		array_push($this->ships, $ship);
	}
	
	/**
	 * Creates new GamePlan width specified solar system.
	 * @param solarSystem associated solar system
	 */
	public function __construct(SolarSystem $solarSystem)
	{
		if ($solarSystem == NULL)
		{
			throw new Exception("Solar system must not be null."); 
		}
		
		$this->SetBackgroundColor("black");
		
		$this->solarSystem = $solarSystem;
		$this->controls = array();
		$this->ships = array();
		
		$deliveryPanel = new DeliveryPanel($this);
		$deliveryPanel->SetVisible(false);
		$deliveryPanel->SetBackgroundColor('#00110c');
		array_push($this->controls, $deliveryPanel);
		
		$shipSelectionPanel = new ShipSelectionPanel($this);
		$shipSelectionPanel->SetVisible(false);
		$shipSelectionPanel->SetBackgroundColor("#00110c");
		array_push($this->controls, $shipSelectionPanel);
		
		$planetHomePlayersPanel = new PlanetHomePlayersPanel($this);
		$planetHomePlayersPanel->SetVisible(false);
		$planetHomePlayersPanel->SetBackgroundColor("#00110c");
		array_push($this->controls, $planetHomePlayersPanel);
		
		$shipShopPanel = new ShipShopPanel($this);
		$shipShopPanel->SetVisible(false);
		$shipShopPanel->SetBackgroundColor('#00110c');
		array_push($this->controls, $shipShopPanel);
		
		$highScorePanel = new HighScorePanel($this);
		$highScorePanel->SetVisible(false);
		$highScorePanel->SetBackgroundColor('#00110c');
		array_push($this->controls, $highScorePanel);
		
		$messagePanel = new MessagePanel($this);
		$messagePanel->SetVisible(false);
		$messagePanel->SetBackgroundColor('#00110c');
		array_push($this->controls, $messagePanel);
		
		$guardAssignmentPanel = new GuardAssignmentPanel($this);
		$guardAssignmentPanel->SetVisible(false);
		$guardAssignmentPanel->SetBackgroundColor('#00110c');
		array_push($this->controls, $guardAssignmentPanel);
		
		$embassyPanel = new EmbassyPanel($this);
		$embassyPanel->SetVisible(false);
		$embassyPanel->SetBackgroundColor('#00110c');
		array_push($this->controls, $embassyPanel);
		
		$allianceTransferPanel = new AllianceTransferPanel($this);
		$allianceTransferPanel->SetVisible(false);
		$allianceTransferPanel->SetBackgroundColor("#00110c");
		array_push($this->controls, $allianceTransferPanel);	
		
		$galaxyMap = new GalaxyMap($this);
		$galaxyMap->SetVisible(false);
		$galaxyMap->SetBackgroundColor("#00110c");
		array_push($this->controls, $galaxyMap);	
	}
	
	public function WorldToScreenCoords($worldX, $worldY, $width = 0, $height = 0)
	{
		$screenX = ($this->width - $width) / 2 + $worldX / $this->solarSystem->GetSystemWidth() * $this->width;
		$screenY = ($this->height - $height) / 2 - $worldY / $this->solarSystem->GetSystemHeight() * $this->height;
					
		return Array($screenX, $screenY); 
	}
	
	/**
	 * Converts in game coordinates to screen pixels according to
	 * this control's size and ingame size of solar system.
	 * @param worldX ingame X coordinate
	 * @param worldY ingame Y coordinate
	 * @return on screen coordinates in pixels relative to
	 * this control's position as length 2 array
	 */
	public function PlanetWorldToScreen($worldX, $worldY)
	{
		return $this->WorldToScreenCoords($worldX, $worldY, DesignConstants::PLANET_SIZE, DesignConstants::PLANET_SIZE);
	}
	
	/**
	 * Generates unique ID for control for HTML.
	 */
	public function GetHtmlId()
	{
		return "GamePlan";
	}
	
	/**
	 * Renders this control to page.
	 */
    public function Render()
    {
        require("View/GamePlan.Design.inc");
    }
    
}

?>
