<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once("View/ShipGraphic.inc");
require_once('View/DesignConstants.inc');
require_once('View/LeftMenuPanel.inc');
require_once('View/HeaderPanel.inc');
require_once('View/MenuPanel.inc');
require_once('View/DisplayFilterPanel.inc');
require_once('View/LoginPanel.inc');
require_once('View/LogViewPanel.inc');
require_once('View/LanguageSelector.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Utils.inc');
require_once('Control/GameConstants.inc');
require_once("Model/SolarSystem.inc");

class GameScreen extends Control
{
	const CLASS_NAME = "GameScreen";
	
	private $gamePlan;
	private $displayFilterPanel;
	private $languageSelector;
	private $loginPanel;
	private $menuPanel;
	private $logViewPanel;
	private $leftMenuPanel;
	private $headerPanel;
	
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function __construct($screenWidth, $screenHeight)
	{
		$this->SetAutoSize(true);
		$this->htmlId = self::CLASS_NAME;
		$gamePlanSize = DesignConstants::GetGamePlanSize($screenWidth, $screenHeight);
		$this->BuildScreen($gamePlanSize);
	}
	
	private function BuildScreen($gamePlanSize)
	{
		$dictionary = Dictionary::GetInstance();
		$solarSystem = Globals::GetActiveSolarSystem();
		$player = Globals::GetActivePlayer();
		
		$this->leftMenuPanel = new LeftMenuPanel();
		$this->leftMenuPanel->SetWidth(213);
		$this->leftMenuPanel->SetHeight(585);
		
		$this->headerPanel = new HeaderPanel($player);
		$this->headerPanel->SetWidth(469);
		$this->headerPanel->SetHeight(121);
		$this->headerPanel->SetX($this->leftMenuPanel->GetWidth());
		 
		$this->gamePlan = new GamePlan($solarSystem);
		$this->gamePlan->SetWidth($gamePlanSize[0]);
		$this->gamePlan->SetHeight($gamePlanSize[1]);
		$this->gamePlan->SetX($this->leftMenuPanel->GetWidth());
		$this->gamePlan->SetY($this->headerPanel->GetHeight());
		
		if ($player != NULL)
		{
			foreach ($player->GetShipsForced() as $ship)
			{
				if ($ship->GetSolarSystemId() != $solarSystem->GetId())
				{
					continue;
				}
				$shipGraphic = new ShipGraphic($ship, $this->gamePlan);
				$shipGraphic->SetVisible(false);
				$this->gamePlan->AddShip($shipGraphic);
			}
		}
		
		$this->loginPanel = new LoginPanel($player);
		$this->loginPanel->SetWidth(253);
		$this->loginPanel->SetHeight(108);
		$this->loginPanel->SetX($this->headerPanel->GetX() + $this->headerPanel->GetWidth());
		$this->loginPanel->SetBackgroundColor("LightBlue");
		
		$this->languageSelector = new LanguageSelector();
		$this->languageSelector->SetAutoSize(true);
		$this->languageSelector->SetX($this->loginPanel->GetX() + 160);
		$this->languageSelector->SetY(26);
		$this->languageSelector->SetBackgroundColor("LightGreen");
		
		$this->menuPanel = new MenuPanel($this->gamePlan);
		$this->menuPanel->SetWidth($this->loginPanel->GetWidth());
		$this->menuPanel->SetHeight(477);
		$this->menuPanel->SetX($this->loginPanel->GetX());
		$this->menuPanel->SetY($this->loginPanel->GetY() + $this->loginPanel->GetHeight());
		$this->menuPanel->SetBackgroundColor("Yellow");		
		
		$this->logViewPanel = new LogViewPanel($player);
		$this->logViewPanel->SetWidth(935);
		$this->logViewPanel->SetHeight(124);
		$this->logViewPanel->SetX(0);
		$this->logViewPanel->SetY($this->leftMenuPanel->GetHeight());
		$this->logViewPanel->SetBackgroundColor("White");
		
		$this->displayFilterPanel = new DisplayFilterPanel();
		$this->displayFilterPanel->SetWidth($gamePlanSize[0]);
		$this->displayFilterPanel->SetHeight(DesignConstants::DISPLAY_FILTER_HEIGHT);
		$this->displayFilterPanel->SetX(0);
		$this->displayFilterPanel->SetY($this->gamePlan->GetY() + $this->gamePlan->GetHeight());
				
	}	
	
	public function Render()
	{
		$style = "width: " . ($this->leftMenuPanel->GetWidth() + $this->gamePlan->GetWidth() + $this->menuPanel->GetWidth()) . "px;";
		$style .= "margin: auto;";
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo '>'."\n";
		
		$this->RenderContent();
				
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();		
		
		echo '<div style="position: absolute">';						
		
		$this->leftMenuPanel->Render();
		$this->headerPanel->Render();
		$this->gamePlan->Render();
		//$this->displayFilterPanel->Render();
		$this->menuPanel->Render();
		$this->loginPanel->Render();
		$this->languageSelector->Render();
		$this->logViewPanel->Render();
		
		/*echo "<div style=\"position: absolute; top: -14px; left: 2px; width: 200px; font-size: 10pt;\">";
		echo "<p>\n<a href=\"info.php\" style=\"color: white; font-weight: bold; cursor: pointer;\">Stav aplikace</a><br />\n";
		echo "<span onclick=\"UpdateGameState()\" style=\"color: white; font-weight: bold;\">".
			 "<span style=\"text-decoration: underline; cursor: pointer;\">Aktualizovat stav hry</span></span>\n";
		echo "<br/>";
		echo "</div>\n";*/
		
		echo "</div>";		
	}	
}

?>