<?php

require_once('View/Control.inc');
require_once('View/DeliveryPanel.inc');
require_once('Model/Ship.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once('Control/GameConstants.inc');
require_once('Control/ShipActionController.inc');

class GuardAssignmentPanel extends Control
{
	private $gamePlan;
	
	private $htmlId;
	
	const CLASS_NAME = "GuardAssignmentPanel";
		
	public function __construct(GamePlan $gamePlan)
	{
		$this->gamePlan = $gamePlan;
		$this->htmlId = self::CLASS_NAME;
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
		
	public function Render()
	{
		$this->UpdateSize();	
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/ship_management.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 18, 35, 433, 353);
		echo '<div style="'.$divStyle.'">';
		
		echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%; position: relative; top: 10px;">';
		echo $dictionary->Translate("GUARD_ASSIGN_HEADLINE");
		echo "</div>\n";
			
		$player = Globals::GetActivePlayer();
		if ($player != NULL)
		{
			$divStyle = sprintf("position: relative; top: %fpx;", 35);
			echo '<div style="'.$divStyle.'">';
			$this->PrintGuards($player);
			echo '</div>'."\n";
		}
		
		echo "</div>\n";
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
	}
	
	private function PrintGuards(Player $player)
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<form method\"post\" action=\"\">";
		
		echo "<table style=\"width: 100%\">\n";
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
		echo "<td>"."</td>\n";
		echo "<td>".$dictionary->Translate('GUARD_NAME')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_CLASS')."</td>\n";
		echo "<td>".$dictionary->Translate('GUARD_CARGO_ASSIGN')."</td>\n";
		echo "<td>".$dictionary->Translate('GUARD_GIVE_PIRATES')."</td>\n";
		echo "</tr>\n";
		
		$ships = (array)$player->GetShipsForced();
		$guards = array();
		$cargos = array();
		
		foreach ($ships as $ship)
		{
			if ($ship->GetModel()->GetShipType()->GetId() == GameConstants::GUARD_SHIP_TYPE_ID)
			{
				$guards[$ship->GetId()] = $ship;
			}
			else if ($ship->GetModel()->GetShipType()->GetId() == GameConstants::CARGO_SHIP_TYPE_ID)
			{
				$cargos[$ship->GetId()] = $ship;
			}			
		}
		
		$optionCount = 0;
		$inputIds = array();
					
		foreach ($guards as $guard)
		{			
			echo "<tr>\n";
			echo "<td style=\"text-align: center; font-style: italic;\">".($optionCount + 1)."</td>\n";
			echo "<td>".$guard->GetName()."</td>\n";
			echo "<td>".$guard->GetModel()->GetName()."</td>\n";
			
			echo "<td>";
			$inputIds[$optionCount] = $this->PrintAssignmentOptions($player, $guard, $cargos);			
			echo "</td>\n";
			
			echo "<td style=\"text-align: center;\">";
			echo '<input type="checkbox" id="'.$inputIds[$optionCount].'_grantPirates" ';
			echo 'onchange="'.self::CLASS_NAME."_GrantChanged('".$inputIds[$optionCount]."')\"/>";			
			echo "</td>\n";
						
			echo "</tr>\n";
			
			$optionCount++;
		}
		
		$idJSArray = "new Array(";
		for ($i = 0; $i < $optionCount; $i++)
		{
			$idJSArray .= "'" . $inputIds[$i] . "'";
			
			if ($i != $optionCount - 1)
			{
				$idJSArray .= ", ";
			}
		}	
		$idJSArray .= ")";	 
				
		echo "</table>\n";
				
		Graphics::PrintBtn($dictionary->Translate("RESET"), 0, 293, 35, 22, self::CLASS_NAME."_Show()");
		Graphics::PrintBtn($dictionary->Translate("APPLY_CHANGES"), 354, 293, 85, 22, self::CLASS_NAME."_ApplyChanges(".$idJSArray.")");
		
		echo "</form>\n";
	}
	
	private function PrintAssignmentOptions(Player $player, Ship $guard, array $cargos)
	{
		$dictionary = Dictionary::GetInstance();
		$name = "guard_".$guard->GetId();
		$id = $this->GetHtmlId() . "_" . $name;
		echo "<select name=\"".$name."\" id=\"".$id."\">\n";
		
		$shipController = new ShipActionController($player, $guard, $this->gamePlan->GetSolarSystem()); // who cares about solar system there
		$assignedShipId = $shipController->GetGuardedShipId();
		
		echo "<option";
		if ($assignedShipId == -1)
		{
			echo " selected=\"selected\"";
		}
		echo " value=\"-1\">";
		echo $dictionary->Translate("GUARD_UNASSIGNED");
		echo "</option>\n";
		
		foreach ($cargos as $cargo)
		{
			echo "<option";
			if ($assignedShipId == $cargo->GetId())
			{
				echo " selected=\"selected\"";
			}
			echo " value=\"".$cargo->GetId()."\">";
			
			echo $cargo->GetName();
			echo "</option>\n";
		}
		
		echo "</select>\n";
		
		return $id;
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}

?>