<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Utils.inc');

class HeaderPanel extends Control
{
	const CLASS_NAME = "HeaderPanel";
	
	const IMG_PATH = "Images/interface/top_panel/";
	
	private $htmlId;
	
	private $player;
	
	public function __construct($player)
	{
		$this->htmlId = self::CLASS_NAME;
		
		$this->player = $player;
		
		if ($this->player == NULL)
		{
			$this->player = Globals::GetActivePlayer();
		}
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function Render()
	{
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/top_panel.png');";
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo '>'."\n";
		
		$this->RenderContent();
		
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		if ($this->player == NULL)
		{
			return;
		}
		
		$this->RenderRelationBar();
		$this->RenderIcons();
		$this->RenderText();		
	}
	
	public function RenderIcons()
	{
		$dictionary = Dictionary::GetInstance();
		
		$shipCount = count($this->player->GetShipsForced());
		$countLbl = "<span class=\"WhiteText\">" . $shipCount . "</span>";
		Graphics::PrintTextBtn($dictionary->Translate("HEADER_SHIP_COUNT") . ": " . $countLbl, -2, 27, "", "", "", $dictionary->Translate("HEADER_SHIP_COUNT"));
		
		$action = "GuardAssignmentPanel_Show()";
		$label = $dictionary->Translate("HEADER_SHOW_UNIVERSAL");
		Graphics::PrintBtn($label, 3, 43, 52, 38, $action);
		Graphics::PrintTextBtn($label, 5, 84, "", "HeaderPanel_link", $action);
		
		/**/
		
		$baseCount = count($this->player->GetBasesForced());
		$countLbl = "<span class=\"WhiteText\">" . $baseCount . "</span>";
		Graphics::PrintTextBtn($dictionary->Translate("HEADER_BASE_COUNT") . ": " . $countLbl, 90, 27, "", "", "", $dictionary->Translate("HEADER_BASE_COUNT"));
		
		$action = "MenuPanel_SelectShip(null)";
		Graphics::PrintBtn($label, 102, 43, 52, 38, $action);
		Graphics::PrintTextBtn($label, 106, 84, "", "HeaderPanel_link", $action);
		
		/**/
		
		$messages = $this->player->GetMessagesForced();
		$messageAllCount = count($messages);
		$messageUnreadCount = 0;
		foreach ($messages as $message)
		{
			if (!$message->WasRead())
			{
				$messageUnreadCount++;
			}
		}
		$messageUnreadLbl = "<span class=\"WhiteText\">" . $messageUnreadCount . "</span>";
		Graphics::PrintTextBtn(
			sprintf($dictionary->Translate("HEADER_MESSAGE_COUNT"), "" . $messageUnreadLbl, $messageAllCount),
			203, 27, "", "", "", 
			sprintf($dictionary->Translate("HEADER_MESSAGE_COUNT"), "" . $messageUnreadCount, $messageAllCount));
			
		$action = "MessagePanel_ShowList()";
		Graphics::PrintBtn($label, 202, 43, 52, 38, $action);
		Graphics::PrintTextBtn($label, 210, 84, "", "HeaderPanel_link", $action);
	}
	
	public function RenderText()
	{
		$dictionary = Dictionary::GetInstance();
		
		$money = $this->player->GetMoney();
		$label = "<span class=\"WhiteText\">$" . number_format($money, 0, ',', ' ') . "</span>";
		Graphics::PrintTextBtn(sprintf($dictionary->Translate("HEADER_MONEY"), $label), 279, 27);
		
		$rank = Utils::GetPlayerRank($this->player);
		$playerCount = Player::CountAll();
		$label = "<span class=\"WhiteText\">" . $rank . "</span>";
		Graphics::PrintTextBtn(sprintf($dictionary->Translate("HEADER_RANK"), $label, $playerCount), 382, 27);
		
		$licenceCount = $this->player->GetLicenceCount();
		$licenceUsed = Utils::CalculatePlayerUsedLicences($this->player);
		$label = "<span class=\"WhiteText\">" . $licenceUsed . "</span>";
		Graphics::PrintTextBtn(sprintf($dictionary->Translate("HEADER_LICENCE"), $label, $licenceCount), 279, 50);
		
		$alliance = Alliance::LoadFromDB($this->player->GetAllianceId())->GetName();
		$label = "<span class=\"WhiteText\">" . $alliance . "</span>";
		Graphics::PrintTextBtn(sprintf($dictionary->Translate("HEADER_ALLIANCE"), $label, $licenceCount), 382, 50);
		
	}
	
	public function RenderRelationBar()
	{
		$dictionary = Dictionary::GetInstance();
		
		$rel = Utils::GetPlayersAlliancePirateRelations($this->player);
		$relTag = $rel + 5;
		$relTag = max(min($relTag, 9), 1);
		
		$label = $dictionary->Translate("HEADER_PIRATE_REL");
				
		echo "<img ";
		echo "src=\"".self::IMG_PATH."vztah".$relTag.".jpg\" ";
		echo "width=\"\" ";
		echo "height=\"\" ";
		echo "style=\"".sprintf("position: absolute; left: %fpx; top: %fpx;", 271, 74)."\" ";
		echo "alt=\"".$label."\" ";
		echo "title=\"".$label."\" ";
		echo "/>\n";
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 279, 84, 165, 11);
		$divStyle .= "text-align: center;";
		echo "<div ";
		echo "style=\"".$divStyle."\" ";
		echo "title=\"".$label."\" ";
		echo "/>\n";
		echo "<span class=\"WhiteText\" style=\"font-size: 8pt;\">".$label."</span>\n";
		echo "</div>\n";
	}
}

?>