<?php

require_once('View/Control.inc');
require_once('Model/Ship.inc');
require_once('Model/ShipModel.inc');
require_once('Model/GoodClass.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once('Control/Utils.inc');
require_once('Control/GameConstants.inc');

class HighScorePanel extends Control
{
	private $gamePlan;
		
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
	
	private $sortKey;
	
	public function SetSortKey($key)
	{
		$this->sortKey = $key; 
	}
	
	private $sortOrder;
	
	public function SetSortOrder($order)
	{
		$this->sortOrder = $order; 
	}
	
	const CLASS_NAME = "HighScorePanel";
		
	public function __construct(GamePlan $gamePlan)
	{
		$this->gamePlan = $gamePlan;
		$this->htmlId = self::CLASS_NAME;
		$this->sortKey = "points";
		$this->sortOrder = "desc";
	}	
		
	public function Render()
	{
		$this->UpdateSize();	
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/highscore.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 18, 40, 433, 348);
		echo '<div style="'.$divStyle.'">';
				
		echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
		echo $dictionary->Translate("HIGH_SCORE_PANEL_HEADLINE");
		echo "</div>";
			
		$this->PrintHighScoreTable();
		
		echo "</div>\n";		
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
	}
	
	private function PrintHighScoreTable()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<table style=\"width: 100%\">\n";
		
		$this->PrintHeader();
		
		$rows = $this->GenerateRows();
		
		$i = 0;
		foreach ($rows as $rowArray)
		{
			foreach ($rowArray as $row)
			{
				echo "<tr>\n";
				echo "<td>".($i + 1)."</td>\n";
				echo "<td>".$row["name"]."</td>\n";
				echo "<td>".$row["points"]."</td>\n";
				echo "<td>".$row["deliveryCount"]."</td>\n";
				echo "<td>".$row["shipCount"]."</td>\n";
				echo "<td>".$row["buildingCount"]."</td>\n";
				echo "</tr>\n";
				$i++;
			}
		}
		
		echo "</table>\n";
	}
	
	private function PrintHeader()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
			
		
		$this->PrintHeaderCell('HIGH_SCORE_ORDER', "", "");
		
		$this->PrintSortableHeaderCell('HIGH_SCORE_NAME', "name", "asc");
		$this->PrintSortableHeaderCell('HIGH_SCORE_POINTS', "points", "desc");	
		$this->PrintSortableHeaderCell('HIGH_SCORE_DELIVERED', "deliveryCount", "desc");	
		$this->PrintSortableHeaderCell('HIGH_SCORE_SHIPS', "shipCount", "desc");
		$this->PrintSortableHeaderCell('HIGH_SCORE_BUILDINGS', "buildingCount", "desc");	
				
		echo "</tr>\n";
	}
	
	private function PrintSortableHeaderCell($dictNameKey, $sortKey, $defaultOrder)
	{
		$sortOrder = $defaultOrder;
		$style = "text-decoration: underline; cursor: pointer;";
		
		if (!strcasecmp($this->sortKey, $sortKey))
		{
			$style .= " font-weight: bold;";
			
			if (!strcasecmp($this->sortOrder, $sortOrder))
			{
				if (!strcasecmp($sortOrder, "desc"))
			    {
			    	$sortOrder  = "asc";
			    }
			    else
			    {
			    	$sortOrder = "desc";	
			    }				
			}
		}		
		
		$action = self::CLASS_NAME . "_Show('".$sortKey."', '".$sortOrder."')";
		$this->PrintHeaderCell($dictNameKey, $style, $action);	
	}
	
	private function PrintHeaderCell($nameKey, $style = "", $action = "")
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<td";
		
		if (strlen($style) > 0)
		{
			echo " style=\"".$style."\"";
		}
		
		if (strlen($action) > 0)
		{
			echo " onclick=\"".$action."\"";
		}
		
		echo ">";
		echo $dictionary->Translate($nameKey);
		echo "</td>\n";
	}
	
	private function GenerateRows()
	{
		$rows = array();
		$players = (array)Player::LoadAllFromDB();
		
		foreach ($players as $player)
		{											
			$name = $player->GetNick();
			if (strlen($name) == 0)
			{
				$name = $player->GetLogin();
			}			
			
			$ships = (array)$player->GetShipsForced();
			$shipCount = count($ships);
			$deliveryCount = Utils::CountPlayerDeliveries($player);
			$points = Utils::CountPlayerPoints($player);
			$buildingCount = count($player->GetBasesForced());
			
			$row = array("name" => $name, "points" => $points, "shipCount" => $shipCount, 
						"deliveryCount" => $deliveryCount, "buildingCount" => $buildingCount);
			
			if (!strcasecmp($this->sortKey, "name"))
			{
				$key = strtolower($name);
			}
			else if (!strcasecmp($this->sortKey, "buildingCount"))
			{
				$key = $buildingCount;
			}
			else if (!strcasecmp($this->sortKey, "shipCount"))
			{
				$key = $shipCount;
			}
			else if (!strcasecmp($this->sortKey, "deliveryCount"))
			{
				$key = $deliveryCount;
			}
			else
			{
				$key = $points;
			}	
			
			if (!array_key_exists($key, $rows))
			{
				$rows[$key] = array();
			}
			
			array_push($rows[$key], $row);
		}
		
		if (!strcasecmp($this->sortOrder, "asc"))
		{
			ksort($rows);
		}
		else
		{
			krsort($rows);
		}
		
		return $rows;
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}
?>