<?php

require_once('View/Control.inc');
require_once("Control/Dictionary.inc");
require_once("Control/Globals.inc");
require_once("View/DesignConstants.inc");
require_once("View/LoginPanel.inc");
require_once("View/LanguageSelector.inc");

class IntroScreen extends Control
{
	const CLASS_NAME = "IntroScreen";
	
	private $languageSelector;
	private $loginPanel;
	
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function __construct()
	{
		$this->SetAutoSize(true);
		$this->htmlId = self::CLASS_NAME;
		$this->BuildScreen();
	}
	
	private function BuildScreen()
	{
		$dictionary = Dictionary::GetInstance();
		
		$this->languageSelector = new LanguageSelector();
		$this->languageSelector->SetWidth(DesignConstants::RIGHT_PANEL_WIDTH);
		$this->languageSelector->SetHeight(DesignConstants::LANGUAGE_SELECTOR_HEIGHT);
		$this->languageSelector->SetX(840);
		$this->languageSelector->SetY(24);
		$this->languageSelector->SetWidth(41);
		$this->languageSelector->SetHeight(19);
		$this->languageSelector->SetBackgroundColor("Transparent");
		
		$this->loginPanel = new LoginPanel(NULL);
		$this->loginPanel->SetWidth($this->languageSelector->GetWidth());
		$this->loginPanel->SetHeight(DesignConstants::LOGIN_PANEL_HEIGHT);
		$this->loginPanel->SetX(378);
		$this->loginPanel->SetY(244);
		$this->loginPanel->SetWidth(313);
		$this->loginPanel->SetHeight(97);
		$this->loginPanel->SetBackgroundColor("Transparent");				
	}	
	
	public function Render()
	{
		$backgroundStyle = sprintf("width: %fpx; height: %fpx; background-image:url('%s'); margin: auto; margin-top: -7px;", 
									935, 709, "Images/interface/intro/intro.jpg");
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$backgroundStyle.'"';
		echo '>'."\n";
		
		$this->RenderContent();
				
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();		
		
		echo '<div style="position: absolute">';
		
		$this->languageSelector->Render();
		$this->loginPanel->Render();
		
		echo "<div id=\"".self::CLASS_NAME."_textPanels\">\n";
		
		$name = self::CLASS_NAME . "_textPanel";
		
		$id1 = self::CLASS_NAME . "_whatIsPanel";
		$this->RenderTextPanel($dictionary->Translate("INTROSCREEN_WHATIS_PANEL"), $id1, $name, "WhiteText", "font-size: 10pt;", "Images/interface/intro/control_bar_1.png", true);
		
		$id2 = self::CLASS_NAME . "_howPlayPanel";
		$this->RenderTextPanel($dictionary->Translate("INTROSCREEN_HOWPLAY_PANEL"), $id2, $name, "WhiteText", "font-size: 10pt;", "Images/interface/intro/control_bar_2.png");
		
		$id3 = self::CLASS_NAME . "_whatWinPanel";
		$this->RenderTextPanel($dictionary->Translate("INTROSCREEN_WHATWIN_PANEL"), $id3, $name, "WhiteText", "font-size: 10pt;", "Images/interface/intro/control_bar_3.png");
		
		Graphics::PrintBtn($dictionary->Translate("INTROSCREEN_WHATIS_PANEL_HL"), 201, 371, 107, 18, self::CLASS_NAME . "_ShowPanel('".$id1."', event)");
		Graphics::PrintBtn($dictionary->Translate("INTROSCREEN_HOWPLAY_PANEL_HL"), 329, 371, 48, 18, self::CLASS_NAME . "_ShowPanel('".$id2."', event)");
		Graphics::PrintBtn($dictionary->Translate("INTROSCREEN_WHATWIN_PANEL_HL"), 398, 371, 86, 18, self::CLASS_NAME . "_ShowPanel('".$id3."', event)");
		
		echo "</div>\n";
		
		echo "</div>\n";
		
		/*
		echo "<a style=\"position: absolute; left: 0px; top: 0px; color: white;\" class=\"LoginPanel_link\" href=\"index2.php?guest=true\" >";
		echo "Volny vstup (docasne reseni)";
		echo "</a>";*/	
	}	
	
	private function RenderTextPanel($text, $id, $name = "", $class = "", $style = "", $headerImageURL = "", $visible = false)
	{
		$divStyle = $visible ? "display: block;" : "display: none;"; 
		
		echo "<div ";
		echo "id=\"".$id."\" ";
		echo "name=\"".$name."\" ";
		echo "style=\"".$divStyle."\" ";
		echo ">\n";
				
		$style = $style . ";" . sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 210, 399, 529, 114);
		
		echo "<div ";
		echo "style=\"".$style."\" ";
		echo "class=\"".$class."\" ";
		echo ">\n";
				
		echo $text;
		
		echo "</div>\n";
		
		$headerStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 200, 244 + 97 + 29, 303, 20);
		$headerStyle .= "background-image: url('".$headerImageURL."');";
		echo "<div ";
		echo "style=\"".$headerStyle."\" ";
		echo "></div>\n";
			
		echo "</div>\n";	
	}
}

?>