<?php

require_once('View/Control.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once('Control/ActionLogger.inc');
require_once("Control/Utils.inc");

class LogViewPanel extends Control
{
	const DEFAULT_ROW_COUNT = 5;
	const FULL_ROW_COUNT = 100;
	
	const IMAGE_PATH = "Images/interface/bottom_panel";
	
	private $actionLogger;
		
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		
		$this->htmlId = $newId;
	}
	
	private $rowCount;
	
	public function SetRowCount($rowCount)
	{
		$this->rowCount = $rowCount;
	}
	
	const CLASS_NAME = "LogViewPanel";
		
	public function __construct(Player $player = NULL)
	{
		$this->htmlId = self::CLASS_NAME;
		//$this->SetBackgroundColor("DeepSkyBlue");
		if ($player != NULL)
		{
			$this->actionLogger = new ActionLogger($player);
		}
		
		$this->rowCount = self::DEFAULT_ROW_COUNT;
	}	
		
	public function Render()
	{	
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('".self::IMAGE_PATH.".png');";
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{				
		if ($this->actionLogger == NULL)
		{
			return;
		}
		
		$dictionary = Dictionary::GetInstance();
		
		$style = sprintf("position: relative; left: %fpx; top: %fpx; width: %fpx; ",
			187, 14, 526);
		$style .= "background-image:url('".self::IMAGE_PATH."/log_repeater.png'); background-repeat:repeat-y;";
		//$style .= "padding-left: 16px; padding-right: 9px;";
		
		echo "<div ";
		echo "style=\"".$style."\" ";
		echo ">\n";
		
		echo "<img style=\"position: absolute; left: 0x; top: 0px;\" src=\"".self::IMAGE_PATH."/log_header.png\" " .
				"width=\"526px\" height=\"28px\" alt=\"".self::CLASS_NAME."_header\" />";
		echo "<img style=\"position: absolute; left: 0x; bottom: -16px;\" src=\"".self::IMAGE_PATH."/log_footer.png\" " .
				"width=\"526px\" height=\"28px\" alt=\"".self::CLASS_NAME."_header\" />";
		
		$style = sprintf("position: relative; left: %fpx; top: %fpx; width: %fpx; ",
			16, 0, 495);
		echo "<div ";
		echo "style=\"".$style."\" ";
		echo ">\n";
		
		$records = $this->actionLogger->GetLatestRecords($this->rowCount);
		
		foreach ($records as $record)
		{
			$date = Utils::GetDateTimeString($record->GetDate());
			$text = $this->actionLogger->BuildTextString($record);
			
			echo "<span style=\"color: white\">" . $date . "</span>";
			echo  " - " . $text . "<br/>\n";
		}
		
		if ($this->rowCount < self::FULL_ROW_COUNT)
		{
			echo "<span class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_Update(".self::FULL_ROW_COUNT.")\">";
			echo $dictionary->Translate("LOG_SHOW_ALL").'</span>'."\n";
		}
		else
		{
			echo "<span class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_Update(".self::DEFAULT_ROW_COUNT.")\">";
			echo sprintf($dictionary->Translate("LOG_SHOW_SHORT"), self::DEFAULT_ROW_COUNT).'</span>'."\n";
		}
		
		echo "</div>\n";
		echo "</div>\n";
		echo "<p>&nbsp;</p>";
	}
}
?>