<?php

require_once('View/Control.inc');
require_once('Control/Dictionary.inc');

class LoginPanel extends Control
{
	const CLASS_NAME = "LoginPanel";
	
	private $player;
	
	public function SetPlayer($player)
	{
		$this->player = $player;
	}
	
	private $errorMessage = NULL;
	
	public function GetErrorMessage()
	{
		return $this->errorMessage;
	}
	
	public function SetErrorMessage($message)
	{
		$this->errorMessage = $message;
	}
	
	private $htmlId;
		
	public function __construct(Player $player = NULL)
	{
		$this->player = $player;
		$this->htmlId = "LoginPanel_" . rand();
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
		
	public function Render()
	{
		echo '<div id="'.$this->GetHtmlId().'" class="LoginPanel" style="'.$this->GenerateStyleString().'">'."\n";
		$this->RenderContentOnly();
		echo "</div>\n";
	}
	
	public function RenderContentOnly()
	{				
		if ($this->player == NULL)	
		{
			$this->RenderUnloggedContent();
		}	
		else
		{
			$this->RenderLoggedContent();
		}
	}
	
	private function RenderUnloggedContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		if(array_key_exists("guest", $_REQUEST))
		{
			echo "<img style=\"position: absolute; left: 0x; top: 0px;\" src=\"Images/interface/login_panel.png\" " .
				"width=\"100%\" height=\"100%\" alt=\"".self::CLASS_NAME."\" />";
				return;
		}
		
		echo '<form id="'.$this->GetHtmlId().'_Form" method="post" action="" '."onsubmit=\"Login('".$this->GetHtmlId()."'); return false;\">\n";
		
		$tableStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 7, 7, 166, 56);
		echo '<table border="0" style="'.$tableStyle.'">' . "\n";
		
		$labelStyle = "width: 45px";
				
		
		echo "<tr>\n";
		echo "<td class=\"WhiteText\" style=\"".$labelStyle."\">".$dictionary->Translate("LOGIN").":</td>\n";
		$loginId = $this->GetHtmlId()."_Form_login";
		echo '<td><input type="text" name="LoginPanel_login" id="'.$loginId.'" value="'.$dictionary->Translate("ENTER_LOGIN").'" ';
		echo 'class="LoginPanel_inputGray" ';
		echo "onfocus=\"EnterLoginPanelInput('".$dictionary->Translate("ENTER_LOGIN")."', event)\" ";
		echo "onblur=\"LeaveLoginPanelInput('".$dictionary->Translate("ENTER_LOGIN")."', event)\"/></td>\n";
		echo "</tr>\n";
		
		echo "<tr>\n";
		echo "<td class=\"WhiteText\" style=\"".$labelStyle."\">".$dictionary->Translate("PASSWORD").":</td>\n";
		$passwordId = $this->GetHtmlId()."_Form_password";
		echo '<td><input ';
		echo 'class="LoginPanel_input" ';
		echo 'type="password" name="LoginPanel_password" id="'.$passwordId.'" value=""/></td>'."\n";
		echo "</tr>\n";
		
		echo "</table>";		
		echo "</form>\n";
						
		Graphics::PrintBtn($dictionary->Translate("REGISTRATION"), 6, 66, 71, 19, "window.location.href='accounts.php?action=register'");
		Graphics::PrintBtn($dictionary->Translate("LOG_IN"), 98, 66, 75, 19, "Login('".$this->GetHtmlId()."')");
		Graphics::PrintBtn($dictionary->Translate("FORGET_PSSWD"), 177, 32, 126, 16, "LoginPanel_ForgotPassword()");
		
		$errorMessageId = $this->GetHtmlId()."_Form_error";
		echo "<span id=\"".$errorMessageId."\" style=\"color: red; font-size: 10px; position: absolute; bottom: -5px; left: 9px;\">";
		echo $this->errorMessage."</span>\n";	
	}
	
	private function RenderLoggedContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<img style=\"position: absolute; left: 0x; top: 0px;\" src=\"Images/interface/login_panel.png\" " .
				"width=\"100%\" height=\"100%\" alt=\"".self::CLASS_NAME."\" />";
				
		Graphics::PrintTextBtn($this->player->GetLogin(), 86, 24, "", "Login_Panel_font");
		Graphics::PrintBtn($dictionary->Translate("SETTINGS"), 25, 52, 36, 16, "window.location.href='accounts.php?action=showPlayer'");
		Graphics::PrintBtn($dictionary->Translate("LOG_OUT"), 146, 81, 52, 19, "Logout()");
		
	}
}