<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Utils.inc');
require_once('Control/GameTimer.inc');
require_once('Control/GameConstants.inc');
require_once('Control/ShipActionController.inc');
require_once('Model/Planet.inc');
require_once('Model/Ship.inc');
require_once('Model/Base.inc');

class MenuPanel extends Control
{
	const CLASS_NAME = "MenuPanel";
	
	private $htmlId;
	
	private $sunMode;
	
	public function SetSunMode($enabled)
	{
		$this->sunMode = $enabled;
	}
	
	private $planet;
	
	private $ship;
	
	public function SetShip(Ship $ship)
	{
		$this->ship = $ship;
	}
	
	private $gamePlan;
	
	//private $items;
	
	public function __construct(GamePlan $gamePlan, Planet $planet = NULL)
	{
		$this->htmlId = "MenuPanel";
		$this->planet = $planet;
		$this->gamePlan = $gamePlan;
		$this->sunMode = false;
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function Render()
	{
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/right_panel.png');";
		echo '<div id="'.$this->GetHtmlId().'" class="MenuPanel" style="'.$style.'"';
		echo '>'."\n";
		
		$this->RenderContent();
		
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<div ";
		printf("style=\"position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx; \" ",
			22, 1, 170, 476);
		echo ">\n";
				
		if ($this->sunMode != NULL)
		{
			$this->RenderForSun();
			$this->RenderHomeButton();
		}
		else if ($this->planet != NULL)
		{
			$this->RenderForPlanet();
			$this->RenderHomeButton();
		}
		else if ($this->ship != NULL)
		{
			$this->RenderForShip();
			$this->RenderHomeButton();				
		}
		else
		{
			$this->RenderPlayer();
		}
		
		echo "</div>\n";
	}
		
	private function RenderForPlanet()
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		echo '<h1>'.$this->planet->GetName().'</h1>'."\n";
		
		echo "<p style=\"padding-top: 0px; margin-top: 0px;\">\n";
		
		if ($player != NULL)
		{
			if ($player->GetHomePlanetId() == $this->planet->GetId())
			{
				echo "<i>".$dictionary->Translate("YOUR_HOME_PLANET")."</i><br/>\n";
			}
		}
		
		echo '<img alt="'.$this->planet->GetName().'" ';
		echo 'src="'.$this->planet->GetImageURL().'" ';
		echo ' width="40%"/>'."\n";
		echo "</p>\n";
		
		echo "<p>\n";
		echo "<b>".$dictionary->Translate("DISTANCE_TO_STAR")."</b>";
		$pos = $this->planet->GetCurrentPosition();
		$dist = sqrt($pos[0] * $pos[0] + $pos[1] * $pos[1]);
		$dist /= 1000 * 1000000;
		$dist = round($dist);
		echo $dist. "mil. km";
		echo "<br/>";
		echo "<b>".$dictionary->Translate("DAY_OF_YEAR")."</b>";
		echo $this->planet->GetCurrentPlanetDay();
		echo " " . $dictionary->Translate("OUT_OF") . " ";
		echo $this->planet->GetYearLengthInDays();
		echo "</p>\n";
		
		echo "<p>\n";
		echo "<span class=\"LoginPanel_link\" onclick=\"DeliveryPanel_Show('".$this->planet->GetId()."')\">";
		echo $dictionary->Translate("SHOW_DELIVERIES").'</span>'."\n";
		echo "</p>\n";
		
		if ($player != NULL)
			{
			echo "<p>\n";
			
			$bases = (array)$this->planet->GetBasesForced();
			
			$baseExists = false;
			foreach ($bases as $base)
			{
				if ($base->GetPlayerId() == $player->GetId())
				{
					$baseExists = true;
					break;
				}
			}
			
			if ($baseExists)
			{
				echo $dictionary->Translate("BASE_ALREADY_BUILT");
				
				$nowTime = time();
				if ($base->GetBuiltTime() > $nowTime)
				{
					$remTime = $base->GetBuiltTime() - $nowTime;
				    printf($dictionary->Translate("BASE_WILL_BE_IN"), GameTimer::RealTimeToEarthDays($remTime));
					
				}
			}
			else if ($player->GetMoney() < GameConstants::BASE_PRICE)
			{
				echo $dictionary->Translate("BASE_TOO_EXPENSIVE");
			}
			else
			{
				echo "<span class=\"LoginPanel_link\" onclick=\"MenuPanel_BuildBase(".$this->planet->GetId().")\">";
				echo $dictionary->Translate("BUILD_BASE").' ($'.GameConstants::BASE_PRICE.')</span>'."\n";	
			}		
			
			echo "</p>\n";
			
			echo "<p>";
			echo "<b>".$dictionary->Translate("MENU_DOCKED_SHIPS")."</b><br/>\n";
			$ships = (array)$player->GetShipsForced();
			$solarSystem = $this->gamePlan->GetSolarSystem();
			
			foreach ($ships as $ship)
			{
				if ($ship->GetModel()->GetShipType()->GetId() == GameConstants::GUARD_SHIP_TYPE_ID)
				{
					continue;
				}
				
				$shipAC = new ShipActionController($player, $ship, $solarSystem);
				if ($shipAC->GetDockedPlanet() != NULL && $shipAC->GetDockedPlanet()->GetId() == $this->planet->GetId())
				{
					echo "<span class=\"LoginPanel_link\" onclick=\"ShipGraphic_OnClick(document.getElementById(shipIds[".$ship->GetId()."]), event)\">";
					echo $ship->GetName().'</span><br/>'."\n";						
				}
			}
			
			echo "</p>\n";
		}
		
		echo "<p>\n";
		echo "<span class=\"LoginPanel_link\" onclick=\"PlanetHomePlayersPanel_Show('".$this->planet->GetId()."')\">";
		echo $dictionary->Translate("SHOW_HOME_PLAYERS").'</span>'."\n";
		echo "</p>\n";
	}
	
	private function RenderForShip()
	{
		$player = Player::LoadFromDB($this->ship->GetPlayerID());
		$dictionary = Dictionary::GetInstance();
		$levelable = GameConstants::IsShipLevelable($this->ship);
		
		echo '<h1>'.$this->ship->GetName().'</h1>'."\n";
			
		echo "<p>\n";
		echo '<img alt="'.$this->ship->GetName().'" ';
		echo 'src="'.$this->ship->GetModel()->GetImage().'" ';
		echo ' width="85%"/>'."\n";
		echo "</p>\n";
		
		
		echo "<p>\n";
		
		echo "<b>".$dictionary->Translate("MENU_SHIP_CLASS")."</b>";
		echo $this->ship->GetModel()->GetName();
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("MENU_SHIP_TYPE")."</b>";
		echo $dictionary->Translate($this->ship->GetModel()->GetShipType()->GetNameString());
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("MENU_SHIP_SPEED")."</b>";
		echo $this->ship->GetModel()->GetSpeed();
		echo " " . $dictionary->Translate("SPEED_MPS");
		echo "<br/>";
		
		$canLevel = false;
		if ($levelable)
		{
			echo "<b>".$dictionary->Translate("MENU_SHIP_LEVEL")."</b>";
			echo $this->ship->GetLevel() . " ";
			
			$levelPrice = GameConstants::GetShipLevelPrice($this->ship);
			$affordable = $levelPrice <= $player->GetMoney();
			$guardCount = count(Utils::GetAssignedGuardians($this->ship, $player));
			$guardable = $guardCount >= $this->ship->GetLevel() + 1;
			$reachable = $this->ship->GetLevel() < GameConstants::CARGO_SHIP_TYPE_MAX_LEVEL;
			echo "<span class=\"LoginPanel_link\" ";
			echo "onclick=\"MenuPanel_BuyShipLevel('".$this->GetHtmlId()."', ".$this->ship->GetId().", false)\">";
			echo "[".$dictionary->Translate("HIGHER_LEVEL")."]".'</span>';
			echo "<br/>";
			
			$canLevel = ($affordable && $guardable && $reachable);
			if ($canLevel)
			{
				$question = sprintf($dictionary->Translate("MENU_SHIP_UPGRADE_CONFIRM"), $this->ship->GetName(), $levelPrice);
			}
			else if (!$reachable)
			{
				$question = sprintf($dictionary->Translate("MENU_SHIP_MAX_LEVEL_REACHED"), $this->ship->GetLevel());
			}
			else if (!$guardable)
			{
				$question = sprintf($dictionary->Translate("MENU_SHIP_LEVEL_NOT_GUARDED"), $guardCount, $this->ship->GetLevel() + 1);
			}
			else
			{
				$question = sprintf($dictionary->Translate("MENU_SHIP_LEVEL_TOO_EXPENSIVE"), $levelPrice);
			}
		}
		
		echo "<b>".$dictionary->Translate("MENU_SHIP_CAPACITY")."</b>";
		echo $this->ship->GetFinalCapacity();
		echo " " . $dictionary->Translate("WEIGHT_TONS");
		echo "<br/>";
		
		if ($this->ship->GetModel()->GetShipType()->GetId() == GameConstants::CARGO_SHIP_TYPE_ID)
		{
			echo "<b>".$dictionary->Translate("MENU_SHIP_GUARD_COUNT")."</b>";
			$guards = Utils::GetAssignedGuardians($this->ship, $player);
			echo count($guards);
			echo "<br/>";
		}
		
		echo "<b>".$dictionary->Translate("MENU_SHIP_DELIVERY_COUNT")."</b>";
		echo $this->ship->GetDeliveryDoneCount();
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("MENU_SHIP_LOADED_TONS")."</b>";
		$deliveries = (array)$this->ship->GetDeliveriesForced();
		$sum = 0;
		foreach ($deliveries as $delivery)
		{
			$sum += $delivery->GetAmount();
		}
		echo $sum;
		echo " " . $dictionary->Translate("WEIGHT_TONS");
		if (count($deliveries) > 0 && $this->ship->GetModel()->GetShipType()->GetId() == GameConstants::CARGO_SHIP_TYPE_ID)
		{
			echo " (=> " . Planet::LoadFromDB($delivery->GetTargetPlanetID())->GetName() . ")";
		}		
		
		$solarSystem = $this->gamePlan->GetSolarSystem();
		$shipAC = new ShipActionController($player, $this->ship, $solarSystem);
		if ($shipAC->IsWaiting())
		{
			if ($this->ship->GetModel()->GetShipType()->GetId() == GameConstants::CARGO_SHIP_TYPE_ID && count($this->ship->GetDeliveriesForced()) > 0)
			{
				$delivery = array_pop(array_values($this->ship->GetDeliveriesForced()));
				$targetPlanet = Planet::LoadFromDB($delivery->GetTargetPlanetID());
				$isLocalDelivery = ($targetPlanet->GetSolarSystemId() == $this->ship->GetSolarSystemId());
				$isLocalDelivery = $isLocalDelivery ? "true" : "false";
				echo "<span class=\"LoginPanel_link\" ";
				echo "onclick=\"".self::CLASS_NAME."_FinishDeliveries(".$this->ship->GetId().", ".$isLocalDelivery.", ".$targetPlanet->GetSolarSystemId().")\">";
				echo "&nbsp;[".$dictionary->Translate("FINISH_DELIVERIES")."]".'</span>';
			}
		}
		
		echo "<br/>";
		
		echo "</p>\n";
		
		
		echo "<p><b>".$dictionary->Translate("SHIP_STATE")."</b>";
	
		$dockedPlanet = $shipAC->GetDockedPlanet();
		
		if ($shipAC->GetDockedPlanet() != NULL)
		{
			echo $dictionary->Translate("DOCKED_ON_THE_PLANET"); // . "<i>" . $dockedPlanet->GetName() . "</i>"; 
			echo "<span class=\"LoginPanel_link\" onclick=\"PlanetGraphic_OnClick(document.getElementById(planetIds[".$dockedPlanet->GetId()."]), event)\">";
			echo $dockedPlanet->GetName().'</span><br/>'."\n";
			
							
		}
		else if ($shipAC->IsFlyingToPlanet())
		{
			echo $dictionary->Translate("FLYING_TO_PLANET") . "<i>" . $shipAC->GetTargetPlanet()->GetName() . "</i>";
		}
		else if ($shipAC->IsFlyingToWormHole())
		{
			$otherSystem = SolarSystem::LoadFromDB($shipAC->GetTargetObject()->GetOtherSystemId($this->ship->GetSolarSystemId()));
			echo $dictionary->Translate("FLYING_TO_WORMHOLE") . "<i>" . $otherSystem->GetName() . "</i>";
		}
		else if ($shipAC->IsBlocked())
		{
			echo $dictionary->Translate("BLOCKED_FOR") . ($shipAC->GetBlockEndTime() - time()) . "s";
		}
		else if ($shipAC->IsWaiting() || true)
		{
			echo $dictionary->Translate("WAITING_IN_SPACE");
		}
		
		echo "</p>\n";
		
		echo "<form method\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_canLevel\" name=\"canLevel\" type=\"hidden\" value=\"".($canLevel ? "true" : "false")."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_question\" name=\"question\" type=\"hidden\" value=\"".$question."\"/>";
		echo "</form>\n";
	}
	
	
	private function RenderForSun()
	{
		$dictionary = Dictionary::GetInstance();
		echo '<h1>'.$dictionary->Translate("STAR").'</h1>'."\n";
		
		echo "<p>\n";
		echo '<img alt="'.$dictionary->Translate("STAR").'" ';
		echo 'title = "'.$dictionary->Translate("STAR").'" ';
		echo 'src="'.$this->gamePlan->GetSolarSystem()->GetSunImageUrl().'" ';
		echo ' width="85%"/>'."\n";
		echo "</p>\n";
	}
	
	private function RenderHomeButton()
	{
		/*$dictionary = Dictionary::GetInstance();
		
		echo '<img alt="'.$dictionary->Translate("SHOW_HOME").'" ';
		echo 'title="'.$dictionary->Translate("SHOW_HOME").'" ';
		echo 'style="cursor: pointer;" ';
		echo 'src="Images/home.png" ';
		echo "onclick=\"MenuPanel_SelectHome()\" ";
		echo ' width="64px" height="64px"/>'."\n";*/
	}
	
	private function RenderPlayer()
	{
		$dictionary = Dictionary::GetInstance();
		$player = Globals::GetActivePlayer();
		
		if ($player == null)
		{			
			echo $dictionary->Translate("LOG_TO_SEE");
			return;
		}
		
		echo '<h1>'.$player->GetNick().'</h1>'."\n";
		
		echo "<p>\n";
		
		echo "<b>".$dictionary->Translate("HOME_PLANET")."</b>";
		$planet = Planet::LoadFromDB($player->GetHomePlanetId());
		echo "<span class=\"LoginPanel_link\" onclick=\"PlanetGraphic_OnClick(document.getElementById(planetIds[".$planet->GetId()."]), event)\">";
		echo $planet->GetName().'</span>'."\n";
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("NUMBER_OF_SHIPS")."</b>";
		$ships = $player->GetShipsForced();
		echo count($ships);
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("NUMBER_OF_BASES")."</b>";
		$bases = $player->GetBasesForced();
		echo count($bases);
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("NUMBER_OF_DELIVERIES")."</b>";
		$sum = 0;
		foreach ($ships as $ship)
		{
			$sum += $ship->GetDeliveryDoneCount();
		}
		echo $sum;
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("NUMBER_OF_LICENCES")."</b>";
		echo $player->GetLicenceCount();
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("NUMBER_OF_USED_LICENCES")."</b>";
		echo Utils::CalculatePlayerUsedLicences($player);
		echo "<br/>";
		
		echo "<b>".$dictionary->Translate("ACCOUNT_STATE")."</b>";
		echo number_format($player->GetMoney(), 0, ',', ' ');
		echo "</p>\n";
		
		echo "<p>\n";
		
		$licencePrice = GameConstants::GetLicencePrice($player);
		$hasMoney = ($licencePrice <= $player->GetMoney());
		$question = $hasMoney ? sprintf($dictionary->Translate("LICENCE_BUY_QUESTION"), $licencePrice) : sprintf($dictionary->Translate("LICENCE_BUY_NO_MONEY"), $licencePrice, $player->GetMoney());
		/*echo "<span class=\"LoginPanel_link\" ";
		echo "onclick=\"MenuPanel_BuyLicence(false)\">";
		echo $dictionary->Translate("BUY_LICENCE_PANEL").'</span>'."<br/>\n";*/
		
		if ($player->GetEmbassyLevel() <= 0)
		{
			echo "<i>".$dictionary->Translate("NO_EMBASSY")."</i>&nbsp;";
			$embassyLbl = $dictionary->Translate("BUILD_EMBASSY"); 
		}
		else
		{
			echo "<b>".$dictionary->Translate("EMBASSY_LEVEL")."</b>";
			echo $player->GetEmbassyLevel(). "&nbsp;";
			$embassyLbl = $dictionary->Translate("EMBASSY_BUY_LEVEL");
		}
				
		$levelPrice = GameConstants::GetEmbassyLevelPrice($player);
		$affordable = $levelPrice <= $player->GetMoney();
		$embassyLevelEnabled = $affordable;
		echo "<span class=\"LoginPanel_link\" ";
		echo "onclick=\"MenuPanel_BuyEmbassyLevel('".$this->GetHtmlId()."', false)\">";
		echo $embassyLbl.'</span>';
		echo "<br/>";
		
		if ($embassyLevelEnabled)
		{
			$emabssyQuestion = sprintf($dictionary->Translate("MENU_EMBASSY_UPGRADE_CONFIRM"), $levelPrice);
		}
		else
		{
			$emabssyQuestion = sprintf($dictionary->Translate("MENU_EMBASSY_NO_MONEY"), $levelPrice);
		}
		
		echo "</p>\n";
		
		
		echo "<p>\n";
		echo "<b>".$dictionary->Translate("CURRENTLY_DELIVERED")."</b><br/>";
		
		$deliveryCount = 0;
		
		foreach ($ships as $ship)
		{
			$deliveries = (array)$ship->GetDeliveriesForced();
			foreach ($deliveries as $delivery)
			{
				echo $delivery->GetGoodType()->GetName();
				echo ' ($'.$delivery->GetPrice().")";
				echo "<br/>\n";
				$deliveryCount++;
			}
		}	
		
		if ($deliveryCount == 0)
		{
			echo "<i>".$dictionary->Translate("NO_ACTIVE_DELIVERIES")."</i>\n";
		}
			
		echo "</p>\n";
		
		echo "<form method\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_hasMoney\" name=\"hasMoney\" type=\"hidden\" value=\"".($hasMoney ? "true" : "false")."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_question\" name=\"question\" type=\"hidden\" value=\"".$question."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_embassyLevelEnabled\" name=\"hasMoney\" type=\"hidden\" value=\"".($embassyLevelEnabled ? "true" : "false")."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_emabssyQuestion\" name=\"question\" type=\"hidden\" value=\"".$emabssyQuestion."\"/>";
		echo "</form>\n";
	}
	
	/*public function AddMenuItem($position, $name, $link)
	{
		$item = new MenuItem($this->GetHtmlId()."_".$position."_".rand(), $name, $link);
		$item->SetWidth($this->GetWidth());
		$item->SetHeight(30);	
		$this->items[$position] = $item;
	}

	private function FillMenu()
	{
		$this->AddMenuItem(0, "Domu", "index.php");
		$this->AddMenuItem(1, "Prihlasit se", "");
		$this->AddMenuItem(2, "Konec", "");	
	}*/
}

?>