<?php

require_once('View/Control.inc');
require_once('Model/Player.inc');
require_once('Model/Message.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once('Control/GameConstants.inc');

class MessagePanel extends Control
{
	const LABEL_WIDTH = 130;
	const CLASS_NAME = "MessagePanel";
	
	private $gamePlan;
	
	private $message;
	
	public function SetMessage(Message $message)
	{
		$this->message = $message;
	}
		
	private $defaultReciever;
	
	public function SetDefaultReciever(Player $reciever)
	{
		$this->defaultReciever = $reciever;
	}
		
	private $htmlId;
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
	
	private $mode;
	
	public function SetMode($mode)
	{
		$this->mode = $mode;
	}
	
	private $sortKey;
	
	public function SetSortKey($key)
	{
		$this->sortKey = $key; 
	}
	
	private $sortOrder;
	
	public function SetSortOrder($order)
	{
		$this->sortOrder = $order; 
	}	
		
	public function __construct(GamePlan $gamePlan, Message $message = NULL)
	{
		$this->gamePlan = $gamePlan;
		$this->message = $message;
		$this->htmlId = self::CLASS_NAME;
		$this->sortKey = "date";
		$this->sortOrder = "desc";
		$this->mode = "list"; // new, read
		$this->defaultReciever = NULL;
	}	
		
	public function Render()
	{
		$this->UpdateSize();	
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/universal.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 6, 35, 455, 396);
		echo '<div style="'.$divStyle.'">';
		$closeAction = "";
			
		if (!strcasecmp($this->mode, "new"))
		{
			$this->PrintNewContent();
			$closeAction = self::CLASS_NAME."_ShowList()";
		}
		else if (!strcasecmp($this->mode, "read") && $this->message != NULL)
		{
			$this->PrintReadContent();
			$closeAction = self::CLASS_NAME."_ShowList()";
		}
		else
		{
			$this->PrintListContent();
			$closeAction = self::CLASS_NAME."_Hide()";
		}	
		
		echo "</div>\n";
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, $closeAction);
	}
	
	private function PrintNewContent()
	{
		$dictionary = Dictionary::GetInstance();
		$this->PrintHeadline($dictionary->Translate("MESSAGE_NEW_HEADLINE"));
		
		$formId = $this->GetHtmlId().'_Form';
		echo '<form id="'.$formId.'" method="post" action="" ' . ">\n";
		echo '<table border="0" style="width: '.$this->GetWidth().'px;">' . "\n";
		
		$this->RenderFormInput("reciever", "MESSAGE_RECIEVER", "text", 
			$this->defaultReciever != NULL ? $this->defaultReciever->GetLogin() : "");
		$this->RenderFormInput("subject", "MESSAGE_SUBJECT", "text");
		
		echo '</table>'."\n";
		
		echo "<textarea id=\"".$formId."_textbody\" name=\"textbody\" rows=\"10\" cols=\"50\">";
		echo "</textarea>\n";				
				
		echo "<p>\n";
		echo '<input type="reset" value="'.$dictionary->Translate("CLEAR_FORM").'"/>'."&nbsp;&nbsp;\n";
		echo '<input type="button" value="'.$dictionary->Translate("SEND_FORM").'" ';
		echo "onclick=\"return ".self::CLASS_NAME."_SendNewMessage('".$formId."')\"" . '"/>'."\n";
		echo "</p>\n";
		echo "</form>\n";
	}
	
	private function RenderFormInput($itemName, $label, $type, $content = "")
	{
		$dictionary = Dictionary::GetInstance();
		$labelColWidth = self::LABEL_WIDTH;
		$inputColWidth = ($this->GetWidth() - $labelColWidth) * 0.35;
		$errorColWidth = ($this->GetWidth() - $labelColWidth) * 0.65;
		
		$itemId = $this->GetHtmlId()."_Form_".$itemName;
		$itemErrorId = $itemId."_error";
		echo "<tr>\n";
		echo "<td style=\"width: ".$labelColWidth."px;\">".$dictionary->Translate($label).":</td>\n";
		echo '<td><input type="'.$type.'" name="'.self::CLASS_NAME.'_'.$itemName.'" id="'.$itemId.'" ';
		echo 'value="'.$content.'" ';
		echo 'style="width: '.$inputColWidth.'px;" ';
		echo '/></td>'."\n";
		echo '<td style="width: '.$errorColWidth.'px;"><span style="color: red;" id="'.$itemErrorId.'"></span></td>'."\n";
		echo '</tr>'."\n";	
	}
	
	private function PrintReadContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$reciever = Player::LoadFromDB($this->message->GetRecieverId());
		$loggedPlayer = Globals::GetActivePlayer();
		
		if ($loggedPlayer == NULL || $loggedPlayer->GetId() != $reciever->GetId())
		{
			echo $dictionary->Translate('MESSAGE_ACCESS_DENIED')."<br/>\n";
		}
		else
		{
			$this->message->MarkRead();
			
			$sender = Player::LoadFromDB($this->message->GetSenderId());
			$dateFormat = $dictionary->TRANSLATE("DATETIME_FORMAT");
			
			$this->PrintHeadline($dictionary->Translate("MESSAGE_READ_HEADLINE") . $sender->GetStringIdentifier());
			
			echo "<p>";
			
			echo "<b>".$dictionary->Translate('MESSAGE_LIST_SENDER')."</b>: ";
			echo $sender->GetStringIdentifier();
			echo "<br/>\n";
			
			echo "<b>".$dictionary->Translate('MESSAGE_LIST_SUBJECT')."</b>: ";
			echo $this->message->GetSubject();
			echo "<br/>\n";
			
			echo "<b>".$dictionary->Translate('MESSAGE_LIST_DATE')."</b>: ";
			echo date($dateFormat, $this->message->GetSentTime());
			echo "<br/>\n";			
			
			echo "</p>\n";
			
			echo "<p>";
			echo $this->message->GetText();
			echo "</p>\n";
			
			echo "<p>";
			echo "<span class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_ShowNewMessage(".$sender->GetId().")\">";
			echo $dictionary->Translate("MESSAGE_REPLY").'</span>'."\n";
			echo "</p>\n";
		}
	}
	
	private function PrintListContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		if (Globals::GetActivePlayer() != NULL)
		{
			$this->PrintHeadline($dictionary->Translate("MESSAGE_LIST_HEADLINE"));
		
			$this->PrintMessageListTable();
			
			echo "<p>";
			echo "<span class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_ShowNewMessage()\">";
			echo $dictionary->Translate("NEW_MESSAGE_PANEL_BTN").'</span>'."\n";
			echo "</p>\n";
		}	
		else
		{
			echo $dictionary->Translate("SIGN_TO_SEE_MESSAGES");
			echo "<br/>\n";
		}
	}
	
	private function PrintHeadline($headline)
	{
		echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
		echo $headline;
		echo "</div>";
	}
	
	private function PrintMessageListTable()
	{
		$dictionary = Dictionary::GetInstance();
		$dateFormat = $dictionary->TRANSLATE("DATETIME_FORMAT");
		
		echo "<table style=\"width: 100%\">\n";
		
		$this->PrintMessageListHeader();
		
		$rows = $this->GenerateMessageListRows();
		
		$i = 0;
		foreach ($rows as $rowArray)
		{
			foreach ($rowArray as $row)
			{
				$action = self::CLASS_NAME . "_ShowReadMessage(".$row["id"].")";

				if ($row["wasRead"])
				{
					$class = "MessagePanel_RowRead";
				}
				else
				{
					$class = "MessagePanel_RowUnread";
				}
				
				$onclick = "onclick=\"".$action."\" ";
				
				echo "<tr ";
				echo "class=\"".$class."\" "; 
				echo "onmouseover=\"this.className='MessagePanel_RowHover'\" ";
				echo "onmouseout=\"this.className='".$class."'\"";
				echo ">\n";
				
				echo "<td ".$onclick.">".($i + 1)."</td>\n";
				echo "<td ".$onclick.">".$row["sender"]."</td>\n";
				echo "<td ".$onclick.">".$row["subject"]."</td>\n";
				echo "<td ".$onclick.">".date($dateFormat, $row["date"])."</td>\n";
				
				echo "<td><span class=\"LoginPanel_link\" ";
				echo "onmouseover=\"this.className='MessagePanel_RowDeleteHover'\"";
				echo "onmouseout=\"this.className='LoginPanel_link'\"";
				echo "onclick=\"".self::CLASS_NAME."_DeleteMessage(".$row["id"].")\">";
				echo $dictionary->Translate("MESSAGE_LIST_DELETE_ACTION");
				echo "</span></td>\n";
								
				echo "</tr>\n";
				$i++;
			}
		}
		
		echo "</table>\n";
	}
	
	private function PrintMessageListHeader()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
			
		
		$this->PrintHeaderCell('MESSAGE_LIST_ORDER', "", "");
		
		$this->PrintSortableHeaderCell('MESSAGE_LIST_SENDER', "sender", "asc");
		$this->PrintSortableHeaderCell('MESSAGE_LIST_SUBJECT', "subject", "asc");	
		$this->PrintSortableHeaderCell('MESSAGE_LIST_DATE', "date", "desc");	
		
		$this->PrintHeaderCell('MESSAGE_LIST_DELETE_HEAD', "", "");
				
		echo "</tr>\n";
	}
	
	private function PrintSortableHeaderCell($dictNameKey, $sortKey, $defaultOrder)
	{
		$sortOrder = $defaultOrder;
		$style = "text-decoration: underline; cursor: pointer;";
		
		if (!strcasecmp($this->sortKey, $sortKey))
		{
			$style .= " font-weight: bold;";
			
			if (!strcasecmp($this->sortOrder, $sortOrder))
			{
				if (!strcasecmp($sortOrder, "desc"))
			    {
			    	$sortOrder  = "asc";
			    }
			    else
			    {
			    	$sortOrder = "desc";	
			    }				
			}
		}		
		
		$action = self::CLASS_NAME . "_ShowList('".$sortKey."', '".$sortOrder."')";
		$this->PrintHeaderCell($dictNameKey, $style, $action);	
	}
	
	private function PrintHeaderCell($nameKey, $style = "", $action = "")
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<td";
		
		if (strlen($style) > 0)
		{
			echo " style=\"".$style."\"";
		}
		
		if (strlen($action) > 0)
		{
			echo " onclick=\"".$action."\"";
		}
		
		echo ">";
		echo $dictionary->Translate($nameKey);
		echo "</td>\n";
	}
	
	private function GenerateMessageListRows()
	{
		$rows = array();
		$player = Globals::GetActivePlayer();
		$messages = (array)$player->GetMessagesForced();
		
		foreach ($messages as $message)
		{											
			$senderPlayer = Player::LoadFromDB($message->GetSenderId());
			$sender = $senderPlayer->GetNick();
			if ($sender == NULL || strlen($sender) == 0)
			{
				$sender = $senderPlayer->GetLogin();
			}
			
			$subject = $message->GetSubject();
			$date = $message->GetSentTime();
			$id = $message->GetId();
			$wasRead = $message->WasRead();
			
			$row = array("sender" => $sender, "subject" => $subject, "date" => $date, "id" => $id, "wasRead" => $wasRead);
			
			if (!strcasecmp($this->sortKey, "sender"))
			{
				$key = strtolower($sender);
			}
			else if (!strcasecmp($this->sortKey, "subject"))
			{
				$key = $subject;
			}
			else if (!strcasecmp($this->sortKey, "date"))
			{
				$key = $date;
			}
			else
			{
				$key = $date;
			}	
			
			if (!array_key_exists($key, $rows))
			{
				$rows[$key] = array();
			}
			
			array_push($rows[$key], $row);
		}
		
		if (!strcasecmp($this->sortOrder, "asc"))
		{
			ksort($rows);
		}
		else
		{
			krsort($rows);
		}
		
		return $rows;
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}
?>