<?php

require_once('View/Control.inc');
require_once('View/DesignConstants.inc');
require_once('Control/Globals.inc');
require_once('Model/Planet.inc');
require_once('View/GamePlan.inc');

class PlanetGraphic extends Control
{
	const CLASS_NAME = "PlanetGraphic";
	
	const STATUS_IMAGE_FILENAME_FORMAT = "Images/space_objects/DLZ%d.png";
	
	const DLZ_WIDTH = 49;
	const DLZ_HEIGHT = 18;
	
	private $htmlId;
	
	private $gamePlan;
	private $planet;
	
	public function GetPlanet()
	{
		return $this->planet;		
	}
	
	private $autoResize = true;
	
	public function IsAutoResize()
	{
		return $this->autoResize;
	}
	
	public function SetAutoResize($autoResize)
	{
		$this->autoResize = $autoResize;
	}
	
	private $autoPosition = true;
	
	public function IsAutoPosition()
	{
		return $this->autoPosition;
	}
	
	public function SetAutoPosition($autoPosition)
	{
		$this->autoPosition = $autoPosition;
	}
	
	public function __construct(Planet $planet, GamePlan $gamePlan)
	{
		$this->htmlId = self::CLASS_NAME."_".rand();
				
		$this->planet = $planet;
		$this->gamePlan = $gamePlan;
		
		$this->SetBackgroundColor("transparent");
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		$this->htmlId = $newId;
	}
	
	
	public function Render()
	{
		if ($this->autoResize)
		{
			$this->AutoResize();			
		}
		
		if ($this->autoPosition)
		{
			$this->AutoPosition();
		}
		
		$style = $this->GenerateStyleString();
		$style .= " cursor: pointer;";
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'" ';
		//echo "onmouseover=\"ShipGraphic_SetHighlight(this, true)\" ";
		//echo "onmouseout=\"ShipGraphic_SetHighlight(this, false)\" ";
		echo "onclick=\"PlanetGraphic_OnClick(this, event)\" ";
		echo "onmouseover=\"PlanetGraphic_OnMouseOver(this, event)\" ";  
		echo ">\n";
		
		$this->RenderContent();
					
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo '<img ';
		echo "alt=\"".$this->planet->GetName()."\" ";
		echo 'src="'.$this->planet->GetImageURL().'" ';
		//echo 'style="opacity:1;filter:alpha(opacity=100)" ';
		echo ' width="'.DesignConstants::PLANET_SIZE.'px" height="'.DesignConstants::PLANET_SIZE.'px"/>'."\n";
		
		$player = Globals::GetActivePlayer();
		
		if ($player != NULL)
		{
			$dlzCode = Utils::GetPlanetStateCode($this->planet, $player, $this->gamePlan->GetSolarSystem());
			echo '<img ';
			echo "alt=\"".$this->planet->GetName()."_DLZ\" ";
			echo 'src="'.sprintf(self::STATUS_IMAGE_FILENAME_FORMAT, $dlzCode).'" ';
			echo "style=\"position: absolute; ".sprintf("left: %fpx; top: %fpx;", (DesignConstants::PLANET_SIZE - self::DLZ_WIDTH) / 2, DesignConstants::PLANET_SIZE)."\" ";
			echo ' width="'.self::DLZ_WIDTH.'px" height="'.self::DLZ_HEIGHT.'px"/>'."\n";
		}
		else
		{
			$dlzCode = Utils::GetPlanetStateCode($this->planet);
		}
		
		$infoPanel = new PlanetInfoPanel($this, $this->gamePlan);
		$infoPanel->SetVisible(false);
		$infoPanel->SetBackgroundColor("#D8EDFF");
		$infoPanel->Render();
		
		echo "<form method=\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_planetId\" name=\"planetId\" type=\"hidden\" value=\"".$this->planet->GetId()."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_stateCode\" name=\"stateCode\" type=\"hidden\" value=\"".$dlzCode."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_lblFlyHere\" name=\"lblFlyHere\" type=\"hidden\" value=\"".sprintf($dictionary->Translate("PLANET_FLY_HERE"), $this->planet->GetName())."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_lblSelect\" name=\"lblSelect\" type=\"hidden\" value=\"".sprintf($dictionary->Translate("PLANET_SELECT"), $this->planet->GetName())."\"/>";
		echo "</form>\n";
	}
	
	private function AutoResize()
	{		
		$this->width = max(DesignConstants::PLANET_SIZE, self::DLZ_WIDTH);
		$this->height = DesignConstants::PLANET_SIZE; //+ self::DLZ_HEIGHT;		
	}
	
	private function AutoPosition()
	{
		$coords = $this->gamePlan->WorldToScreenCoords(
			$this->planet->GetWorldX(), $this->planet->GetWorldY(), 
			$this->GetWidth(), $this->GetHeight());
		$this->x = $coords[0];
		$this->y = $coords[1];	
	}
}

?>