<?php

require_once('View/Control.inc');
require_once('View/GamePlan.inc');
require_once('Model/Planet.inc');
require_once('Control/Dictionary.inc');

class PlanetHomePlayersPanel extends Control
{
	private $gamePlan;
	
	public function GetGamePlan()
	{
		return $this->gamePlan;
	}
	
	private $planet;
	
	private $htmlId;
	
	const CLASS_NAME = "PlanetHomePlayersPanel";
		
	public function __construct(GamePlan $gamePlan, Planet $planet  = NULL)
	{
		$this->gamePlan = $gamePlan;
		$this->planet = $planet;
		$this->htmlId = PlanetHomePlayersPanel::CLASS_NAME;
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
		
	public function Render()
	{
		//$this->SetX($this->gamePlan->GetX());
		//$this->SetY($this->gamePlan->GetY());
		$this->UpdateSize();
		
		
		echo '<div id="'.$this->GetHtmlId().'" class="PlanetHomePlayersPanel" style="'.$this->GenerateStyleString().'"';
		echo 'onclick="PlanetHomePlayersPanel_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		if ($this->planet != NULL)
		{
			echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
			echo $dictionary->Translate('WHOS_HOME_ON');
			echo $this->planet->GetName()."</div>\n";
			
			echo "<table style=\"width: 100%\">\n";
			
			echo "<tr style=\"text-align: center; font-style: italic;\">\n";
			echo "<td>#</td>\n";
			echo "<td>".$dictionary->Translate('LOGIN')."</td>\n";
			echo "<td>".$dictionary->Translate('NICK')."</td>\n";
			echo "</tr>\n";
			
			$players = (array)Player::LoadAllFromDB();
			
			$i = 0;
			
			foreach ($players as $player)
			{
				if ($player->GetHomePlanetId() != $this->planet->GetId())
				{
					continue;
				}
				
				echo "<tr>\n";
				echo "<td style=\"text-align: center;\">\n";
				echo ($i + 1);				
				echo "</td>\n";
				echo "<td>\n";
				echo $player->GetLogin();			
				echo "</td>\n";
				echo "<td>\n";
				echo $player->GetNick();				
				echo "</td>\n";
				echo "</tr>\n";
				
				$i += 1;
			}
			
			echo "</table>\n";
			
			echo "<p>";
			printf($dictionary->Translate('TOTAL_FOUND_RECORDS'), $i);
			echo "</p>\n";
		}
		
		echo "<span class=\"LoginPanel_link\" onclick=\"PlanetHomePlayersPanel_Hide()\">";
		echo $dictionary->Translate("CLOSE").'</span>'."\n";
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}

?>