<?php

require_once("Model/Planet.inc");
require_once("Model/SolarSystem.inc");
require_once("View/GamePlan.inc");
require_once("Model/Delivery.inc");
require_once("Model/GoodType.inc");

/**
 * View control for displaying info about single planet
 * as part of GamePlan.
 * @author Petr Kellnhofer (A07278)
 *
 */
class PlanetInfoPanel extends Control
{
	const CLASS_NAME = "PlanetInfoPanel";
	const DELIVERY_DISPLAY_COUNT = 3;
	
	private $htmlId;
	
	/**
	 * Planet to display info about.
	 */
	private $planet;
	
	/**
	 * Parent game plan.
	 */
	private $gamePlan;
	
	/**
	 * Creates new planet info panel.
	 * @param Planet $planet planet to display info about
	 * @param GamePlan $gamePlan parent game plan
	 */
	public function __construct(PlanetGraphic $planetGraphic, GamePlan $gamePlan)
	{
		$this->htmlId = $planetGraphic->GetHtmlId() . "_" . self::CLASS_NAME;
		
		$this->planet = $planetGraphic->GetPlanet();
		$this->gamePlan = $gamePlan;
		
		$this->SetAutoSize(true);
		$this->SetWidth(150);
		$this->SetVisible(false);
	}
	
	/**
	 * (non-PHPdoc)
	 * @see View/Control#GetHtmlId()
	 */
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	/**
	 * (non-PHPdoc)
	 * @see Control/IRenderable#Render()
	 */
	public function Render()
	{		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/planetinfo.png');background-repeat:repeat;";
		
		$style .= "cursor: pointer; width: " . $this->GetWidth() . "px;";
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'" ';
		echo "onclick=\"PlanetInfoPanel_OnClick(this, event)\" ";		
		echo ">\n";
		
		$this->RenderContent();
		
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo '<div style="font-weight: bold; font-size: 11pt; text-align: center; width: 100%;">';
		echo $this->planet->GetName()."</div>\n";
		
		echo "<table style=\"width: 100%\">\n";
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
		echo "<td>".$dictionary->Translate('GOODS')."</td>\n";
		//echo "<td>".$dictionary->Translate('TONS')."</td>\n";
		echo "<td>".$dictionary->Translate('REWARD')."</td>\n";
		echo "<td>".$dictionary->Translate('PLANET')."</td>\n";
		echo "</tr>\n";
		
		$deliveries = $this->planet->GetDeliveriesForced();
		$deliveriesSorted = array();
		
		foreach ($deliveries as $delivery)
		{
			$deliveriesSorted[$delivery->GetPrice()] = $delivery;
		}
		
		ksort($deliveriesSorted);
		
		$printCount = min(self::DELIVERY_DISPLAY_COUNT, count($deliveriesSorted));		
				
		for ($i = 0; $i < $printCount; $i++)
		{
			$delivery = array_pop($deliveriesSorted);
			
			echo "<tr>\n";
			$target =  Planet::LoadFromDB($delivery->GetTargetPlanetId());
			echo "<td>".$delivery->GetGoodType()->GetName()."</td>";
			//echo "<td style=\"text-align: right;\">".$delivery->GetAmount()."</td>";
			echo "<td style=\"text-align: right;\">$".number_format($delivery->GetPrice(), 0, ',', ' ')."</td>";
			echo "<td>".$target->GetName()."</td>";
			echo "</tr>\n";
		}
		
		echo "</table>\n";
	}
}

?>