<?php

require_once('View/Control.inc');
require_once('View/DesignConstants.inc');
require_once('Control/Globals.inc');
require_once('Model/Ship.inc');
require_once('View/GamePlan.inc');

class ShipGraphic extends Control
{
	const CLASS_NAME = "ShipGraphic";
	
	private $htmlId;
	
	private $gamePlan;
	
	private $ship;
	
	public function GetShip()
	{
		return $this->ship;
	}
	
	private $autoResize = true;
	
	public function IsAutoResize()
	{
		return $this->autoResize;
	}
	
	public function SetAutoResize($autoResize)
	{
		$this->autoResize = $autoResize;
	}
	
	private $autoPosition = true;
	
	public function IsAutoPosition()
	{
		return $this->autoPosition;
	}
	
	public function SetAutoPosition($autoPosition)
	{
		$this->autoPosition = $autoPosition;
	}
	
	public function __construct(Ship $ship, GamePlan $gamePlan = NULL)
	{
		$this->htmlId = ShipGraphic::CLASS_NAME."_".rand();
				
		$this->ship = $ship;
		$this->gamePlan = $gamePlan;
		$this->SetBackgroundColor("Transparent");
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function Render()
	{
		if ($this->autoResize)
		{
			$this->AutoResize();			
		}
		
		if ($this->autoPosition)
		{
			$this->AutoPosition();
		}
		
		$style = $this->GenerateStyleString();
		$style .= " border-width: 0px; border-style: solid; border-color: yellow; cursor: pointer;";
	
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'" ';
		echo "onmouseover=\"ShipGraphic_SetHighlight(this, true)\" ";
		echo "onmouseout=\"ShipGraphic_SetHighlight(this, false)\" ";
		echo "onclick=\"ShipGraphic_OnClick(this,event)\" "; 
		echo ">\n";
		
		echo '<img alt="'.$this->ship->GetName().'" ';
		echo 'src="'.$this->ship->GetModel()->GetShipType()->GetIconURL().'" ';
		//echo 'style="opacity:1;filter:alpha(opacity=100);" ';
		echo ' width="'.$this->GetWidth().'px" height="'.$this->GetHeight().'px"/>'."\n";
		
		echo "<form method\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_shipId\" name=\"shipId\" type=\"hidden\" value=\"".$this->ship->GetId()."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_shipName\" name=\"shipName\" type=\"hidden\" value=\"".$this->ship->GetName()."\"/>";
		echo "</form>\n";
					
		echo "</div>\n";	
	}
	
	private function AutoResize()
	{
		if ($this->gamePlan == NULL)
		{
			return false;
		}
		
		$width = $this->gamePlan->GetWidth() * DesignConstants::SHIP_SIZE_REL;
		$height = $this->gamePlan->GetHeight() * DesignConstants::SHIP_SIZE_REL;
		
		if ($width >= $height)
		{
			$height = $width / 1;//$this->ship->GetModel()->GetAspectRatio(); 
		}
		else
		{
			$width = $height * 1;//$this->ship->GetModel()->GetAspectRatio(); 
		}
		
		$this->width = $width;
		$this->height = $height;		
	}
	
	private function AutoPosition()
	{
		if ($this->gamePlan == NULL)
		{
			return false;
		}
		
		$coords = $this->gamePlan->WorldToScreenCoords($this->ship->GetX(), $this->ship->GetY(), $this->GetWidth(), $this->GetHeight());
		$this->x = $coords[0];// - $this->GetWidth() / 2;
		$this->y = $coords[1];// - $this->GetHeight() / 2;	
	}
}

?>