<?php

require_once('View/Control.inc');
require_once('View/DeliveryPanel.inc');
require_once('Model/Delivery.inc');
require_once('Model/Ship.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Globals.inc');
require_once('Control/ShipActionController.inc');

class ShipSelectionPanel extends Control
{
	private $gamePlan;
	
	private $delivery;
	
	private $htmlId;
	
	const CLASS_NAME = "ShipSelectionPanel";
		
	public function __construct(GamePlan $gamePlan, Delivery $delivery = NULL)
	{
		$this->gamePlan = $gamePlan;
		$this->delivery = $delivery;
		$this->htmlId = ShipSelectionPanel::CLASS_NAME;
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
		
	public function Render()
	{
		$this->UpdateSize();	
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/universal.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="ShipSelectionPanel_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 18, 35, 433, 353);
		echo '<div style="'.$divStyle.'">';
		
		if ($this->delivery != NULL)
		{
			echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
			echo $dictionary->Translate("SHIP_SELECTION_PANEL_HEADLINE");
			echo "<i>".$this->delivery->GetGoodType()->GetName()."</i></div>\n";
			
			$player = Globals::GetActivePlayer();
			if ($player != NULL && $this->delivery->GetLocationID() > 0)
			{
				$this->PrintShipTable($player);
			}
		}
		
		echo "</div>\n";
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
	}
	
	private function PrintShipTable(Player $player)
	{
		$dictionary = Dictionary::GetInstance();
		
		echo "<table style=\"width: 100%\">\n";
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
		echo "<td>".$dictionary->Translate('SHIP_NAME')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_CLASS')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_TYPE')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_POSITION')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_CHOOSE')."</td>\n";
		echo "</tr>\n";
		
		$ships = (array)$player->GetShipsForced();
		$solarSystem = $this->gamePlan->GetSolarSystem();
							
		foreach ($ships as $ship)
		{			
			$shipController = new ShipActionController($player, $ship);
			if (!$shipController->CanBeDelivered($this->delivery))
			{
				continue;
			}
			
			echo "<tr>\n";
			echo "<td>".$ship->GetName()."</td>\n";
			echo "<td>".$ship->GetModel()->GetName()."</td>\n";
			echo "<td>".$dictionary->Translate($ship->GetModel()->GetShipType()->GetNameString())."</td>\n";
			$planet = $shipController->GetDockedPlanet();
			echo "<td>".($planet != NULL ? $planet->GetName() : $dictionary->Translate('SHIP_UNDOCKED'))."</td>\n";
			echo "<td style=\"text-align: center;\">\n";
			
			if ($shipController->IsWaiting())
			{
				$isShipInSystem = $ship->GetSolarSystemId() == $solarSystem->GetId();
				$isShipInSystem = $isShipInSystem ? "true" : "false";
				echo "<span class=\"LoginPanel_link\" " .
						"onclick=\"ShipSelectionPanel_Deliver(".$ship->GetId().", ".$this->delivery->GetId().", ".$isShipInSystem.")\">\n";
				echo $dictionary->Translate('SHIP_FLY').'</span>';
			}
			else
			{
				echo $dictionary->Translate('SHIP_BUSY');
			}			
			echo "</td>\n";
			echo "</tr>\n";
		}
		
		echo "<form method=\"post\" action=\"\">";
		$isLocal = (Planet::LoadFromDB($this->delivery->GetLocationID())->GetSolarSystemId() == Planet::LoadFromDB($this->delivery->GetTargetPlanetID())->GetSolarSystemId());
		echo "<input id=\"".self::CLASS_NAME."_isLocalDelivery\" name=\"isLocalDelivery\" type=\"hidden\" value=\"".($isLocal ? "true" : "false")."\"/>";
		echo "</form>\n";
		
		echo "</table>\n";
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}

?>