<?php

require_once('View/Control.inc');
require_once('Model/Ship.inc');
require_once('Model/ShipModel.inc');
require_once('Control/Dictionary.inc');
require_once('Control/Utils.inc');
require_once('Control/Globals.inc');

class ShipShopPanel extends Control
{
	private $gamePlan;
		
	private $htmlId;
	
	const CLASS_NAME = "ShipShopPanel";
		
	public function __construct(GamePlan $gamePlan)
	{
		$this->gamePlan = $gamePlan;
		$this->htmlId = self::CLASS_NAME;
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		if ($newId == NULL)
		{
			throw new Exception("ID must not be NULL.");
		}
		$this->htmlId = $newId;
	}
		
	public function Render()
	{
		$this->UpdateSize();	
		
		$style = $this->GenerateStyleString();
		$style .= "background-image:url('Images/interface/gameplan/universal.png');"; 
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'"';
		echo 'onclick="'.self::CLASS_NAME.'_OnClick(event)">'."\n";
		$this->RenderContent();
		echo "</div>\n";
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$divStyle = sprintf("position: absolute; left: %fpx; top: %fpx; width: %fpx; height: %fpx;", 6, 35, 455, 396);
		echo '<div style="'.$divStyle.'">';
		
		$player = Globals::GetActivePlayer();
		
		if ($player != NULL)
		{
			echo '<div style="font-weight: bold; font-size: 14pt; text-align: center; width: 100%;">';
			echo $dictionary->Translate("SHIP_SHOP_PANEL_HEADLINE");
			echo "</div>";
			
			$this->PrintAvailableShipsTable($player);
		}
		else
		{
			echo $dictionary->Translate("LOG_TO_SHIPSHOP");	
			echo "<br/>\n";	
		}
		
		echo "</div>\n";
		
		Graphics::PrintBtn($dictionary->Translate("CLOSE"), 429, 4, 27, 26, self::CLASS_NAME."_Hide()");
	}
	
	private function PrintAvailableShipsTable(Player $player)
	{
		$dictionary = Dictionary::GetInstance();
		$licenceUsedCount = Utils::CalculatePlayerUsedLicences($player);
		$hasFreeLicence = ($licenceUsedCount < $player->GetLicenceCount());
		
		echo "<table style=\"width: 100%\">\n";
		echo "<tr style=\"text-align: center; font-style: italic;\">\n";
		echo "<td>".$dictionary->Translate('SHIP_CLASS_NAME')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_TYPE')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_SPEED')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_CAPACITY')."</td>\n";
		echo "<td>".$dictionary->Translate('SHIP_PRICE')."</td>\n";
		echo "<td>".$dictionary->Translate('ACTION')."</td>\n";
		echo "</tr>\n";
		
		$shipModels = (array)ShipModel::LoadAllFromDB();
					
		foreach ($shipModels as $model)
		{
			if ($model->GetId() == 2)
			{
				continue; // NPC ship
			}
			
			$class = "GreenText";
			$action = "ShipShopPanel_BuyShip(".$model->GetId().")";
			$button_class = "LoginPanel_link";
			$buttonText = $dictionary->Translate('SHIP_BUY');
			
			$affordable = ($model->GetPrice() <= $player->GetMoney());
			$licenceble = (!$model->GetShipType()->IsLicenceRequired()) || $hasFreeLicence;
						
			if (!$affordable || !$licenceble)
			{
				$class = "GrayText";
				$action = "";
				$button_class = "ShipShopPanel_unavailable";
				
				if (!$affordable)
				{
					$buttonText = $dictionary->Translate('SHIP_TOO_EXPENSIVE');
				}
				else if (!$licenceble)
				{
					$buttonText = $dictionary->Translate('SHIP_LICENCE_REQUIRED');
				}
			}
									
			echo "<tr class=\"".$class."\">\n";
			echo "<td>".$model->GetName()."</td>\n";
			echo "<td>".$dictionary->Translate($model->GetShipType()->GetNameString())."</td>\n";
			echo "<td>".$model->GetSpeed()."</td>\n";
			echo "<td>".$model->GetCapacity()."</td>\n";
			echo "<td>".$model->GetPrice()."</td>\n";
			
			echo "<td style=\"text-align: center;\">\n";
			echo "<span class=\"".$button_class."\" onclick=\"".$action."\">\n";
			echo $buttonText.'</span>';			
			echo "</td>\n";
			
			echo "</tr>\n";
		}
		
		echo "</table>\n";
		
		echo "<form method=\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_namePromptText\" name=\"namePromptText\" type=\"hidden\" value=\"".$dictionary->Translate('ENTER_SHIP_NAME')."\"/>";
		echo "</form>\n";
	}
	
	public function UpdateSize()
	{
		$this->SetWidth($this->gamePlan->GetWidth());
		$this->SetHeight($this->gamePlan->GetHeight());
	}
}

?>