<?php

require_once('View/Control.inc');
require_once('Model/Player.inc');
require_once('Control/Dictionary.inc');

class UserDetailForm extends Control
{
	private $player;
	
	const LABEL_WIDTH = 130;
	const CLASS_NAME = "UserDetailForm";
	
	private $modeForgotten;
	
	public function SetForgottenMode($enabled)
	{
		$this->modeForgotten = $enabled;
	}
	
	private $htmlId;
	
	public function __construct(Player $player = NULL)
	{
		$this->player = $player;
		$this->htmlId = "UserDetailForm_" . rand();
		$this->modeForgotten = false;
		$this->SetBackgroundColor("#00110c");
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function Render()
	{
		$dictionary = Dictionary::GetInstance();
		
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$this->GenerateStyleString().'">'."\n";
		
		$this->RenderContent();
		
		echo '</form>'."\n";		
		echo '</div>'."\n";
	}
	
	private function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		if ($this->modeForgotten)
		{
			$action = "passwordGenerate";
			$headline = "PSSWD_GENERATE_HEADLINE";
		}
		else if ($this->player == NULL)
		{	
			$action = "createUser";
			$headline = "NEW_REG_HEADLINE";
		}
		else 
		{
			$action = "editUser";	
			$headline = "EDIT_PLAYER_HEADLINE";
		}
		
		echo '<div style="width: '.$this->GetWidth().'px;">';
		echo '<h1 style="text-align: center;">';
		echo $dictionary->Translate($headline);
		echo "</h1>\n";
		echo '</div>';		
		
		if (!$this->modeForgotten && $this->player != NULL)
		{
			echo "<p>".$dictionary->Translate("USER_DETAIL_EDIT_HELP")."</p>\n";
		}		
		
		$formId = $this->GetHtmlId().'_Form';
		echo '<form id="'.$formId.'" method="post" action="" ';
		echo "onsubmit=\"return ValidateUserDetailForm('".$formId."', '".$action."')\">\n";
		echo '<table border="0" style="width: '.$this->GetWidth().'px;">' . "\n";
		
		if ($this->modeForgotten || $this->player == NULL)
		{
			$this->RenderTableRow("login", "LOGIN", "text", "");
			$this->RenderTableRow("email", "EMAIL", "text", "");
		}
		
		if (!$this->modeForgotten && $this->player != NULL)
		{
			$this->RenderTableRow("password_old", "PASSWORD_OLD", "password");
		}
		
		if (!$this->modeForgotten)
		{
			$this->RenderTableRow("password", "PASSWORD", "password");
			$this->RenderTableRow("password2", "REPEAT_PASSWORD", "password");
			$this->RenderTableRow("nick", "NICK", "text", $this->player != NULL ? $this->player->GetNick() : "");
			$this->RenderTableRow("address", "ADDRESS", "text", $this->player != NULL ? $this->player->GetAddress() : "");
			$this->RenderTableRow("age", "AGE", "text", $this->player != NULL ? $this->player->GetAge() : "");
		}
		
		echo '</table>'."\n";		
				
		echo "<p>\n";
		echo '<input type="hidden" id="'.$formId.'_action'.'" name="action" value="'.$action.'"/>'."\n";
		echo '<input type="reset" value="'.$dictionary->Translate("CLEAR_FORM").'"/>'."&nbsp;&nbsp;\n";
		echo '<input type="submit" value="'.$dictionary->Translate("SEND_FORM").'"/>'."\n";
		echo "</p>\n";
		
		if (!$this->modeForgotten && $this->player != NULL)
		{
			echo "<p>";
			echo '<input type="hidden" name="deletePromptText" id="'.$formId.'_deletePromptText" ';
			echo 'value="'.$dictionary->Translate("DELETE_PLAYER_PROMPT").'"/>'."\n";
			echo "<span class=\"LoginPanel_link\" onclick=\"".self::CLASS_NAME."_DeletePlayer('".$formId."')\">";
			echo $dictionary->Translate("DELETE_PLAYER");
			echo "</span>\n";
			echo "</p>\n";
		}
		
		echo "</form>\n";
	}
	
	private function RenderTableRow($itemName, $label, $type, $content = "")
	{
		$dictionary = Dictionary::GetInstance();
		$labelColWidth = self::LABEL_WIDTH;
		$inputColWidth = ($this->GetWidth() - $labelColWidth) * 0.35;
		$errorColWidth = ($this->GetWidth() - $labelColWidth) * 0.65;
		
		$itemId = $this->GetHtmlId()."_Form_".$itemName;
		$itemErrorId = $itemId."_error";
		echo "<tr>\n";
		echo "<td style=\"width: ".$labelColWidth."px;\">".$dictionary->Translate($label).":</td>\n";
		echo '<td><input type="'.$type.'" name="'.self::CLASS_NAME.'_'.$itemName.'" id="'.$itemId.'" ';
		echo 'value="'.$content.'" ';
		echo 'style="width: '.$inputColWidth.'px;" ';
		echo '/></td>'."\n";
		echo '<td style="width: '.$errorColWidth.'px;"><span style="color: red;" id="'.$itemErrorId.'"></span></td>'."\n";
		echo '</tr>'."\n";	
	}
}


?>