<?php

require_once('View/Control.inc');
require_once('View/DesignConstants.inc');
require_once('Control/Globals.inc');
require_once('Model/WormHole.inc');
require_once('View/GamePlan.inc');

class WormHoleGraphic extends Control
{
	const CLASS_NAME = "WormHoleGraphic";
	
	private $htmlId;
	
	private $gamePlan;
	private $wormHole;
	
	private $autoResize = true;
	
	public function IsAutoResize()
	{
		return $this->autoResize;
	}
	
	public function SetAutoResize($autoResize)
	{
		$this->autoResize = $autoResize;
	}
	
	private $autoPosition = true;
	
	public function IsAutoPosition()
	{
		return $this->autoPosition;
	}
	
	public function SetAutoPosition($autoPosition)
	{
		$this->autoPosition = $autoPosition;
	}
	
	public function __construct(WormHole $wormHole, GamePlan $gamePlan)
	{
		$this->htmlId = self::CLASS_NAME."_".rand();
				
		$this->wormHole = $wormHole;
		$this->gamePlan = $gamePlan;
		
		$this->SetBackgroundColor("transparent");
	}
	
	public function GetHtmlId()
	{
		return $this->htmlId;
	}
	
	public function SetHtmlId($newId)
	{
		$this->htmlId = $newId;
	}
	
	
	public function Render()
	{
		if ($this->autoResize)
		{
			$this->AutoResize();			
		}
		
		if ($this->autoPosition)
		{
			$this->AutoPosition();
		}
		
		$style = $this->GenerateStyleString();
		$style .= " cursor: pointer;";
		echo '<div id="'.$this->GetHtmlId().'" class="'.self::CLASS_NAME.'" style="'.$style.'" ';
		echo "onclick=\"".self::CLASS_NAME."_OnClick(this, event)\" ";
		echo "ondblclick=\"".self::CLASS_NAME."_OnDoubleClick(this, event)\" ";
		echo "onmouseover=\"".self::CLASS_NAME."_OnMouseOver(this, event)\" ";  
		echo ">\n";
		
		$this->RenderContent();
					
		echo "</div>\n";	
	}
	
	public function RenderContent()
	{
		$dictionary = Dictionary::GetInstance();
		
		$otherId = $this->GetOtherSystemId();
		$system = SolarSystem::LoadFromDB($otherId, false);
		$otherName = $system->GetName();
		
		echo '<img ';
		echo "alt=\"".$dictionary->Translate("WORM_HOLE_TO").$otherName."\" ";
		echo 'src="'.$this->wormHole->GetImageURL().'" ';
		//echo 'style="opacity:1;filter:alpha(opacity=100)" ';
		echo ' width="100%" height="100%"/>'."\n";
		
		
		echo "<form method=\"post\" action=\"\">";
		echo "<input id=\"".$this->GetHtmlId()."_wormHoleId\" name=\"wormHoleId\" type=\"hidden\" value=\"".$this->wormHole->GetId()."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_targetSystemId\" name=\"targetSystemId\" type=\"hidden\" value=\"".$otherId."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_lblFlyThrough\" name=\"lblFlyThrough\" type=\"hidden\" value=\"".sprintf($dictionary->Translate("WORMHOLE_FLY_THROUGH"), $otherName)."\"/>";
		echo "<input id=\"".$this->GetHtmlId()."_lblSwitchTo\" name=\"lblSwitchTo\" type=\"hidden\" value=\"".sprintf($dictionary->Translate("WORMHOLE_SWITCH_TO"), $otherName)."\"/>";
		echo "</form>\n";
	}
	
	private function AutoResize()
	{		
		$this->width = DesignConstants::WORMHOLE_SIZE;
		$this->height = DesignConstants::WORMHOLE_SIZE;		
	}
	
	private function GetOtherSystemId()
	{
		$systemIds = (array)$this->wormHole->GetSystemIds();
		foreach ($systemIds as $systemId)
		{
			if ($systemId != $this->gamePlan->GetSolarSystem()->GetId())
			{
				return $systemId;
			}			
		}
	}
	
	private function AutoPosition()
	{
		$systemIds = (array)$this->wormHole->GetSystemIds();
		$i = 0;
		foreach ($systemIds as $systemId)
		{
			if ($systemId == $this->gamePlan->GetSolarSystem()->GetId())
			{
				break;
			}			
			$i++;
		}
		
		$positions = (array)$this->wormHole->GetPositions();
		$position = $positions[$i];
		
		$coords = $this->gamePlan->WorldToScreenCoords(
			$position[0], $position[1], 
			$this->GetWidth(), $this->GetHeight());
			
		$this->x = $coords[0];
		$this->y = $coords[1];	
	}
}

?>