<?php
require_once("View/Page.inc");
require_once("View/UserDetailForm.inc");
require_once("View/LanguageSelector.inc");
require_once("View/DesignConstants.inc");
require_once("Control/GameConstants.inc");
require_once("Control/DBManager.inc");
require_once("Control/DBConstants.inc");
require_once("Control/EmailService.inc");
require_once("Control/Globals.inc");
require_once("Control/Utils.inc");
require_once("Control/ShipActionController.inc");
require_once("Model/Player.inc");
require_once("Model/Planet.inc");
require_once("Model/SolarSystem.inc");
require_once("Model/Ship.inc");
require_once("Model/ActivationRecord.inc");

/**
 * This is entry page of game. 
 */

session_start();

if (!array_key_exists("action", $_REQUEST))
{
	echo "Invalid access.\n";
	exit(1);
}

$action = $_REQUEST["action"];
 
$page = new Page("KIV Webgame prealpha internal");
$page->PrintHeader();

if (!strcmp($action, "register") || !strcmp($action, "showPlayer"))
{
	PrintRegistrationForm();
}
else if (!strcmp($action, "createUser") || !strcmp($action, "editUser"))
{
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_login", $_REQUEST))
	{
		$login = $_REQUEST[UserDetailForm::CLASS_NAME . "_login"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_password_old", $_REQUEST))
	{
		$oldPassword = $_REQUEST[UserDetailForm::CLASS_NAME . "_password_old"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_password", $_REQUEST))
	{
		$password = $_REQUEST[UserDetailForm::CLASS_NAME . "_password"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_password2", $_REQUEST))
	{
		$password2 = $_REQUEST[UserDetailForm::CLASS_NAME . "_password2"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_email", $_REQUEST))
	{
		$email = $_REQUEST[UserDetailForm::CLASS_NAME . "_email"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_nick", $_REQUEST))
	{
		$nick = $_REQUEST[UserDetailForm::CLASS_NAME . "_nick"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_address", $_REQUEST))
	{
		$address = $_REQUEST[UserDetailForm::CLASS_NAME . "_address"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_age", $_REQUEST))
	{
		$age = intval($_REQUEST[UserDetailForm::CLASS_NAME . "_age"]);
	}
	
	if (!strcmp($action, "createUser")) 
	{
		CreateNewUserForm($login, $password, $password2, $email, $nick, $address, $age);
	}
	else 
	{
		UpdateUser(Globals::GetActivePlayer(), $password, $password2, $nick, $address, $age, $oldPassword);
	}
}
else if (!strcmp($action, "activate"))
{
	if (array_key_exists("login", $_REQUEST))
	{
		$login = $_REQUEST["login"];
	}
	
	if (array_key_exists("hash", $_REQUEST))
	{
		$hash = $_REQUEST["hash"];
	}
	
	ActivateUser($login, $hash);
}
else if (!strcmp($action, "forgot"))
{	
	ForgottenPassword();
}
else if (!strcmp($action, "passwordGenerate"))
{
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_login", $_REQUEST))
	{
		$login = $_REQUEST[UserDetailForm::CLASS_NAME . "_login"];
	}
	
	if (array_key_exists(UserDetailForm::CLASS_NAME . "_email", $_REQUEST))
	{
		$email = $_REQUEST[UserDetailForm::CLASS_NAME . "_email"];
	}	
	
	RegeneratePassword($login, $email);
}
else if (!strcmp($_REQUEST["action"], "deletePlayer"))
{
	DeletePlayer();
}
else 
{
	echo "Invalid access.";	
}

$page->PrintFooter();


$dbManager = DBManager::GetInstance();
$dbManager->Dispose();


function PrintRegistrationForm()
{
	$dictionary = Dictionary::GetInstance();
	
	$form = new UserDetailForm(Globals::GetActivePlayer());
	$form->SetPoistionMode("relative");
	$form->SetY(-10);
	$form->SetWidth(650);
	$form->SetHeight(240);
	
	$languageSelector = new LanguageSelector();
	$languageSelector->SetHeight(DesignConstants::LANGUAGE_SELECTOR_HEIGHT);
	$languageSelector->SetWidth($form->GetWidth());
	$languageSelector->SetPoistionMode("static");
	
	$languageSelector->Render();
	$form->Render();
	echo '<p><a href="index.php" style="position: relative; top: 100px;">'.$dictionary->Translate('RETURN_HOME')."</a></p>\n";
}

function DeletePlayer()
{
	$dictionary = Dictionary::GetInstance();
	
	$player = Globals::GetActivePlayer();
	if ($player == NULL)
	{
		echo $dictionary->Translate("LOG_TO_DELETE_PLAYER");
		return;
	}
	
	$player->SetFlag("delete", true, array("" . (time() + GameConstants::TIME_TO_PLAYER_DELETE)));
	Globals::SetActivePlayer(NULL);
	
	echo "<h1>".$dictionary->Translate('PLAYER_DELETE_SCHEDULED')."</h1>\n";
	
	echo "<p>".$dictionary->Translate('PLAYER_DELETE_SCHEDULED_TEXT')."</p>\n";
	
	echo '<a href="index.php">'.$dictionary->Translate('RETURN_HOME').'</a>';
}

function ForgottenPassword()
{
	$dictionary = Dictionary::GetInstance();
	
	$form = new UserDetailForm(Globals::GetActivePlayer());
	$form->SetPoistionMode("relative");
	$form->SetY(-10);
	$form->SetWidth(650);
	$form->SetHeight(240);
	$form->SetForgottenMode(true);
	
	$languageSelector = new LanguageSelector();
	$languageSelector->SetHeight(DesignConstants::LANGUAGE_SELECTOR_HEIGHT);
	$languageSelector->SetWidth($form->GetWidth());
	$languageSelector->SetPoistionMode("static");
	
	$languageSelector->Render();
	$form->Render();
	echo '<p><a href="index.php" style="position: relative; top: 15px;">'.$dictionary->Translate('RETURN_HOME')."</a></p>\n";
}

function RegeneratePassword($login, $email)
{
	$dictionary = Dictionary::GetInstance();
	
	$login = trim($login);
	$email = trim($email);
	
	$allOk = true;
	if (!ValidateLogin($login, true))
	{
		$allOk = false;
	}
	
	if (!ValidateEmail($email))
	{
		$allOk = false;
	}
	
	if (!$allOk)
	{
		ForgottenPassword();
		exit(1);	
	}
	
	$player = Player::LoadFromDBByLogin($login);
	if ($player == NULL || strcasecmp($player->GetEmail(), $email))
	{
		PrintErrorMessage($dictionary->Translate("REGENERATE_PSSWD_BAD_COMB"));
		ForgottenPassword();
		exit(1);
	}
	
	mt_srand(time());
	$newPswd = Utils::GenerateRandomString(12);
	$player->SetPasswordHash(md5($newPswd));
	SendNewPasswordMail($player, $newPswd);
	
	echo "<h1>".$dictionary->Translate('PASSWORD_CHANGED')."</h1>\n";
	
	echo "<p>".$dictionary->Translate('PASSWORD_CHANGED_TEXT')."</p>\n";
	
	echo '<a href="index.php">'.$dictionary->Translate('RETURN_HOME').'</a>';
}

function CreateNewUserForm($login, $password, $password2, $email, $nick, $address, $age)
{
	$dictionary = Dictionary::GetInstance();
	
	$login = trim($login);
	$password = trim($password);
	$password2 = trim($password2);
	$email = trim($email);
	$nick = trim($nick);
	
	if (!ValidateInputs($login, $password, $password2, $email, $nick, $address, $age))
	{
		PrintRegistrationForm();
		exit(1);	
	}
	
	$planets = (array)Planet::LoadAllFromDB();
	$time = explode(" ", microtime());
	$time = floor(microtime(true) * 1000) % 1000000;
	srand($time);
	$homePlanet = $planets[array_rand($planets)];
	$planetId = $homePlanet->GetId();
	
	$player = Player::CreateNewPlayer($login, $password, $email, $nick, $address, $age, $planetId);
	
	if ($player == NULL)
	{
		PrintErrorMessage($dictionary->Translate("COULDNT_REGISTER"));
		PrintRegistrationForm();
		exit(1);
	}
	
	$player->SetLanguage(Globals::GetLanguage());
	
	SendActivationMail($player);
	
	$solarSystem = SolarSystem::LoadFromDB($homePlanet->GetSolarSystemId());
	Globals::SetActiveSolarSystem($solarSystem);
	$ship = Ship::CreateNewShip($player->GetId(), 1, "First ship", $solarSystem->GetId());
	$planets = (array)$solarSystem->GetPlanets();
	
	Base::CreateNewBase($player->GetId(), $player->GetHomePlanetId(), time());
	
	$shipAC = new ShipActionController($player, $ship, $solarSystem);
	$shipAC->DockToPlanet($planets[$player->GetHomePlanetId()]);

	echo "<h1>".$dictionary->Translate('REGISTRATION_FINISHED')."</h1>\n";
	
	echo "<p>".$dictionary->Translate('REGISTRATION_FINISHED_TEXT')."</p>\n";
	
	echo '<a href="index.php">'.$dictionary->Translate('RETURN_HOME').'</a>';
}

function UpdateUser(Player $player, $password, $password2, $nick, $address, $age, $oldPassword)
{
	$dictionary = Dictionary::GetInstance();
	
	$password = trim($password);
	$password2 = trim($password2);
	$email = trim($email);
	$nick = trim($nick);
	
	if (strlen($password) > 0 && !ValidatePassword($password, $password2))
	{
		PrintRegistrationForm();
		exit(1);
	}
	
	if (strlen($password) > 0)
	{
		if ($oldPassword == null || strcmp($player->GetPasswordHash(), $oldPassword))
		{			
			PrintErrorMessage($dictionary->Translate('BAD_OLD_PASSWORD'));
			PrintRegistrationForm();
			exit(1);
		}
		
		$player->SetPasswordHash($password);
	}
	
	$player->SetNick($nick);
	$player->SetAddress($address);
	$player->SetAge($age);
	
	echo "<h1>".$dictionary->Translate('USER_EDIT_FINISHED')."</h1>\n";
	
	echo "<p>".$dictionary->Translate('USER_EDIT_FINISHED_TEXT')."</p>\n";
	
	echo '<a href="index.php">'.$dictionary->Translate('RETURN_HOME').'</a>';
}

function SendActivationMail($player)
{
	$dictionary = Dictionary::GetInstance();
	
	ActivationRecord::RemoveExpired(GameConstants::REGISTRATION_ACTIVATION_LIFETIME);
	$activation = ActivationRecord::CreateActivation($player);	
	
	if ($activation == NULL)
	{
		throw new Exception("Error during activation record creation.");
	}
	
	$activationLink = GameConstants::GAME_URL."/accounts.php?action=activate&login=".
					$player->GetLogin()."&hash=".$activation->GetControlHash();
	
	$message = "<h1>".$dictionary->Translate("WELCOME_TO_GAME")."</h1>\n";
	$message .= "<p>".$dictionary->Translate("REG_MAIL_TEXT")."</p>";
	$message .= '<table border="0">';
	
	$message .= '<tr>';
	$message .= '<td>'.$dictionary->Translate("LOGIN").'</td>';
	$message .= '<td>'.$player->GetLogin().'</td>';
	$message .= '</tr>'."\n";
	
	$message .= '<tr>';
	$message .= '<td>'.$dictionary->Translate("EMAIL").'</td>';
	$message .= '<td>'.$player->GetEmail().'</td>';
	$message .= '</tr>'."\n";
	
	$message .= '</table>';
	
	$message .= "<p>".$dictionary->Translate("REG_MAIL_CLICK_HERE");
	$message .= ' <a href="'.$activationLink.'">'.$activationLink.'</a>';
	$message .= "</p>\n";
	
	EmailService::SendEmail($player->GetEmail(), $dictionary->Translate("REG_MAIL_SUBJ"), $message);
}

function SendNewPasswordMail($player, $password)
{
	$dictionary = Dictionary::GetInstance();
	
	$message = "<h1>".$dictionary->Translate("MAIL_NEW_PASSWORD_HEADLINE")."</h1>\n";
	$message .= "<p>".$dictionary->Translate("MAIL_NEW_PASSWORD_TEXT")."</p>";
	$message .= '<table border="0">';
	
	$message .= '<tr>';
	$message .= '<td>'.$dictionary->Translate("LOGIN").'</td>';
	$message .= '<td>'.$player->GetLogin().'</td>';
	$message .= '</tr>'."\n";
	
	$message .= '<tr>';
	$message .= '<td>'.$dictionary->Translate("EMAIL").'</td>';
	$message .= '<td>'.$player->GetEmail().'</td>';
	$message .= '</tr>'."\n";
	
	$message .= '<tr>';
	$message .= '<td>'.$dictionary->Translate("PASSWORD").'</td>';
	$message .= '<td>'.$password.'</td>';
	$message .= '</tr>'."\n";
	
	$message .= '</table>';
	
	EmailService::SendEmail($player->GetEmail(), $dictionary->Translate("MAIL_NEW_PASSWORD_SUBJ"), $message);
}

function ValidateInputs($login, $password, $password2, $email, $nick, $address, $age)
{
	$dictionary = Dictionary::GetInstance();
	
	$allOk = true;
	
	if (!ValidateLogin($login))
	{
		$allOk = false;
	}
	
	if (!ValidatePassword($password, $password2))
	{
		$allOk = false;
	}
	
	if (!ValidateEmail($email))
	{
		$allOk = false;
	}
	
	return $allOk;
}

function ValidatePassword($password, $password2)
{
	$dictionary = Dictionary::GetInstance();
	
	$allOk = true;
	
	if (strlen($password) < Player::MIN_PASSWORD_LENGTH)
	{
		PrintErrorMessage($dictionary->Translate("PASSWORD_MIN_LENGTH") . " " . Player::MIN_PASSWORD_LENGTH . ".");
		$allOk = false;
	}
	
	if (strlen($password) > Player::MAX_PASSWORD_LENGTH)
	{
		PrintErrorMessage($dictionary->Translate("PASSWORD_MAX_LENGTH") . " " . Player::MAX_PASSWORD_LENGTH . ".");
		$allOk = false;
	}
	
	if (strcmp($password, $password2) != 0)
	{
		PrintErrorMessage($dictionary->Translate("PASSWORD_MISSMATCH"));
		$allOk = false;
	}	
	
	return $allOk;
}

function ValidateLogin($login, $mayExist = false)
{
	$dictionary = Dictionary::GetInstance();
	
	$allOk = true;
	if (strlen($login) < Player::MIN_LOGIN_LENGTH)
	{
		PrintErrorMessage($dictionary->Translate("LOGIN_MIN_LENGTH") . " " . Player::MIN_LOGIN_LENGTH . ".");
		$allOk = false;
	}
	
	if (strlen($login) > Player::MAX_LOGIN_LENGTH)
	{
		PrintErrorMessage($dictionary->Translate("LOGIN_MAX_LENGTH") . " " . Player::MAX_LOGIN_LENGTH . ".");
		$allOk = false;
	}
	
	if (!$mayExist && $login != NULL && Player::LoadFromDBByLogin($login) != NULL)
	{
		PrintErrorMessage($dictionary->Translate("USER_ALREADY_EXISTS"));
		$allOk = false;
	}
	
	return $allOk;
}

function ValidateEmail($email)
{
	$dictionary = Dictionary::GetInstance();
	
	$allOk = true;
	
	if (strlen($email) <= 0)
	{
		PrintErrorMessage($dictionary->Translate("EMAIL_NOT_FILLED"));
		$allOk = false;
	}
	
	if (!eregi("^[_a-z0-9-]+(\.[_a-z0-9-]+)*@[a-z0-9-]+(\.[a-z0-9-]+)*(\.[a-z]{2,3})$", $email))
	{		
		PrintErrorMessage($dictionary->Translate("EMAIL_INVALID"));
		$allOk = false;		
	}
	
	return $allOk;
}

function PrintErrorMessage($message)
{
	echo '<span class="error_message" style="color: red;">';
	echo $message;
	echo '</span><br />'. "\n";
}

function ActivateUser($login, $hash)
{
	$dictionary = Dictionary::GetInstance();
	
	$languageSelector = new LanguageSelector();
	$languageSelector->SetWidth(800);
	$languageSelector->SetHeight(DesignConstants::LANGUAGE_SELECTOR_HEIGHT);
	$languageSelector->SetPoistionMode("static");
	$languageSelector->Render();
	
	$player = Player::LoadFromDBByLogin($login);
	
	$allOk = true;
	
	if ($allOk && $player == NULL)
	{
		PrintErrorMessage($dictionary->Translate("PLAYER_DOESNT_EXIST"));
		$allOk = false;
	}
	
	if ($allOk && $player->IsActive())
	{
		PrintErrorMessage($dictionary->Translate("PLAYER_ALREADY_ACTIVATED"));
		$allOk = false;
	}
	
	$activationRecord = ActivationRecord::LoadActivationForPlayer($player);
	
	if ($allOk && $activationRecord == NULL)
	{
		PrintErrorMessage($dictionary->Translate("NO_ACTIVATION_RECORD"));
		$allOk = false;
	}
	
	if ($allOk && (time() - $activationRecord->GetCreateTime()) > GameConstants::REGISTRATION_ACTIVATION_LIFETIME)
	{
		PrintErrorMessage($dictionary->Translate("ACT_LIFETIME_EXPIRED"));
		$allOk = false;
	}
	
	if ($allOk)
	{
		$activationRecord->RemoveFromDB();
		$player->SetActive(true);
		
		echo "<h3>".$dictionary->Translate("ACCOUNT_ACTIVATED")." ".$player->GetLogin()."</h3>\n";
		echo "<p>".$dictionary->Translate("YOU_CAN_LOG_IN")."</p>\n";
	}
	
	echo '<a href="index.php">'.$dictionary->Translate('RETURN_HOME').'</a>';
}

?>
